#
# * Main Zen Cart SQL Load for MySQL databases
# * @package Installer
# * @access private
# * @copyright Copyright 2003-2007 Zen Cart Development Team
# * @copyright Portions Copyright 2003 osCommerce
# * @license http://www.zen-cart.com/license/2_0.txt GNU Public License V2.0
# * @version $Id: mysql_zencart.sql 7555 2007-11-30 17:39:21Z drbyte $
#

############ IMPORTANT INSTRUCTIONS ###############
#
# * Zen Cart uses the zc_install/index.php program to do installations
# * This SQL script is intended to be used by running zc_install
# * It is *not* recommended to simply run these statements manually via any other means
# * ie: not via phpMyAdmin or other SQL front-end tools
# * The zc_install program catches possible problems/exceptions
# * and also handles table-prefixes automatically, based on selections made during installation
#
#####################################################


# --------------------------------------------------------
#
# Table structure for table upgrade_exceptions
# (Placed at top so any exceptions during installation can be trapped as well)
#

DROP TABLE IF EXISTS upgrade_exceptions;
CREATE TABLE upgrade_exceptions (
  upgrade_exception_id smallint(5) NOT NULL auto_increment,
  sql_file varchar(50) default NULL,
  reason varchar(200) default NULL,
  errordate datetime default '0001-01-01 00:00:00',
  sqlstatement text,
  PRIMARY KEY  (upgrade_exception_id)
) TYPE=MyISAM;


# --------------------------------------------------------
#
# Table structure for table address_book
#

DROP TABLE IF EXISTS address_book;
CREATE TABLE address_book (
  address_book_id int(11) NOT NULL auto_increment,
  customers_id int(11) NOT NULL default '0',
  entry_gender char(1) NOT NULL default '',
  entry_company varchar(64) default NULL,
  entry_firstname varchar(32) NOT NULL default '',
  entry_lastname varchar(32) NOT NULL default '',
  entry_street_address varchar(64) NOT NULL default '',
  entry_suburb varchar(32) default NULL,
  entry_postcode varchar(10) NOT NULL default '',
  entry_city varchar(32) NOT NULL default '',
  entry_state varchar(32) default NULL,
  entry_country_id int(11) NOT NULL default '0',
  entry_zone_id int(11) NOT NULL default '0',
  PRIMARY KEY  (address_book_id),
  KEY idx_address_book_customers_id_zen (customers_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'address_format'
#

DROP TABLE IF EXISTS address_format;
CREATE TABLE address_format (
  address_format_id int(11) NOT NULL auto_increment,
  address_format varchar(128) NOT NULL default '',
  address_summary varchar(48) NOT NULL default '',
  PRIMARY KEY  (address_format_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'admin'
#

DROP TABLE IF EXISTS admin;
CREATE TABLE admin (
  admin_id int(11) NOT NULL auto_increment,
  admin_name varchar(32) NOT NULL default '',
  admin_email varchar(96) NOT NULL default '',
  admin_pass varchar(40) NOT NULL default '',
  admin_level tinyint(1) NOT NULL default '1',
  PRIMARY KEY  (admin_id),
  KEY idx_admin_name_zen (admin_name),
  KEY idx_admin_email_zen (admin_email)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'admin_activity_log'
#

DROP TABLE IF EXISTS admin_activity_log;
CREATE TABLE admin_activity_log (
  log_id int(15) NOT NULL auto_increment,
  access_date datetime NOT NULL default '0001-01-01 00:00:00',
  admin_id int(11) NOT NULL default '0',
  page_accessed varchar(80) NOT NULL default '',
  page_parameters text,
  ip_address varchar(15) NOT NULL default '',
  PRIMARY KEY  (log_id),
  KEY idx_page_accessed_zen (page_accessed),
  KEY idx_access_date_zen (access_date),
  KEY idx_ip_zen (ip_address)
) TYPE=MyISAM;


# --------------------------------------------------------

#
# Table structure for table 'authorizenet'
#
DROP TABLE IF EXISTS authorizenet;
CREATE TABLE authorizenet (
  id int(11) unsigned NOT NULL auto_increment,
  customer_id int(11) NOT NULL default '0',
  order_id int(11) NOT NULL default '0',
  response_code int(1) NOT NULL default '0',
  response_text varchar(255) NOT NULL default '',
  authorization_type varchar(50) NOT NULL default '',
  transaction_id int(15) NOT NULL default '0',
  sent longtext NOT NULL,
  received longtext NOT NULL,
  time varchar(50) NOT NULL default '',
  session_id varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'banners'
#

DROP TABLE IF EXISTS banners;
CREATE TABLE banners (
  banners_id int(11) NOT NULL auto_increment,
  banners_title varchar(64) NOT NULL default '',
  banners_url varchar(255) NOT NULL default '',
  banners_image varchar(64) NOT NULL default '',
  banners_group varchar(15) NOT NULL default '',
  banners_html_text text,
  expires_impressions int(7) default '0',
  expires_date datetime default NULL,
  date_scheduled datetime default NULL,
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  date_status_change datetime default NULL,
  status int(1) NOT NULL default '1',
  banners_open_new_windows int(1) NOT NULL default '1',
  banners_on_ssl int(1) NOT NULL default '1',
  banners_sort_order int(11) NOT NULL default '0',
  PRIMARY KEY  (banners_id),
  KEY idx_status_group_zen (status,banners_group),
  KEY idx_expires_date_zen (expires_date),
  KEY idx_date_scheduled_zen (date_scheduled)
) TYPE=MyISAM;


# --------------------------------------------------------

#
# Table structure for table 'banners_history'
#

DROP TABLE IF EXISTS banners_history;
CREATE TABLE banners_history (
  banners_history_id int(11) NOT NULL auto_increment,
  banners_id int(11) NOT NULL default '0',
  banners_shown int(5) NOT NULL default '0',
  banners_clicked int(5) NOT NULL default '0',
  banners_history_date datetime NOT NULL default '0001-01-01 00:00:00',
  PRIMARY KEY  (banners_history_id),
  KEY idx_banners_id_zen (banners_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'categories'
#

DROP TABLE IF EXISTS categories;
CREATE TABLE categories (
  categories_id int(11) NOT NULL auto_increment,
  categories_image varchar(64) default NULL,
  parent_id int(11) NOT NULL default '0',
  sort_order int(3) default NULL,
  date_added datetime default NULL,
  last_modified datetime default NULL,
  categories_status tinyint(1) NOT NULL default '1',
  PRIMARY KEY  (categories_id),
  KEY idx_parent_id_cat_id_zen (parent_id,categories_id),
  KEY idx_status_zen (categories_status),
  KEY idx_sort_order_zen (sort_order)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'categories_description'
#

DROP TABLE IF EXISTS categories_description;
CREATE TABLE categories_description (
  categories_id int(11) NOT NULL default '0',
  language_id int(11) NOT NULL default '1',
  categories_name varchar(32) NOT NULL default '',
  categories_description text NOT NULL,
  PRIMARY KEY  (categories_id,language_id),
  KEY idx_categories_name_zen (categories_name)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'configuration'
#

DROP TABLE IF EXISTS configuration;
CREATE TABLE configuration (
  configuration_id int(11) NOT NULL auto_increment,
  configuration_title text NOT NULL,
  configuration_key varchar(255) NOT NULL default '',
  configuration_value text NOT NULL,
  configuration_description text NOT NULL,
  configuration_group_id int(11) NOT NULL default '0',
  sort_order int(5) default NULL,
  last_modified datetime default NULL,
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  use_function text default NULL,
  set_function text default NULL,
  PRIMARY KEY  (configuration_id),
  UNIQUE KEY unq_config_key_zen (configuration_key),
  KEY idx_key_value_zen (configuration_key,configuration_value(10)),
  KEY idx_cfg_grp_id_zen (configuration_group_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'configuration_group'
#

DROP TABLE IF EXISTS configuration_group;
CREATE TABLE configuration_group (
  configuration_group_id int(11) NOT NULL auto_increment,
  configuration_group_title varchar(64) NOT NULL default '',
  configuration_group_description varchar(255) NOT NULL default '',
  sort_order int(5) default NULL,
  visible int(1) default '1',
  PRIMARY KEY  (configuration_group_id),
  KEY idx_visible_zen (visible)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'counter'
#

DROP TABLE IF EXISTS counter;
CREATE TABLE counter (
  startdate char(8) default NULL,
  counter int(12) default NULL
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'counter_history'
#

DROP TABLE IF EXISTS counter_history;
CREATE TABLE counter_history (
  startdate char(8) default NULL,
  counter int(12) default NULL,
  session_counter int(12) default NULL
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'countries'
#

DROP TABLE IF EXISTS countries;
CREATE TABLE countries (
  countries_id int(11) NOT NULL auto_increment,
  countries_name varchar(64) NOT NULL default '',
  countries_iso_code_2 char(2) NOT NULL default '',
  countries_iso_code_3 char(3) NOT NULL default '',
  address_format_id int(11) NOT NULL default '0',
  PRIMARY KEY  (countries_id),
  KEY idx_countries_name_zen (countries_name),
  KEY idx_address_format_id_zen (address_format_id),
  KEY idx_iso_2_zen (countries_iso_code_2),
  KEY idx_iso_3_zen (countries_iso_code_3)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'coupon_email_track'
#

DROP TABLE IF EXISTS coupon_email_track;
CREATE TABLE coupon_email_track (
  unique_id int(11) NOT NULL auto_increment,
  coupon_id int(11) NOT NULL default '0',
  customer_id_sent int(11) NOT NULL default '0',
  sent_firstname varchar(32) default NULL,
  sent_lastname varchar(32) default NULL,
  emailed_to varchar(32) default NULL,
  date_sent datetime NOT NULL default '0001-01-01 00:00:00',
  PRIMARY KEY  (unique_id),
  KEY idx_coupon_id_zen (coupon_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'coupon_gv_customer'
#

DROP TABLE IF EXISTS coupon_gv_customer;
CREATE TABLE coupon_gv_customer (
  customer_id int(5) NOT NULL default '0',
  amount decimal(15,4) NOT NULL default '0.0000',
  PRIMARY KEY  (customer_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'coupon_gv_queue'
#

DROP TABLE IF EXISTS coupon_gv_queue;
CREATE TABLE coupon_gv_queue (
  unique_id int(5) NOT NULL auto_increment,
  customer_id int(5) NOT NULL default '0',
  order_id int(5) NOT NULL default '0',
  amount decimal(15,4) NOT NULL default '0.0000',
  date_created datetime NOT NULL default '0001-01-01 00:00:00',
  ipaddr varchar(32) NOT NULL default '',
  release_flag char(1) NOT NULL default 'N',
  PRIMARY KEY  (unique_id),
  KEY idx_cust_id_order_id_zen (customer_id,order_id),
  KEY idx_release_flag_zen (release_flag)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'coupon_redeem_track'
#

DROP TABLE IF EXISTS coupon_redeem_track;
CREATE TABLE coupon_redeem_track (
  unique_id int(11) NOT NULL auto_increment,
  coupon_id int(11) NOT NULL default '0',
  customer_id int(11) NOT NULL default '0',
  redeem_date datetime NOT NULL default '0001-01-01 00:00:00',
  redeem_ip varchar(32) NOT NULL default '',
  order_id int(11) NOT NULL default '0',
  PRIMARY KEY  (unique_id),
  KEY idx_coupon_id_zen (coupon_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'coupon_restrict'
#

DROP TABLE IF EXISTS coupon_restrict;
CREATE TABLE coupon_restrict (
  restrict_id int(11) NOT NULL auto_increment,
  coupon_id int(11) NOT NULL default '0',
  product_id int(11) NOT NULL default '0',
  category_id int(11) NOT NULL default '0',
  coupon_restrict char(1) NOT NULL default 'N',
  PRIMARY KEY  (restrict_id),
  KEY idx_coup_id_prod_id_zen (coupon_id,product_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'coupons'
#

DROP TABLE IF EXISTS coupons;
CREATE TABLE coupons (
  coupon_id int(11) NOT NULL auto_increment,
  coupon_type char(1) NOT NULL default 'F',
  coupon_code varchar(32) NOT NULL default '',
  coupon_amount decimal(15,4) NOT NULL default '0.0000',
  coupon_minimum_order decimal(15,4) NOT NULL default '0.0000',
  coupon_start_date datetime NOT NULL default '0001-01-01 00:00:00',
  coupon_expire_date datetime NOT NULL default '0001-01-01 00:00:00',
  uses_per_coupon int(5) NOT NULL default '1',
  uses_per_user int(5) NOT NULL default '0',
  restrict_to_products varchar(255) default NULL,
  restrict_to_categories varchar(255) default NULL,
  restrict_to_customers text,
  coupon_active char(1) NOT NULL default 'Y',
  date_created datetime NOT NULL default '0001-01-01 00:00:00',
  date_modified datetime NOT NULL default '0001-01-01 00:00:00',
  coupon_zone_restriction int(11) NOT NULL default '0',
  PRIMARY KEY (coupon_id),
  KEY idx_active_type_zen (coupon_active,coupon_type),
  KEY idx_coupon_code_zen (coupon_code),
  KEY idx_coupon_type_zen (coupon_type)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'coupons_description'
#

DROP TABLE IF EXISTS coupons_description;
CREATE TABLE coupons_description (
  coupon_id int(11) NOT NULL default '0',
  language_id int(11) NOT NULL default '0',
  coupon_name varchar(32) NOT NULL default '',
  coupon_description text,
  PRIMARY KEY (coupon_id,language_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'currencies'
#

DROP TABLE IF EXISTS currencies;
CREATE TABLE currencies (
  currencies_id int(11) NOT NULL auto_increment,
  title varchar(32) NOT NULL default '',
  code char(3) NOT NULL default '',
  symbol_left varchar(24) default NULL,
  symbol_right varchar(24) default NULL,
  decimal_point char(1) default NULL,
  thousands_point char(1) default NULL,
  decimal_places char(1) default NULL,
  value float(13,8) default NULL,
  last_updated datetime default NULL,
  PRIMARY KEY  (currencies_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'customers'
#

DROP TABLE IF EXISTS customers;
CREATE TABLE customers (
  customers_id int(11) NOT NULL auto_increment,
  customers_gender char(1) NOT NULL default '',
  customers_firstname varchar(32) NOT NULL default '',
  customers_lastname varchar(32) NOT NULL default '',
  customers_dob datetime NOT NULL default '0001-01-01 00:00:00',
  customers_email_address varchar(96) NOT NULL default '',
  customers_nick varchar(96) NOT NULL default '',
  customers_default_address_id int(11) NOT NULL default '0',
  customers_telephone varchar(32) NOT NULL default '',
  customers_fax varchar(32) default NULL,
  customers_password varchar(40) NOT NULL default '',
  customers_newsletter char(1) default NULL,
  customers_group_pricing int(11) NOT NULL default '0',
  customers_email_format varchar(4) NOT NULL default 'TEXT',
  customers_authorization int(1) NOT NULL default '0',
  customers_referral varchar(32) NOT NULL default '',
  customers_paypal_payerid VARCHAR(20) NOT NULL default '',
  customers_paypal_ec TINYINT(1) UNSIGNED DEFAULT 0 NOT NULL,
  PRIMARY KEY  (customers_id),
  KEY idx_email_address_zen (customers_email_address),
  KEY idx_referral_zen (customers_referral(10)),
  KEY idx_grp_pricing_zen (customers_group_pricing),
  KEY idx_nick_zen (customers_nick),
  KEY idx_newsletter_zen (customers_newsletter)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'customers_basket'
#

DROP TABLE IF EXISTS customers_basket;
CREATE TABLE customers_basket (
  customers_basket_id int(11) NOT NULL auto_increment,
  customers_id int(11) NOT NULL default '0',
  products_id tinytext NOT NULL,
  customers_basket_quantity float NOT NULL default '0',
  final_price decimal(15,4) NOT NULL default '0.0000',
  customers_basket_date_added varchar(8) default NULL,
  PRIMARY KEY  (customers_basket_id),
  KEY idx_customers_id_zen (customers_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'customers_basket_attributes'
#

DROP TABLE IF EXISTS customers_basket_attributes;
CREATE TABLE customers_basket_attributes (
  customers_basket_attributes_id int(11) NOT NULL auto_increment,
  customers_id int(11) NOT NULL default '0',
  products_id tinytext NOT NULL,
  products_options_id varchar(64) NOT NULL default '0',
  products_options_value_id int(11) NOT NULL default '0',
  products_options_value_text BLOB NULL,
  products_options_sort_order text NOT NULL,
  PRIMARY KEY  (customers_basket_attributes_id),
  KEY idx_cust_id_prod_id_zen (customers_id,products_id(36))
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'customers_info'
#

DROP TABLE IF EXISTS customers_info;
CREATE TABLE customers_info (
  customers_info_id int(11) NOT NULL default '0',
  customers_info_date_of_last_logon datetime default NULL,
  customers_info_number_of_logons int(5) default NULL,
  customers_info_date_account_created datetime default NULL,
  customers_info_date_account_last_modified datetime default NULL,
  global_product_notifications int(1) default '0',
  PRIMARY KEY  (customers_info_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table db_cache
#
DROP TABLE IF EXISTS db_cache;
CREATE TABLE db_cache (
  cache_entry_name varchar(64) NOT NULL default '',
  cache_data mediumblob,
  cache_entry_created int(15) default NULL,
  PRIMARY KEY  (cache_entry_name)
) TYPE=MyISAM;



# --------------------------------------------------------

#
# Table structure for table 'email_archive'
#

DROP TABLE IF EXISTS email_archive;
CREATE TABLE email_archive (
  archive_id int(11) NOT NULL auto_increment,
  email_to_name varchar(96) NOT NULL default '',
  email_to_address varchar(96) NOT NULL default '',
  email_from_name varchar(96) NOT NULL default '',
  email_from_address varchar(96) NOT NULL default '',
  email_subject varchar(255) NOT NULL default '',
  email_html text NOT NULL,
  email_text text NOT NULL,
  date_sent datetime NOT NULL default '0001-01-01 00:00:00',
  module varchar(64) NOT NULL default '',
  PRIMARY KEY  (archive_id),
  KEY idx_email_to_address_zen (email_to_address),
  KEY idx_module_zen (module)
) TYPE=MyISAM;


# --------------------------------------------------------

#
# Table structure for table 'ezpages'
#

DROP TABLE IF EXISTS ezpages;
CREATE TABLE ezpages (
  pages_id int(11) NOT NULL auto_increment,
  languages_id int(11) NOT NULL default '1',
  pages_title varchar(64) NOT NULL default '',
  alt_url varchar(255) NOT NULL default '',
  alt_url_external varchar(255) NOT NULL default '',
  pages_html_text mediumtext,
  status_header int(1) NOT NULL default '1',
  status_sidebox int(1) NOT NULL default '1',
  status_footer int(1) NOT NULL default '1',
  status_toc int(1) NOT NULL default '1',
  header_sort_order int(3) NOT NULL default '0',
  sidebox_sort_order int(3) NOT NULL default '0',
  footer_sort_order int(3) NOT NULL default '0',
  toc_sort_order int(3) NOT NULL default '0',
  page_open_new_window int(1) NOT NULL default '0',
  page_is_ssl int(1) NOT NULL default '0',
  toc_chapter int(11) NOT NULL default '0',
  PRIMARY KEY  (pages_id),
  KEY idx_lang_id_zen (languages_id),
  KEY idx_ezp_status_header_zen (status_header),
  KEY idx_ezp_status_sidebox_zen (status_sidebox),
  KEY idx_ezp_status_footer_zen (status_footer),
  KEY idx_ezp_status_toc_zen (status_toc)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'featured'
#

DROP TABLE IF EXISTS featured;
CREATE TABLE featured (
  featured_id int(11) NOT NULL auto_increment,
  products_id int(11) NOT NULL default '0',
  featured_date_added datetime default NULL,
  featured_last_modified datetime default NULL,
  expires_date date NOT NULL default '0001-01-01',
  date_status_change datetime default NULL,
  status int(1) NOT NULL default '1',
  featured_date_available date NOT NULL default '0001-01-01',
  PRIMARY KEY  (featured_id),
  KEY idx_status_zen (status),
  KEY idx_products_id_zen (products_id),
  KEY idx_date_avail_zen (featured_date_available),
  KEY idx_expires_date_zen (expires_date)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'files_uploaded'
#

DROP TABLE IF EXISTS files_uploaded;
CREATE TABLE files_uploaded (
  files_uploaded_id int(11) NOT NULL auto_increment,
  sesskey varchar(32) default NULL,
  customers_id int(11) default NULL,
  files_uploaded_name varchar(64) NOT NULL default '',
  PRIMARY KEY  (files_uploaded_id),
  KEY idx_customers_id_zen (customers_id)
) TYPE=MyISAM COMMENT='Must always have either a sesskey or customers_id';

# --------------------------------------------------------

#
# Table structure for table 'geo_zones'
#

DROP TABLE IF EXISTS geo_zones;
CREATE TABLE geo_zones (
  geo_zone_id int(11) NOT NULL auto_increment,
  geo_zone_name varchar(32) NOT NULL default '',
  geo_zone_description varchar(255) NOT NULL default '',
  last_modified datetime default NULL,
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  PRIMARY KEY  (geo_zone_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'get_terms_to_filter'
#
DROP TABLE IF EXISTS get_terms_to_filter;
CREATE TABLE get_terms_to_filter (
  get_term_name varchar(255) NOT NULL default '',
  get_term_table varchar(64) NOT NULL,
  get_term_name_field varchar(64) NOT NULL,
  PRIMARY KEY  (get_term_name)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'group_pricing'
#

DROP TABLE IF EXISTS group_pricing;
CREATE TABLE group_pricing (
  group_id int(11) NOT NULL auto_increment,
  group_name varchar(32) NOT NULL default '',
  group_percentage decimal(5,2) NOT NULL default '0.00',
  last_modified datetime default NULL,
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  PRIMARY KEY  (group_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'languages'
#

DROP TABLE IF EXISTS languages;
CREATE TABLE languages (
  languages_id int(11) NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  code char(2) NOT NULL default '',
  image varchar(64) default NULL,
  directory varchar(32) default NULL,
  sort_order int(3) default NULL,
  PRIMARY KEY  (languages_id),
  KEY idx_languages_name_zen (name)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'layout_boxes'
#

DROP TABLE IF EXISTS layout_boxes;
CREATE TABLE layout_boxes (
  layout_id int(11) NOT NULL auto_increment,
  layout_template varchar(64) NOT NULL default '',
  layout_box_name varchar(64) NOT NULL default '',
  layout_box_status tinyint(1) NOT NULL default '0',
  layout_box_location tinyint(1) NOT NULL default '0',
  layout_box_sort_order int(11) NOT NULL default '0',
  layout_box_sort_order_single int(11) NOT NULL default '0',
  layout_box_status_single tinyint(4) NOT NULL default '0',
  PRIMARY KEY  (layout_id),
  KEY idx_name_template_zen (layout_template,layout_box_name),
  KEY idx_layout_box_status_zen (layout_box_status),
  KEY idx_layout_box_sort_order_zen (layout_box_sort_order)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'manufacturers'
#

DROP TABLE IF EXISTS manufacturers;
CREATE TABLE manufacturers (
  manufacturers_id int(11) NOT NULL auto_increment,
  manufacturers_name varchar(32) NOT NULL default '',
  manufacturers_image varchar(64) default NULL,
  date_added datetime default NULL,
  last_modified datetime default NULL,
  PRIMARY KEY  (manufacturers_id),
  KEY idx_mfg_name_zen (manufacturers_name)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'manufacturers_info'
#

DROP TABLE IF EXISTS manufacturers_info;
CREATE TABLE manufacturers_info (
  manufacturers_id int(11) NOT NULL default '0',
  languages_id int(11) NOT NULL default '0',
  manufacturers_url varchar(255) NOT NULL default '',
  url_clicked int(5) NOT NULL default '0',
  date_last_click datetime default NULL,
  PRIMARY KEY  (manufacturers_id,languages_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'media_clips'
#

DROP TABLE IF EXISTS media_clips;
CREATE TABLE media_clips (
  clip_id int(11) NOT NULL auto_increment,
  media_id int(11) NOT NULL default '0',
  clip_type smallint(6) NOT NULL default '0',
  clip_filename text NOT NULL,
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  last_modified datetime NOT NULL default '0001-01-01 00:00:00',
  PRIMARY KEY  (clip_id),
  KEY idx_media_id_zen (media_id),
  KEY idx_clip_type_zen (clip_type)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'media_manager'
#

DROP TABLE IF EXISTS media_manager;
CREATE TABLE media_manager (
  media_id int(11) NOT NULL auto_increment,
  media_name varchar(255) NOT NULL default '',
  last_modified datetime NOT NULL default '0001-01-01 00:00:00',
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  PRIMARY KEY  (media_id),
  KEY idx_media_name_zen (media_name)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'media_to_products'
#

DROP TABLE IF EXISTS media_to_products;
CREATE TABLE media_to_products (
  media_id int(11) NOT NULL default '0',
  product_id int(11) NOT NULL default '0',
  KEY idx_media_product_zen (media_id,product_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'media_types'
#

DROP TABLE IF EXISTS media_types;
CREATE TABLE media_types (
  type_id int(11) NOT NULL auto_increment,
  type_name varchar(64) NOT NULL default '',
  type_ext varchar(8) NOT NULL default '',
  PRIMARY KEY  (type_id),
  KEY idx_type_name_zen (type_name)
) TYPE=MyISAM;

INSERT INTO media_types (type_name, type_ext) VALUES ('MP3','.mp3');

# -------------------------------------------------------

#
# Table structure for table 'meta_tags_categories_description'
#

DROP TABLE IF EXISTS meta_tags_categories_description;
CREATE TABLE meta_tags_categories_description (
  categories_id int(11) NOT NULL,
  language_id int(11) NOT NULL default '1',
  metatags_title varchar(255) NOT NULL default '',
  metatags_keywords text,
  metatags_description text,
  PRIMARY KEY  (categories_id,language_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'meta_tags_products_description'
#

DROP TABLE IF EXISTS meta_tags_products_description;
CREATE TABLE meta_tags_products_description (
  products_id int(11) NOT NULL,
  language_id int(11) NOT NULL default '1',
  metatags_title varchar(255) NOT NULL default '',
  metatags_keywords text,
  metatags_description text,
  PRIMARY KEY  (products_id,language_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'music_genre'
#

DROP TABLE IF EXISTS music_genre;
CREATE TABLE music_genre (
  music_genre_id int(11) NOT NULL auto_increment,
  music_genre_name varchar(32) NOT NULL default '',
  date_added datetime default NULL,
  last_modified datetime default NULL,
  PRIMARY KEY  (music_genre_id),
  KEY idx_music_genre_name_zen (music_genre_name)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'newsletters'
#

DROP TABLE IF EXISTS newsletters;
CREATE TABLE newsletters (
  newsletters_id int(11) NOT NULL auto_increment,
  title varchar(255) NOT NULL default '',
  content text NOT NULL,
  content_html text NOT NULL,
  module varchar(255) NOT NULL default '',
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  date_sent datetime default NULL,
  status int(1) default NULL,
  locked int(1) default '0',
  PRIMARY KEY  (newsletters_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'nochex_apc_transactions'
#

DROP TABLE IF EXISTS nochex_apc_transactions;
CREATE TABLE nochex_apc_transactions (
  nochex_apc_id int(11) unsigned NOT NULL auto_increment,
  order_id int(11) unsigned NOT NULL default 0,
  nc_transaction_id varchar(30) NOT NULL,
  nc_transaction_date varchar(100) NOT NULL,
  nc_to_email varchar(255) NOT NULL,
  nc_from_email varchar(255) NOT NULL,
  nc_order_id varchar(255) NOT NULL,
  nc_custom varchar(255) NOT NULL,
  nc_amount decimal(9,2) NOT NULL,
  nc_security_key varchar(255) NOT NULL,
  nc_status varchar(15) NOT NULL,
  nochex_response varchar(255) NOT NULL,
  last_modified datetime NOT NULL default '0001-01-01 00:00:00',
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  memo text,
  PRIMARY KEY  (nochex_apc_id),
  KEY idx_order_id_zen (order_id)
);

# --------------------------------------------------------

#
# Table structure for table 'nochex_sessions'
#

DROP TABLE IF EXISTS nochex_sessions;
CREATE TABLE nochex_sessions (
  unique_id int(11) NOT NULL auto_increment,
  session_id text NOT NULL,
  saved_session mediumblob NOT NULL,
  expiry int(17) NOT NULL default '0',
  PRIMARY KEY  (unique_id),
  KEY idx_session_id_zen (session_id(36))
);


# --------------------------------------------------------

#
# Table structure for table 'orders'
#

DROP TABLE IF EXISTS orders;
CREATE TABLE orders (
  orders_id int(11) NOT NULL auto_increment,
  customers_id int(11) NOT NULL default '0',
  customers_name varchar(64) NOT NULL default '',
  customers_company varchar(64) default NULL,
  customers_street_address varchar(64) NOT NULL default '',
  customers_suburb varchar(32) default NULL,
  customers_city varchar(32) NOT NULL default '',
  customers_postcode varchar(10) NOT NULL default '',
  customers_state varchar(32) default NULL,
  customers_country varchar(32) NOT NULL default '',
  customers_telephone varchar(32) NOT NULL default '',
  customers_email_address varchar(96) NOT NULL default '',
  customers_address_format_id int(5) NOT NULL default '0',
  delivery_name varchar(64) NOT NULL default '',
  delivery_company varchar(64) default NULL,
  delivery_street_address varchar(64) NOT NULL default '',
  delivery_suburb varchar(32) default NULL,
  delivery_city varchar(32) NOT NULL default '',
  delivery_postcode varchar(10) NOT NULL default '',
  delivery_state varchar(32) default NULL,
  delivery_country varchar(32) NOT NULL default '',
  delivery_address_format_id int(5) NOT NULL default '0',
  billing_name varchar(64) NOT NULL default '',
  billing_company varchar(64) default NULL,
  billing_street_address varchar(64) NOT NULL default '',
  billing_suburb varchar(32) default NULL,
  billing_city varchar(32) NOT NULL default '',
  billing_postcode varchar(10) NOT NULL default '',
  billing_state varchar(32) default NULL,
  billing_country varchar(32) NOT NULL default '',
  billing_address_format_id int(5) NOT NULL default '0',
  payment_method varchar(128) NOT NULL default '',
  payment_module_code varchar(32) NOT NULL default '',
  shipping_method varchar(128) NOT NULL default '',
  shipping_module_code varchar(32) NOT NULL default '',
  coupon_code varchar(32) NOT NULL default '',
  cc_type varchar(20) default NULL,
  cc_owner varchar(64) default NULL,
  cc_number varchar(32) default NULL,
  cc_expires varchar(4) default NULL,
  cc_cvv blob,
  last_modified datetime default NULL,
  date_purchased datetime default NULL,
  orders_status int(5) NOT NULL default '0',
  orders_date_finished datetime default NULL,
  currency char(3) default NULL,
  currency_value decimal(14,6) default NULL,
  order_total decimal(14,2) default NULL,
  order_tax decimal(14,2) default NULL,
  paypal_ipn_id int(11) NOT NULL default '0',
  ip_address varchar(96) NOT NULL default '',
  PRIMARY KEY  (orders_id),
  KEY idx_status_orders_cust_zen (orders_status,orders_id,customers_id),
  KEY idx_date_purchased_zen (date_purchased)
) TYPE=MyISAM;


# --------------------------------------------------------

#
# Table structure for table 'orders_products'
#

DROP TABLE IF EXISTS orders_products;
CREATE TABLE orders_products (
  orders_products_id int(11) NOT NULL auto_increment,
  orders_id int(11) NOT NULL default '0',
  products_id int(11) NOT NULL default '0',
  products_model varchar(32) default NULL,
  products_name varchar(64) NOT NULL default '',
  products_price decimal(15,4) NOT NULL default '0.0000',
  final_price decimal(15,4) NOT NULL default '0.0000',
  products_tax decimal(7,4) NOT NULL default '0.0000',
  products_quantity float NOT NULL default '0',
  onetime_charges decimal(15,4) NOT NULL default '0.0000',
  products_priced_by_attribute tinyint(1) NOT NULL default '0',
  product_is_free tinyint(1) NOT NULL default '0',
  products_discount_type tinyint(1) NOT NULL default '0',
  products_discount_type_from tinyint(1) NOT NULL default '0',
  products_prid tinytext NOT NULL,
  PRIMARY KEY  (orders_products_id),
  KEY idx_orders_id_prod_id_zen (orders_id,products_id)
) TYPE=MyISAM;


# --------------------------------------------------------

#
# Table structure for table 'orders_products_attributes'
#

DROP TABLE IF EXISTS orders_products_attributes;
CREATE TABLE orders_products_attributes (
  orders_products_attributes_id int(11) NOT NULL auto_increment,
  orders_id int(11) NOT NULL default '0',
  orders_products_id int(11) NOT NULL default '0',
  products_options varchar(32) NOT NULL default '',
  products_options_values text NOT NULL,
  options_values_price decimal(15,4) NOT NULL default '0.0000',
  price_prefix char(1) NOT NULL default '',
  product_attribute_is_free tinyint(1) NOT NULL default '0',
  products_attributes_weight float NOT NULL default '0',
  products_attributes_weight_prefix char(1) NOT NULL default '',
  attributes_discounted tinyint(1) NOT NULL default '1',
  attributes_price_base_included tinyint(1) NOT NULL default '1',
  attributes_price_onetime decimal(15,4) NOT NULL default '0.0000',
  attributes_price_factor decimal(15,4) NOT NULL default '0.0000',
  attributes_price_factor_offset decimal(15,4) NOT NULL default '0.0000',
  attributes_price_factor_onetime decimal(15,4) NOT NULL default '0.0000',
  attributes_price_factor_onetime_offset decimal(15,4) NOT NULL default '0.0000',
  attributes_qty_prices text,
  attributes_qty_prices_onetime text,
  attributes_price_words decimal(15,4) NOT NULL default '0.0000',
  attributes_price_words_free int(4) NOT NULL default '0',
  attributes_price_letters decimal(15,4) NOT NULL default '0.0000',
  attributes_price_letters_free int(4) NOT NULL default '0',
  products_options_id int(11) NOT NULL default '0',
  products_options_values_id int(11) NOT NULL default '0',
  products_prid tinytext NOT NULL,
  PRIMARY KEY  (orders_products_attributes_id),
  KEY idx_orders_id_prod_id_zen (orders_id,orders_products_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'orders_products_download'
#

DROP TABLE IF EXISTS orders_products_download;
CREATE TABLE orders_products_download (
  orders_products_download_id int(11) NOT NULL auto_increment,
  orders_id int(11) NOT NULL default '0',
  orders_products_id int(11) NOT NULL default '0',
  orders_products_filename varchar(255) NOT NULL default '',
  download_maxdays int(2) NOT NULL default '0',
  download_count int(2) NOT NULL default '0',
  products_prid tinytext NOT NULL,
  PRIMARY KEY  (orders_products_download_id),
  KEY idx_orders_id_zen (orders_id),
  KEY idx_orders_products_id_zen (orders_products_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'orders_status'
#

DROP TABLE IF EXISTS orders_status;
CREATE TABLE orders_status (
  orders_status_id int(11) NOT NULL default '0',
  language_id int(11) NOT NULL default '1',
  orders_status_name varchar(32) NOT NULL default '',
  PRIMARY KEY  (orders_status_id,language_id),
  KEY idx_orders_status_name_zen (orders_status_name)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'orders_status_history'
#

DROP TABLE IF EXISTS orders_status_history;
CREATE TABLE orders_status_history (
  orders_status_history_id int(11) NOT NULL auto_increment,
  orders_id int(11) NOT NULL default '0',
  orders_status_id int(5) NOT NULL default '0',
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  customer_notified int(1) default '0',
  comments text,
  PRIMARY KEY  (orders_status_history_id),
  KEY idx_orders_id_status_id_zen (orders_id,orders_status_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'orders_total'
#

DROP TABLE IF EXISTS orders_total;
CREATE TABLE orders_total (
  orders_total_id int(10) unsigned NOT NULL auto_increment,
  orders_id int(11) NOT NULL default '0',
  title varchar(255) NOT NULL default '',
  text varchar(255) NOT NULL default '',
  value decimal(15,4) NOT NULL default '0.0000',
  class varchar(32) NOT NULL default '',
  sort_order int(11) NOT NULL default '0',
  PRIMARY KEY  (orders_total_id),
  KEY idx_ot_orders_id_zen (orders_id),
  KEY idx_ot_class_zen (class)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'paypal'
#

DROP TABLE IF EXISTS paypal;
CREATE TABLE paypal (
  paypal_ipn_id int(11) unsigned NOT NULL auto_increment,
  order_id int(11) unsigned NOT NULL default '0',
  txn_type varchar(40) NOT NULL default '',
  module_name varchar(40) NOT NULL default '',
  module_mode varchar(40) NOT NULL default '',
  reason_code varchar(40) default NULL,
  payment_type varchar(40) NOT NULL default '',
  payment_status varchar(32) NOT NULL default '',
  pending_reason varchar(32) default NULL,
  invoice varchar(128) default NULL,
  mc_currency char(3) NOT NULL default '',
  first_name varchar(32) NOT NULL default '',
  last_name varchar(32) NOT NULL default '',
  payer_business_name varchar(128) default NULL,
  address_name varchar(64) default NULL,
  address_street varchar(254) default NULL,
  address_city varchar(120) default NULL,
  address_state varchar(120) default NULL,
  address_zip varchar(10) default NULL,
  address_country varchar(64) default NULL,
  address_status varchar(11) default NULL,
  payer_email varchar(128) NOT NULL default '',
  payer_id varchar(32) NOT NULL default '',
  payer_status varchar(10) NOT NULL default '',
  payment_date datetime NOT NULL default '0001-01-01 00:00:00',
  business varchar(128) NOT NULL default '',
  receiver_email varchar(128) NOT NULL default '',
  receiver_id varchar(32) NOT NULL default '',
  txn_id varchar(20) NOT NULL default '',
  parent_txn_id varchar(20) default NULL,
  num_cart_items tinyint(4) unsigned NOT NULL default '1',
  mc_gross decimal(7,2) NOT NULL default '0.00',
  mc_fee decimal(7,2) NOT NULL default '0.00',
  payment_gross decimal(7,2) default NULL,
  payment_fee decimal(7,2) default NULL,
  settle_amount decimal(7,2) default NULL,
  settle_currency char(3) default NULL,
  exchange_rate decimal(4,2) default NULL,
  notify_version decimal(2,1) NOT NULL default '0.0',
  verify_sign varchar(128) NOT NULL default '',
  last_modified datetime NOT NULL default '0001-01-01 00:00:00',
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  memo text,
  PRIMARY KEY (paypal_ipn_id,txn_id),
  KEY idx_order_id_zen (order_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'paypal_payment_status'
#

DROP TABLE IF EXISTS paypal_payment_status;
CREATE TABLE paypal_payment_status (
  payment_status_id int(11) NOT NULL auto_increment,
  payment_status_name varchar(64) NOT NULL default '',
  PRIMARY KEY (payment_status_id)
) TYPE=MyISAM;

#
# Dumping data for table 'paypal_payment_status'
#

INSERT INTO paypal_payment_status VALUES (1, 'Completed');
INSERT INTO paypal_payment_status VALUES (2, 'Pending');
INSERT INTO paypal_payment_status VALUES (3, 'Failed');
INSERT INTO paypal_payment_status VALUES (4, 'Denied');
INSERT INTO paypal_payment_status VALUES (5, 'Refunded');
INSERT INTO paypal_payment_status VALUES (6, 'Canceled_Reversal');
INSERT INTO paypal_payment_status VALUES (7, 'Reversed');

# --------------------------------------------------------

#
# Table structure for table 'paypal_payment_status_history'
#

DROP TABLE IF EXISTS paypal_payment_status_history;
CREATE TABLE paypal_payment_status_history (
  payment_status_history_id int(11) NOT NULL auto_increment,
  paypal_ipn_id int(11) NOT NULL default '0',
  txn_id varchar(64) NOT NULL default '',
  parent_txn_id varchar(64) NOT NULL default '',
  payment_status varchar(17) NOT NULL default '',
  pending_reason varchar(14) default NULL,
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  PRIMARY KEY (payment_status_history_id),
  KEY idx_paypal_ipn_id_zen (paypal_ipn_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'paypal_session'
#

DROP TABLE IF EXISTS paypal_session;
CREATE TABLE paypal_session (
  unique_id int(11) NOT NULL auto_increment,
  session_id text NOT NULL,
  saved_session mediumblob NOT NULL,
  expiry int(17) NOT NULL default '0',
  PRIMARY KEY  (unique_id),
  KEY idx_session_id_zen (session_id(36))
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'paypal_testing'
#

DROP TABLE IF EXISTS paypal_testing;
CREATE TABLE paypal_testing (
  paypal_ipn_id int(11) unsigned NOT NULL auto_increment,
  order_id int(11) unsigned NOT NULL default '0',
  custom varchar(255) NOT NULL default '',
  txn_type varchar(40) NOT NULL default '',
  module_name varchar(40) NOT NULL default '',
  module_mode varchar(40) NOT NULL default '',
  reason_code varchar(40) default NULL,
  payment_type varchar(40) NOT NULL default '',
  payment_status varchar(32) NOT NULL default '',
  pending_reason varchar(32) default NULL,
  invoice varchar(128) default NULL,
  mc_currency char(3) NOT NULL default '',
  first_name varchar(32) NOT NULL default '',
  last_name varchar(32) NOT NULL default '',
  payer_business_name varchar(128) default NULL,
  address_name varchar(64) default NULL,
  address_street varchar(254) default NULL,
  address_city varchar(120) default NULL,
  address_state varchar(120) default NULL,
  address_zip varchar(10) default NULL,
  address_country varchar(64) default NULL,
  address_status varchar(11) default NULL,
  payer_email varchar(128) NOT NULL default '',
  payer_id varchar(32) NOT NULL default '',
  payer_status varchar(10) NOT NULL default '',
  payment_date datetime NOT NULL default '0001-01-01 00:00:00',
  business varchar(128) NOT NULL default '',
  receiver_email varchar(128) NOT NULL default '',
  receiver_id varchar(32) NOT NULL default '',
  txn_id varchar(20) NOT NULL default '',
  parent_txn_id varchar(20) default NULL,
  num_cart_items tinyint(4) unsigned NOT NULL default '1',
  mc_gross decimal(7,2) NOT NULL default '0.00',
  mc_fee decimal(7,2) NOT NULL default '0.00',
  payment_gross decimal(7,2) default NULL,
  payment_fee decimal(7,2) default NULL,
  settle_amount decimal(7,2) default NULL,
  settle_currency char(3) default NULL,
  exchange_rate decimal(4,2) default NULL,
  notify_version decimal(2,1) NOT NULL default '0.0',
  verify_sign varchar(128) NOT NULL default '',
  last_modified datetime NOT NULL default '0001-01-01 00:00:00',
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  memo text,
  PRIMARY KEY  (paypal_ipn_id,txn_id),
  KEY idx_order_id_zen (order_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'product_music_extra'
#

DROP TABLE IF EXISTS product_music_extra;
CREATE TABLE product_music_extra (
  products_id int(11) NOT NULL default '0',
  artists_id int(11) NOT NULL default '0',
  record_company_id int(11) NOT NULL default '0',
  music_genre_id int(11) NOT NULL default '0',
  PRIMARY KEY  (products_id),
  KEY idx_music_genre_id_zen (music_genre_id),
  KEY idx_artists_id_zen (artists_id),
  KEY idx_record_company_id_zen (record_company_id)
) TYPE=MyISAM;


# --------------------------------------------------------

#
# Table structure for table 'product_type_layout'
#
DROP TABLE IF EXISTS product_type_layout;
CREATE TABLE product_type_layout (
  configuration_id int(11) NOT NULL auto_increment,
  configuration_title text NOT NULL,
  configuration_key varchar(255) NOT NULL default '',
  configuration_value text NOT NULL,
  configuration_description text NOT NULL,
  product_type_id int(11) NOT NULL default '0',
  sort_order int(5) default NULL,
  last_modified datetime default NULL,
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  use_function text default NULL,
  set_function text default NULL,
  PRIMARY KEY  (configuration_id),
  UNIQUE KEY unq_config_key_zen (configuration_key),
  KEY idx_key_value_zen (configuration_key,configuration_value(10)),
  KEY idx_type_id_sort_order_zen (product_type_id,sort_order)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'product_types'
#

DROP TABLE IF EXISTS product_types;
CREATE TABLE product_types (
  type_id int(11) NOT NULL auto_increment,
  type_name varchar(255) NOT NULL default '',
  type_handler varchar(255) NOT NULL default '',
  type_master_type int(11) NOT NULL default '1',
  allow_add_to_cart char(1) NOT NULL default 'Y',
  default_image varchar(255) NOT NULL default '',
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  last_modified datetime NOT NULL default '0001-01-01 00:00:00',
  PRIMARY KEY  (type_id),
  KEY idx_type_master_type_zen (type_master_type)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'product_types_to_category'
#

DROP TABLE IF EXISTS product_types_to_category;
CREATE TABLE product_types_to_category (
  product_type_id int(11) NOT NULL default '0',
  category_id int(11) NOT NULL default '0',
  KEY idx_category_id_zen (category_id),
  KEY idx_product_type_id_zen (product_type_id)
) TYPE=MyISAM;


# --------------------------------------------------------

#
# Table structure for table 'products'
#

DROP TABLE IF EXISTS products;
CREATE TABLE products (
  products_id int(11) NOT NULL auto_increment,
  products_type int(11) NOT NULL default '1',
  products_quantity float NOT NULL default '0',
  products_model varchar(32) default NULL,
  products_image varchar(64) default NULL,
  products_price decimal(15,4) NOT NULL default '0.0000',
  products_virtual tinyint(1) NOT NULL default '0',
  products_date_added datetime NOT NULL default '0001-01-01 00:00:00',
  products_last_modified datetime default NULL,
  products_date_available datetime default NULL,
  products_weight float NOT NULL default '0',
  products_status tinyint(1) NOT NULL default '0',
  products_tax_class_id int(11) NOT NULL default '0',
  manufacturers_id int(11) default NULL,
  products_ordered float NOT NULL default '0',
  products_quantity_order_min float NOT NULL default '1',
  products_quantity_order_units float NOT NULL default '1',
  products_priced_by_attribute tinyint(1) NOT NULL default '0',
  product_is_free tinyint(1) NOT NULL default '0',
  product_is_call tinyint(1) NOT NULL default '0',
  products_quantity_mixed tinyint(1) NOT NULL default '0',
  product_is_always_free_shipping tinyint(1) NOT NULL default '0',
  products_qty_box_status tinyint(1) NOT NULL default '1',
  products_quantity_order_max float NOT NULL default '0',
  products_sort_order int(11) NOT NULL default '0',
  products_discount_type tinyint(1) NOT NULL default '0',
  products_discount_type_from tinyint(1) NOT NULL default '0',
  products_price_sorter decimal(15,4) NOT NULL default '0.0000',
  master_categories_id int(11) NOT NULL default '0',
  products_mixed_discount_quantity tinyint(1) NOT NULL default '1',
  metatags_title_status tinyint(1) NOT NULL default '0',
  metatags_products_name_status tinyint(1) NOT NULL default '0',
  metatags_model_status tinyint(1) NOT NULL default '0',
  metatags_price_status tinyint(1) NOT NULL default '0',
  metatags_title_tagline_status tinyint(1) NOT NULL default '0',
  PRIMARY KEY  (products_id),
  KEY idx_products_date_added_zen (products_date_added),
  KEY idx_products_status_zen (products_status),
  KEY idx_products_date_available_zen (products_date_available),
  KEY idx_products_ordered_zen (products_ordered),
  KEY idx_products_model_zen (products_model),
  KEY idx_products_price_sorter_zen (products_price_sorter),
  KEY idx_master_categories_id_zen (master_categories_id),
  KEY idx_products_sort_order_zen (products_sort_order),
  KEY idx_manufacturers_id_zen (manufacturers_id)
) TYPE=MyISAM;
# --------------------------------------------------------

#
# Table structure for table 'products_attributes'
#

DROP TABLE IF EXISTS products_attributes;
CREATE TABLE products_attributes (
  products_attributes_id int(11) NOT NULL auto_increment,
  products_id int(11) NOT NULL default '0',
  options_id int(11) NOT NULL default '0',
  options_values_id int(11) NOT NULL default '0',
  options_values_price decimal(15,4) NOT NULL default '0.0000',
  price_prefix char(1) NOT NULL default '',
  products_options_sort_order int(11) NOT NULL default '0',
  product_attribute_is_free tinyint(1) NOT NULL default '0',
  products_attributes_weight float NOT NULL default '0',
  products_attributes_weight_prefix char(1) NOT NULL default '',
  attributes_display_only tinyint(1) NOT NULL default '0',
  attributes_default tinyint(1) NOT NULL default '0',
  attributes_discounted tinyint(1) NOT NULL default '1',
  attributes_image varchar(64) default NULL,
  attributes_price_base_included tinyint(1) NOT NULL default '1',
  attributes_price_onetime decimal(15,4) NOT NULL default '0.0000',
  attributes_price_factor decimal(15,4) NOT NULL default '0.0000',
  attributes_price_factor_offset decimal(15,4) NOT NULL default '0.0000',
  attributes_price_factor_onetime decimal(15,4) NOT NULL default '0.0000',
  attributes_price_factor_onetime_offset decimal(15,4) NOT NULL default '0.0000',
  attributes_qty_prices text,
  attributes_qty_prices_onetime text,
  attributes_price_words decimal(15,4) NOT NULL default '0.0000',
  attributes_price_words_free int(4) NOT NULL default '0',
  attributes_price_letters decimal(15,4) NOT NULL default '0.0000',
  attributes_price_letters_free int(4) NOT NULL default '0',
  attributes_required tinyint(1) NOT NULL default '0',
  PRIMARY KEY  (products_attributes_id),
  KEY idx_id_options_id_values_zen (products_id,options_id,options_values_id),
  KEY idx_opt_sort_order_zen (products_options_sort_order)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'products_attributes_download'
#

DROP TABLE IF EXISTS products_attributes_download;
CREATE TABLE products_attributes_download (
  products_attributes_id int(11) NOT NULL default '0',
  products_attributes_filename varchar(255) NOT NULL default '',
  products_attributes_maxdays int(2) default '0',
  products_attributes_maxcount int(2) default '0',
  PRIMARY KEY  (products_attributes_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'products_description'
#

DROP TABLE IF EXISTS products_description;
CREATE TABLE products_description (
  products_id int(11) NOT NULL auto_increment,
  language_id int(11) NOT NULL default '1',
  products_name varchar(64) NOT NULL default '',
  products_description text,
  products_url varchar(255) default NULL,
  products_viewed int(5) default '0',
  PRIMARY KEY  (products_id,language_id),
  KEY idx_products_name_zen (products_name)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'products_discount_quantity'
#
DROP TABLE IF EXISTS products_discount_quantity;
CREATE TABLE products_discount_quantity (
  discount_id int(4) NOT NULL default '0',
  products_id int(11) NOT NULL default '0',
  discount_qty float NOT NULL default '0',
  discount_price decimal(15,4) NOT NULL default '0.0000',
  KEY idx_id_qty_zen (products_id,discount_qty)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'products_notifications'
#

DROP TABLE IF EXISTS products_notifications;
CREATE TABLE products_notifications (
  products_id int(11) NOT NULL default '0',
  customers_id int(11) NOT NULL default '0',
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  PRIMARY KEY  (products_id,customers_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'products_options'
#

DROP TABLE IF EXISTS products_options;
CREATE TABLE products_options (
  products_options_id int(11) NOT NULL default '0',
  language_id int(11) NOT NULL default '1',
  products_options_name varchar(32) NOT NULL default '',
  products_options_sort_order int(11) NOT NULL default '0',
  products_options_type int(5) NOT NULL default '0',
  products_options_length smallint(2) NOT NULL default '32',
  products_options_comment varchar(64) default NULL,
  products_options_size smallint(2) NOT NULL default '32',
  products_options_images_per_row int(2) default '5',
  products_options_images_style int(1) default '0',
  products_options_rows smallint(2) NOT NULL default '1',
  PRIMARY KEY  (products_options_id,language_id),
  KEY idx_lang_id_zen (language_id),
  KEY idx_products_options_sort_order_zen (products_options_sort_order),
  KEY idx_products_options_name_zen (products_options_name)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'products_options_types'
#

DROP TABLE IF EXISTS products_options_types;
CREATE TABLE products_options_types (
  products_options_types_id int(11) NOT NULL default '0',
  products_options_types_name varchar(32) default NULL,
  PRIMARY KEY  (products_options_types_id)
) TYPE=MyISAM COMMENT='Track products_options_types';

# --------------------------------------------------------

#
# Table structure for table 'products_options_values'
#

DROP TABLE IF EXISTS products_options_values;
CREATE TABLE products_options_values (
  products_options_values_id int(11) NOT NULL default '0',
  language_id int(11) NOT NULL default '1',
  products_options_values_name varchar(64) NOT NULL default '',
  products_options_values_sort_order int(11) NOT NULL default '0',
  PRIMARY KEY (products_options_values_id,language_id),
  KEY idx_products_options_values_name_zen (products_options_values_name),
  KEY idx_products_options_values_sort_order_zen (products_options_values_sort_order)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'products_options_values_to_products_options'
#

DROP TABLE IF EXISTS products_options_values_to_products_options;
CREATE TABLE products_options_values_to_products_options (
  products_options_values_to_products_options_id int(11) NOT NULL auto_increment,
  products_options_id int(11) NOT NULL default '0',
  products_options_values_id int(11) NOT NULL default '0',
  PRIMARY KEY  (products_options_values_to_products_options_id),
  KEY idx_products_options_id_zen (products_options_id),
  KEY idx_products_options_values_id_zen (products_options_values_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'products_to_categories'
#

DROP TABLE IF EXISTS products_to_categories;
CREATE TABLE products_to_categories (
  products_id int(11) NOT NULL default '0',
  categories_id int(11) NOT NULL default '0',
  PRIMARY KEY  (products_id,categories_id),
  KEY idx_cat_prod_id_zen (categories_id,products_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'project_version'
#

DROP TABLE IF EXISTS project_version;
CREATE TABLE project_version (
  project_version_id tinyint(3) NOT NULL auto_increment,
  project_version_key varchar(40) NOT NULL default '',
  project_version_major varchar(20) NOT NULL default '',
  project_version_minor varchar(20) NOT NULL default '',
  project_version_patch1 varchar(20) NOT NULL default '',
  project_version_patch2 varchar(20) NOT NULL default '',
  project_version_patch1_source varchar(20) NOT NULL default '',
  project_version_patch2_source varchar(20) NOT NULL default '',
  project_version_comment varchar(250) NOT NULL default '',
  project_version_date_applied datetime NOT NULL default '0001-01-01 01:01:01',
  PRIMARY KEY  (project_version_id),
  UNIQUE KEY idx_project_version_key_zen (project_version_key)
) TYPE=MyISAM COMMENT='Database Version Tracking';


# --------------------------------------------------------

#
# Table structure for table 'project_version_history'
#
DROP TABLE IF EXISTS project_version_history;
CREATE TABLE project_version_history (
  project_version_id tinyint(3) NOT NULL auto_increment,
  project_version_key varchar(40) NOT NULL default '',
  project_version_major varchar(20) NOT NULL default '',
  project_version_minor varchar(20) NOT NULL default '',
  project_version_patch varchar(20) NOT NULL default '',
  project_version_comment varchar(250) NOT NULL default '',
  project_version_date_applied datetime NOT NULL default '0001-01-01 01:01:01',
  PRIMARY KEY  (project_version_id)
) TYPE=MyISAM COMMENT='Database Version Tracking History';

# --------------------------------------------------------

#
# Table structure for table 'query_builder'
# This table is used by audiences.php for building data-extraction queries
#
DROP TABLE IF EXISTS query_builder;
CREATE TABLE query_builder (
  query_id int(11) NOT NULL auto_increment,
  query_category varchar(40) NOT NULL default '',
  query_name varchar(80) NOT NULL default '',
  query_description TEXT NOT NULL,
  query_string TEXT NOT NULL,
  query_keys_list TEXT NOT NULL,
  PRIMARY KEY  (query_id),
  UNIQUE KEY query_name (query_name)
) TYPE=MyISAM COMMENT='Stores queries for re-use in Admin email and report modules';

# --------------------------------------------------------

#
# Table structure for table 'record_artists'
#

DROP TABLE IF EXISTS record_artists;
CREATE TABLE record_artists (
  artists_id int(11) NOT NULL auto_increment,
  artists_name varchar(32) NOT NULL default '',
  artists_image varchar(64) default NULL,
  date_added datetime default NULL,
  last_modified datetime default NULL,
  PRIMARY KEY  (artists_id),
  KEY idx_rec_artists_name_zen (artists_name)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'record_artists_info'
#

DROP TABLE IF EXISTS record_artists_info;
CREATE TABLE record_artists_info (
  artists_id int(11) NOT NULL default '0',
  languages_id int(11) NOT NULL default '0',
  artists_url varchar(255) NOT NULL default '',
  url_clicked int(5) NOT NULL default '0',
  date_last_click datetime default NULL,
  PRIMARY KEY  (artists_id,languages_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'record_company'
#

DROP TABLE IF EXISTS record_company;
CREATE TABLE record_company (
  record_company_id int(11) NOT NULL auto_increment,
  record_company_name varchar(32) NOT NULL default '',
  record_company_image varchar(64) default NULL,
  date_added datetime default NULL,
  last_modified datetime default NULL,
  PRIMARY KEY  (record_company_id),
  KEY idx_rec_company_name_zen (record_company_name)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'record_company_info'
#

DROP TABLE IF EXISTS record_company_info;
CREATE TABLE record_company_info (
  record_company_id int(11) NOT NULL default '0',
  languages_id int(11) NOT NULL default '0',
  record_company_url varchar(255) NOT NULL default '',
  url_clicked int(5) NOT NULL default '0',
  date_last_click datetime default NULL,
  PRIMARY KEY  (record_company_id,languages_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'reviews'
#

DROP TABLE IF EXISTS reviews;
CREATE TABLE reviews (
  reviews_id int(11) NOT NULL auto_increment,
  products_id int(11) NOT NULL default '0',
  customers_id int(11) default NULL,
  customers_name varchar(64) NOT NULL default '',
  reviews_rating int(1) default NULL,
  date_added datetime default NULL,
  last_modified datetime default NULL,
  reviews_read int(5) NOT NULL default '0',
  status int(1) NOT NULL default '1',
  PRIMARY KEY  (reviews_id),
  KEY idx_products_id_zen (products_id),
  KEY idx_customers_id_zen (customers_id),
  KEY idx_status_zen (status),
  KEY idx_date_added_zen (date_added)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'reviews_description'
#

DROP TABLE IF EXISTS reviews_description;
CREATE TABLE reviews_description (
  reviews_id int(11) NOT NULL default '0',
  languages_id int(11) NOT NULL default '0',
  reviews_text text NOT NULL,
  PRIMARY KEY  (reviews_id,languages_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'salemaker_sales'
#

DROP TABLE IF EXISTS salemaker_sales;
CREATE TABLE salemaker_sales (
  sale_id int(11) NOT NULL auto_increment,
  sale_status tinyint(4) NOT NULL default '0',
  sale_name varchar(30) NOT NULL default '',
  sale_deduction_value decimal(15,4) NOT NULL default '0.0000',
  sale_deduction_type tinyint(4) NOT NULL default '0',
  sale_pricerange_from decimal(15,4) NOT NULL default '0.0000',
  sale_pricerange_to decimal(15,4) NOT NULL default '0.0000',
  sale_specials_condition tinyint(4) NOT NULL default '0',
  sale_categories_selected text,
  sale_categories_all text,
  sale_date_start date NOT NULL default '0001-01-01',
  sale_date_end date NOT NULL default '0001-01-01',
  sale_date_added date NOT NULL default '0001-01-01',
  sale_date_last_modified date NOT NULL default '0001-01-01',
  sale_date_status_change date NOT NULL default '0001-01-01',
  PRIMARY KEY  (sale_id),
  KEY idx_sale_status_zen (sale_status),
  KEY idx_sale_date_start_zen (sale_date_start),
  KEY idx_sale_date_end_zen (sale_date_end)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'sessions'
#

DROP TABLE IF EXISTS sessions;
CREATE TABLE sessions (
  sesskey varchar(32) NOT NULL default '',
  expiry int(11) unsigned NOT NULL default '0',
  value mediumblob NOT NULL,
  PRIMARY KEY  (sesskey)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'specials'
#

DROP TABLE IF EXISTS specials;
CREATE TABLE specials (
  specials_id int(11) NOT NULL auto_increment,
  products_id int(11) NOT NULL default '0',
  specials_new_products_price decimal(15,4) NOT NULL default '0.0000',
  specials_date_added datetime default NULL,
  specials_last_modified datetime default NULL,
  expires_date date NOT NULL default '0001-01-01',
  date_status_change datetime default NULL,
  status int(1) NOT NULL default '1',
  specials_date_available date NOT NULL default '0001-01-01',
  PRIMARY KEY  (specials_id),
  KEY idx_status_zen (status),
  KEY idx_products_id_zen (products_id),
  KEY idx_date_avail_zen (specials_date_available),
  KEY idx_expires_date_zen (expires_date)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'tax_class'
#

DROP TABLE IF EXISTS tax_class;
CREATE TABLE tax_class (
  tax_class_id int(11) NOT NULL auto_increment,
  tax_class_title varchar(32) NOT NULL default '',
  tax_class_description varchar(255) NOT NULL default '',
  last_modified datetime default NULL,
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  PRIMARY KEY  (tax_class_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'tax_rates'
#

DROP TABLE IF EXISTS tax_rates;
CREATE TABLE tax_rates (
  tax_rates_id int(11) NOT NULL auto_increment,
  tax_zone_id int(11) NOT NULL default '0',
  tax_class_id int(11) NOT NULL default '0',
  tax_priority int(5) default '1',
  tax_rate decimal(7,4) NOT NULL default '0.0000',
  tax_description varchar(255) NOT NULL default '',
  last_modified datetime default NULL,
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  PRIMARY KEY  (tax_rates_id),
  KEY idx_tax_zone_id_zen (tax_zone_id),
  KEY idx_tax_class_id_zen (tax_class_id)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'template_select'
#

DROP TABLE IF EXISTS template_select;
CREATE TABLE template_select (
  template_id int(11) NOT NULL auto_increment,
  template_dir varchar(64) NOT NULL default '',
  template_language varchar(64) NOT NULL default '0',
  PRIMARY KEY  (template_id),
  KEY idx_tpl_lang_zen (template_language)
) TYPE=MyISAM;

# --------------------------------------------------------


#
# Table structure for table 'whos_online'
#

DROP TABLE IF EXISTS whos_online;
CREATE TABLE whos_online (
  customer_id int(11) default NULL,
  full_name varchar(64) NOT NULL default '',
  session_id varchar(128) NOT NULL default '',
  ip_address varchar(15) NOT NULL default '',
  time_entry varchar(14) NOT NULL default '',
  time_last_click varchar(14) NOT NULL default '',
  last_page_url varchar(255) NOT NULL default '',
  host_address text NOT NULL,
  user_agent varchar(255) NOT NULL default '',
  KEY idx_ip_address_zen (ip_address),
  KEY idx_session_id_zen (session_id),
  KEY idx_customer_id_zen (customer_id),
  KEY idx_time_entry_zen (time_entry),
  KEY idx_time_last_click_zen (time_last_click),
  KEY idx_last_page_url_zen (last_page_url)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'zones'
#

DROP TABLE IF EXISTS zones;
CREATE TABLE zones (
  zone_id int(11) NOT NULL auto_increment,
  zone_country_id int(11) NOT NULL default '0',
  zone_code varchar(32) NOT NULL default '',
  zone_name varchar(32) NOT NULL default '',
  PRIMARY KEY  (zone_id),
  KEY idx_zone_country_id_zen (zone_country_id),
  KEY idx_zone_code_zen (zone_code)
) TYPE=MyISAM;

# --------------------------------------------------------

#
# Table structure for table 'zones_to_geo_zones'
#

DROP TABLE IF EXISTS zones_to_geo_zones;
CREATE TABLE zones_to_geo_zones (
  association_id int(11) NOT NULL auto_increment,
  zone_country_id int(11) NOT NULL default '0',
  zone_id int(11) default NULL,
  geo_zone_id int(11) default NULL,
  last_modified datetime default NULL,
  date_added datetime NOT NULL default '0001-01-01 00:00:00',
  PRIMARY KEY  (association_id),
  KEY idx_zones_zen (geo_zone_id,zone_country_id,zone_id)
) TYPE=MyISAM;


#
# Database table for customers_wishlist
#

DROP TABLE IF EXISTS customers_wishlist;
CREATE TABLE customers_wishlist (
  products_id int(13) NOT NULL default '0',
  customers_id int(13) NOT NULL default '0',
  products_model varchar(13) default NULL,
  products_name varchar(64) NOT NULL default '',
  products_price decimal(8,2) NOT NULL default '0.00',
  final_price decimal(8,2) NOT NULL default '0.00',
  products_quantity int(2) NOT NULL default '0',
  wishlist_name varchar(64) default NULL
) TYPE=MyISAM;


















# data
INSERT INTO template_select VALUES (1, 'classic', '0');

# 1 - Default, 2 - USA, 3 - Spain, 4 - Singapore, 5 - Germany, 6 - UK/GB
INSERT INTO address_format VALUES (1, '$firstname $lastname$cr$streets$cr$city, $postcode$cr$statecomma$country','$city / $country');
INSERT INTO address_format VALUES (2, '$firstname $lastname$cr$streets$cr$city, $state    $postcode$cr$country','$city, $state / $country');
INSERT INTO address_format VALUES (3, '$firstname $lastname$cr$streets$cr$city$cr$postcode - $statecomma$country','$state / $country');
INSERT INTO address_format VALUES (4, '$firstname $lastname$cr$streets$cr$city ($postcode)$cr$country', '$postcode / $country');
INSERT INTO address_format VALUES (5, '$firstname $lastname$cr$streets$cr$postcode $city$cr$country','$city / $country');
INSERT INTO address_format VALUES (6, '$firstname $lastname$cr$streets$cr$city$cr$state$cr$postcode$cr$country','$postcode / $country');

INSERT INTO admin VALUES (1, 'Admin', 'admin@localhost', '351683ea4e19efe34874b501fdbf9792:9b', 1);

INSERT INTO banners (banners_title, banners_url, banners_image, banners_group, banners_html_text, expires_impressions, expires_date, date_scheduled, date_added, date_status_change, status, banners_open_new_windows, banners_on_ssl, banners_sort_order) VALUES ('Zen Cart', 'http://www.zen-cart.com', 'banners/zencart_468_60_02.gif', 'Wide-Banners', '', 0, NULL, NULL, '2004-01-11 20:59:12', NULL, 1, 1, 1, 0);
INSERT INTO banners (banners_title, banners_url, banners_image, banners_group, banners_html_text, expires_impressions, expires_date, date_scheduled, date_added, date_status_change, status, banners_open_new_windows, banners_on_ssl, banners_sort_order) VALUES ('Zen Cart the art of e-commerce', 'http://www.zen-cart.com', 'banners/125zen_logo.gif', 'SideBox-Banners', '', 0, NULL, NULL, '2004-01-11 20:59:12', NULL, 1, 1, 1, 0);
INSERT INTO banners (banners_title, banners_url, banners_image, banners_group, banners_html_text, expires_impressions, expires_date, date_scheduled, date_added, date_status_change, status, banners_open_new_windows, banners_on_ssl, banners_sort_order) VALUES ('Zen Cart the art of e-commerce', 'http://www.zen-cart.com', 'banners/125x125_zen_logo.gif', 'SideBox-Banners', '', 0, NULL, NULL, '2004-01-11 20:59:12', NULL, 1, 1, 1, 0);
INSERT INTO banners (banners_title, banners_url, banners_image, banners_group, banners_html_text, expires_impressions, expires_date, date_scheduled, date_added, date_status_change, status, banners_open_new_windows, banners_on_ssl, banners_sort_order) VALUES ('if you have to think ... you haven''t been Zenned!', 'http://www.zen-cart.com', 'banners/think_anim.gif', 'Wide-Banners', '', 0, NULL, NULL, '2004-01-12 20:53:18', NULL, 1, 1, 1, 0);
#INSERT INTO banners (banners_title, banners_url, banners_image, banners_group, banners_html_text, expires_impressions, expires_date, date_scheduled, date_added, date_status_change, status, banners_open_new_windows, banners_on_ssl, banners_sort_order) VALUES ('Sashbox.net - the ultimate e-commerce hosting solution', 'http://www.sashbox.net/zencart/', 'banners/sashbox_125x50.jpg', 'BannersAll', '', 0, NULL, NULL, '2005-05-13 10:53:50', NULL, 1, 1, 1, 20);
INSERT INTO banners (banners_title, banners_url, banners_image, banners_group, banners_html_text, expires_impressions, expires_date, date_scheduled, date_added, date_status_change, status, banners_open_new_windows, banners_on_ssl, banners_sort_order) VALUES ('Zen Cart the art of e-commerce', 'http://www.zen-cart.com', 'banners/bw_zen_88wide.gif', 'BannersAll', '', 0, NULL, NULL, '2005-05-13 10:54:38', NULL, 1, 1, 1, 10);
#INSERT INTO banners (banners_title, banners_url, banners_image, banners_group, banners_html_text, expires_impressions, expires_date, date_scheduled, date_added, date_status_change, status, banners_open_new_windows, banners_on_ssl, banners_sort_order) VALUES ('Sashbox.net - the ultimate e-commerce hosting solution', 'http://www.sashbox.net/zencart/', 'banners/sashbox_468x60.jpg', 'Wide-Banners', '', 0, NULL, NULL, '2005-05-13 10:55:11', NULL, 1, 1, 1, 0);
INSERT INTO banners (banners_title, banners_url, banners_image, banners_group, banners_html_text, expires_impressions, expires_date, date_scheduled, date_added, date_status_change, status, banners_open_new_windows, banners_on_ssl, banners_sort_order) VALUES ('Start Accepting Credit Cards For Your Business Today!', 'http://www.zen-cart.com/index.php?main_page=infopages&pages_id=30', 'banners/cardsvcs_468x60.gif', 'Wide-Banners', '', 0, NULL, NULL, '2006-03-13 11:02:43', NULL, 1, 1, 1, 0);
INSERT INTO banners (banners_title, banners_url, banners_image, banners_group, banners_html_text, expires_impressions, expires_date, date_scheduled, date_added, date_status_change, status, banners_open_new_windows, banners_on_ssl, banners_sort_order) VALUES ('eStart Your Web Store with Zen Cart(tm)', 'http://www.lulu.com/content/466605', 'banners/big-book-ad.gif', 'Wide-Banners', '', '0', NULL, NULL, '2007-02-10 00:00:00',NULL,'1','1','1','1');
INSERT INTO banners (banners_title, banners_url, banners_image, banners_group, banners_html_text, expires_impressions, expires_date, date_scheduled, date_added, date_status_change, status, banners_open_new_windows, banners_on_ssl, banners_sort_order) VALUES ('eStart Your Web Store with Zen Cart(tm)', 'http://www.lulu.com/content/466605', 'banners/tall-book.gif', 'SideBox-Banners', '', '0', NULL, NULL, '2007-02-10 00:00:00',NULL,'1','1','1','1');
INSERT INTO banners (banners_title, banners_url, banners_image, banners_group, banners_html_text, expires_impressions, expires_date, date_scheduled, date_added, date_status_change, status, banners_open_new_windows, banners_on_ssl, banners_sort_order) VALUES ('eStart Your Web Store with Zen Cart(tm)', 'http://www.lulu.com/content/466605', 'banners/tall-book.gif', 'BannersAll', '', '0', NULL, NULL, '2007-02-10 00:00:00',NULL,'1','1','1','15');


INSERT INTO configuration VALUES (1, 'Nom de la boutique', 'STORE_NAME', 'Ma boutique ecommerce', 'Le nom de ma boutique', 1, 1, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (2, 'Propri&eacute;taire de la boutique', 'STORE_OWNER', 'Damien', 'Le nom du propri&eacute;taire de la boutique', 1, 2, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (3, 'Pays', 'STORE_COUNTRY', '73', 'Le pays dans lequel se trouve ma boutique <br /><br /><strong>Note: Pensez &agrave; mettre &agrave; jour la Zone de la boutique egalement.</strong>', 1, 6, NULL, '2007-11-04 19:39:58', 'zen_get_country_name', 'zen_cfg_pull_down_country_list(');
INSERT INTO configuration VALUES (4, 'Zone', 'STORE_ZONE', '', 'La zone dans laquelle se trouve ma boutique', 1, 7, '2008-02-22 21:02:36', '2007-11-04 19:39:58', 'zen_cfg_get_zone_name', 'zen_cfg_pull_down_zone_list(');
INSERT INTO configuration VALUES (5, 'Produits  venir : Ordre de classement', 'EXPECTED_PRODUCTS_SORT', 'desc', 'Type de classement utilis&eacute; pour la boite de produits  venir (en stock prochainement) : <br />desc pour descendant ou asc pour ascendant.', 1, 8, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''asc'', ''desc''), ');
INSERT INTO configuration VALUES (6, 'Produits  venir : Champ de classement', 'EXPECTED_PRODUCTS_FIELD', 'date_expected', 'La colonne qui servira &agrave; classer les produits  venir. Choisissez entre :\r\n<br /><br />\r\n- products_name : pour classer les produits  venir par leurs noms,\r\n<br />\r\n- date_expected : pour classer les produits  venir par leurs dates prvisionnelles d''entre dans le catalogue.\r\n', 1, 9, '2008-02-28 12:03:34', '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''products_name'', ''date_expected''), ');
INSERT INTO configuration VALUES (7, 'Utiliser la devise de la langue par d&eacute;faut', 'USE_DEFAULT_LANGUAGE_CURRENCY', 'false', 'Passer automatiquement sur la devise de la langue par d&eacute;faut', 1, 10, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (8, 'S&eacute;lecteur de langue', 'LANGUAGE_DEFAULT_SELECTOR', 'Default', 'Est-ce que la langue par d&eacute;faut de la boutique doit etre base sur la configuration Admin, ou sur la langue du navigateur du client?\r\n<br /><br />Valeur par d&eacute;faut: Configuration de langue Admin', 1, 11, '2007-11-16 18:46:41', '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''Default'', ''Browser''), ');
INSERT INTO configuration VALUES (9, 'Utiliser la r&eacute;ecriture des URLs (encore en d&eacute;veloppement)', 'SEARCH_ENGINE_FRIENDLY_URLS', 'false', 'Utiliser la r&eacute;ecriture d''URLS pour les moteurs de recherche (en cours de d&eacute;veloppement)', 6, 12, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (10, 'Afficher le panier apr&egrave;s l''ajout d''un produit', 'DISPLAY_CART', 'true', 'Afficher le contenu du Panier apr&egrave;s l''ajout d''un produit dans celui-ci (ou retourner &agrave; la page d''origine)', 1, 14, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (11, 'Op&eacute;rateur de recherche par d&eacute;faut', 'ADVANCED_SEARCH_DEFAULT_OPERATOR', 'and', 'Op&eacute;rateur de recherche par d&eacute;faut (and = ET, or = OU)', 1, 17, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''and'', ''or''), ');
INSERT INTO configuration VALUES (12, 'Adresse et t&eacute;l&eacute;phone de la boutique', 'STORE_NAME_ADDRESS', 'Ma boutique\r\n75 rue de ma boutique\r\n75000 Ma ville', 'Ceci est le nom de la boutique, son adresse et son num&eacute;ro de t&eacute;lephone. Il sont utilis&eacute;s sur les documents &agrave; imprimer et sur le site pour pouvoir vous contacter.', 1, 18, '2008-03-05 11:03:45', '2007-11-04 19:39:58', NULL, 'zen_cfg_textarea(');
INSERT INTO configuration VALUES (13, 'Affiche les compteurs de cat&eacute;gorie', 'SHOW_COUNTS', 'true', 'Compte r&eacute;cursivement combien de produits se trouvent dans chaque cat&eacute;gorie', 1, 19, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (14, 'Arrondir Taxe', 'TAX_DECIMAL_PLACES', '0', 'Arrondir la valeur des taxes  cette dcimale', 1, 20, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (15, 'Affiche les prix avec Taxes', 'DISPLAY_PRICE_WITH_TAX', 'true', 'Affiche les prix TTC (true) ou ajoute la TVA &agrave; la fin (false)', 1, 21, '2008-02-25 14:04:59', '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (16, 'Affiche les prix TTC dans l''Administration', 'DISPLAY_PRICE_WITH_TAX_ADMIN', 'false', 'Affiche les prix en TTC (true) or ou ajoute la TVA a la fin (false) pour l''administration (Factures etc)', 1, 21, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (17, 'Base des taxes sur produits', 'STORE_PRODUCT_TAX_BASIS', 'Shipping', 'La base sur laquelle les taxes sont calcules. Les options sont<br />Shipping - Bases sur l''adresse de livraison du client<br />Billing - Bases sur l''adresse de facturation du client<br />Store - Bases sur l''adresse de la boutique si la zone de livraison/facturation est la mme que la zone de la boutique', 1, 21, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''Shipping'', ''Billing'', ''Store''), ');
INSERT INTO configuration VALUES (18, 'Base des taxes de livraison', 'STORE_SHIPPING_TAX_BASIS', 'Shipping', 'Base sur laquelle les taxes de lviraison sont calcules. Les options sont <br />Shipping - Bases sur l''adresse de livraison du client<br />Billing - Bases sur l''adresse de facturation du client<br />Store - Bases sur l''adresse de la boutique si la zone de facturation/livraison est la mme que celle de la boutique - Peut tre cras avec un module de livraison bien crit', 1, 21, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''Shipping'', ''Billing'', ''Store''), ');
INSERT INTO configuration VALUES (19, 'Etat d''affichage des taxes', 'STORE_TAX_DISPLAY_STATUS', '0', 'Toujours afficher les taxes mme si le total est $0.00?<br />0= Non<br />1= Oui', 1, 21, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (20, 'Dure de Session Admin en secondes', 'SESSION_TIMEOUT_ADMIN', '3600', 'Entrez le nombre en secondes. Par dfaut=3600<br />Exemple: 3600= 1 heure<br /><br />Note: un dlai trop court peut amener  des dconnexions quand vous ajoutez/modifiez des produits', 1, 40, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (21, 'max_execution_time pour les processus Admin', 'GLOBAL_SET_TIME_LIMIT', '60', 'Entrez le temps en secondes du max_execution_time des processus (temps d''execution maximum). Dfaut=60<br />Exemple: 60= 1 minute<br /><br />Note: Le changement de cette limite de temps est seulement ncessaire si vous avez des problmes avec le teps d''excution d''une tche', 1, 42, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (22, 'Afficher les mises  jour disponibles', 'SHOW_VERSION_UPDATE_IN_HEADER', 'true', 'Vrifie automatiquement si une nouvelle version de Zen Cart est disponible. Activer cette options peut parfois ralentir le chargement de vos pages Admin. (S''affiche sur la page d''accueil principale, et la page Infos serveur.)', 1, 44, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (23, 'Etat de la boutique', 'STORE_STATUS', '0', 'Le mode de fonctionnement de la boutique<br />0= Boutique normale<br />1= Catalogue sans prix<br />2= Catalogue avec prix', 1, 25, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2''), ');
INSERT INTO configuration VALUES (24, 'Uptime du serveur', 'DISPLAY_SERVER_UPTIME', 'true', 'L''affichage de temps de fonctionnement du serveur peut provoquer des entres dans lesl ogs d''erreurs de certains serveurs. (true = Affiche, false = n''affiche pas)', 1, 46, '2003-11-08 20:24:47', '0001-01-01 00:00:00', '', 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (25, 'Vrification des pages manquantes', 'MISSING_PAGE_CHECK', 'Page Not Found', 'La boutique peut vrifier les pages manquantes dans l''URL et rediriger vers la page d''accueil. Pour dbugguer, vous devrez dsactiver cela. <br /><br /><strong>Par dfaut=On</strong><br />On = Envoie les pages manquantes vers ''index''<br />Off = Ne vrifie pas les pages manquantes<br />Page Not Found = Affiche la Page-Not-Found (page non trouve)', 1, 48, '2003-11-08 20:24:47', '0001-01-01 00:00:00', '', 'zen_cfg_select_option(array(''On'', ''Off'', ''Page Not Found''),');
INSERT INTO configuration VALUES (26, 'Etat du proxy cURL', 'CURL_PROXY_REQUIRED', 'False', 'Est-ce que votre serveur ncessite l''utilisation d''un proxy pour les communications cURL ?', 1, 50, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (27, 'Adresse proxy cURL', 'CURL_PROXY_SERVER_DETAILS', '', 'If you have GoDaddy hosting or other hosting services that require use of a proxy to talk to external sites via cURL, enter their proxy address here.<br />format: address:port<br />ie: for GoDaddy, enter: <strong>proxy.shr.secureserver.net:3128</strong> or possibly 64.202.165.130:3128', 1, 51, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (28, 'Editeur HTML', 'HTML_EDITOR_PREFERENCE', 'HTMLAREA', 'Veuillez choisir l''diteur de HTML/Rich-Text que vous souhaitez utiliser pour crire les emails Admin, newsletters, et descriptions des produits', 1, 110, '2007-11-16 11:15:52', '2007-11-04 19:39:58', NULL, 'zen_cfg_pull_down_htmleditors(');
INSERT INTO configuration VALUES (29, 'Activer le lien PhpBB?', 'PHPBB_LINKS_ENABLED', 'false', 'Est-ce que la boutique doit synchroniser les infos des nouveaux comptes avec un forum phpBB (dj install)?', 1, 120, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (30, 'Affiche le nombre des catgories - Admin', 'SHOW_COUNTS_ADMIN', 'true', 'Affiche le compteur des catgories dans l''Admin?', 1, 19, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (31, 'Ratio de conversion de devise', 'CURRENCY_UPLIFT_RATIO', '1.05', 'Lors de la mise  jour auto des devises, quel ratio "uplift" doit tre utilis pour calculer le taux de change utilis par votre boutique?<br />ex: le taux de banque vient des serveurs de change-devises; combien d''extra voulez-vous prendre sur les commandes pour combler la diffrence entre le taux de banque et le taux du consommateur?<br /><br /><strong>Par dfaut: 1.05 </strong><br />Cela entrainera la multiplication du taux de banque par  1.05 pour tablir les taux de devise dans votre boutique.', 1, 55, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (32, 'Prnom', 'ENTRY_FIRST_NAME_MIN_LENGTH', '2', 'Longueur minimum du prnom', 2, 1, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (33, 'Nom', 'ENTRY_LAST_NAME_MIN_LENGTH', '2', 'Longueur minimum du nom', 2, 2, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (34, 'Date de naissance', 'ENTRY_DOB_MIN_LENGTH', '10', 'Longueur minimum de la date de naissance', 2, 3, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (35, 'Adresse E-Mail', 'ENTRY_EMAIL_ADDRESS_MIN_LENGTH', '6', 'Longueur minimum de l''adresse E-mail', 2, 4, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (36, 'Adresse postale', 'ENTRY_STREET_ADDRESS_MIN_LENGTH', '5', 'Longueur minimum de l''adresse postale', 2, 5, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (37, 'Socit', 'ENTRY_COMPANY_MIN_LENGTH', '0', 'Longueur minimum du nom de la socit', 2, 6, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (38, 'Code postal', 'ENTRY_POSTCODE_MIN_LENGTH', '4', 'Longueur minimum du code postal', 2, 7, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (39, 'Ville', 'ENTRY_CITY_MIN_LENGTH', '3', 'Longueur minimum de la ville', 2, 8, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (40, 'Etat', 'ENTRY_STATE_MIN_LENGTH', '2', 'Longueur minimum de l''tat', 2, 9, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (41, 'Numro de tlphone', 'ENTRY_TELEPHONE_MIN_LENGTH', '3', 'Longueur minimum du numro de tlphone', 2, 10, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (42, 'Mot de passe', 'ENTRY_PASSWORD_MIN_LENGTH', '5', 'Longueur minimum du mot de passe', 2, 11, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (43, 'Nom du propritaire de la carte bancaire', 'CC_OWNER_MIN_LENGTH', '3', 'Longueur minimum du nom du propritaire de la CB', 2, 12, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (44, 'Numro de Carte Bancaire', 'CC_NUMBER_MIN_LENGTH', '10', 'Longueur minimum du numro de Carte Bancaire', 2, 13, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (45, 'Numro CVV de Carte Bancaire', 'CC_CVV_MIN_LENGTH', '3', 'Longueur minimum du numro CVV de la carte bancaire', 2, 13, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (46, 'Texte de l''avis sur un produit', 'REVIEW_TEXT_MIN_LENGTH', '50', 'Longueur minimum du texte de l''avis sur un produit', 2, 14, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (47, 'Meilleures ventes', 'MIN_DISPLAY_BESTSELLERS', '1', 'Nombre minimum de meilleures ventes  afficher', 2, 15, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (48, 'Produits galement achets', 'MIN_DISPLAY_ALSO_PURCHASED', '1', 'Nombre minimum de produits  afficher dans la boite ''Ce client a aussi achet''', 2, 16, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (49, 'Pseudo', 'ENTRY_NICK_MIN_LENGTH', '3', 'Longueur minimum du pseudo', 2, 1, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (50, 'Entres du carnet d''adresses', 'MAX_ADDRESS_BOOK_ENTRIES', '5', 'Nombre maximum d''adresses qu''un client peut avoir dans son carnet d''adresses', 3, 1, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (51, 'Rsultats de recherche par page', 'MAX_DISPLAY_SEARCH_RESULTS', '20', 'Nombre de produits  afficher sur une page de rsultat de recherche', 3, 2, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (52, 'Liens de navigation Prec/Suiv', 'MAX_DISPLAY_PAGE_LINKS', '5', 'Nombre de liens de ''nombres'' utilis sur les pages', 3, 3, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (53, 'Produits en promotion', 'MAX_DISPLAY_SPECIAL_PRODUCTS', '9', 'Nombre de produits en promotion  afficher', 3, 4, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (54, 'Module nouveaux produits', 'MAX_DISPLAY_NEW_PRODUCTS', '9', 'Nombre de nouveaux produits  afficher dans une catgorie', 3, 5, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (55, 'Produits  venir', 'MAX_DISPLAY_UPCOMING_PRODUCTS', '10', 'Nombre de produits '' venir''  afficher', 3, 6, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (56, 'Liste des fabricants - Taille/style de la liste droulante', 'MAX_MANUFACTURERS_LIST', '3', 'Nombre de fabricants  afficher dans la liste droulante. Mettre ceci  1 ou 0 affichera une liste droulante', 3, 7, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (57, 'Liste de fabricants - Vrifie l''existence du produit', 'PRODUCTS_MANUFACTURERS_STATUS', '1', 'Vrifie qu''au moins 1 produit existe et est actif pour le fabricant affich<br /><br />Note: Quand cette option est active, cela peut ralentir les rsultats du site avec un grand nombre de produits et/ou fabricants<br />0= off 1= on', 3, 7, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (58, 'Liste genre de musique - Style/taille de liste droulante', 'MAX_MUSIC_GENRES_LIST', '3', 'Nombre de genre de musique  afficher dans la fentre de liste droulante. Mettre cette option  1 or 0 affichera une liste droulante.', 3, 7, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (59, 'Liste de maisons de disque - Style/taille de liste droulante', 'MAX_RECORD_COMPANY_LIST', '3', 'Nombre de maisons de disque  afficher dans la fentre de liste droulante. Mettre  1 or 0 affichera une liste droulante.', 3, 7, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (60, 'Longueur du nom de maison de disque', 'MAX_DISPLAY_RECORD_COMPANY_NAME_LEN', '15', 'Utilis dans la liste des maisons de disque; longueur maximum du nom des maisons de disque  afficher. Les noms plus longs seront coups.', 3, 8, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (61, 'Longueur du genre de musique', 'MAX_DISPLAY_MUSIC_GENRES_NAME_LEN', '15', 'Utilis dans la boite des genres de musiques; longueur maximum des genres de musiques  afficher. Les noms plus longs seront coups.', 3, 8, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (62, 'Longueur du nom des fabricants', 'MAX_DISPLAY_MANUFACTURER_NAME_LEN', '15', 'Utilis pour la boite fabricants; longueur maximum du nom des fabricants  afficher. Les noms plus longs seront coups.', 3, 8, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (63, 'Nouveaux avis de produits par page', 'MAX_DISPLAY_NEW_REVIEWS', '6', 'Nombre de nouveaux avis  afficher sur chaque page', 3, 9, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (64, 'Commentaires sur les produits pour la boite latrale', 'MAX_RANDOM_SELECT_REVIEWS', '1', 'Le nombre de commentaires sur les produits qui doit tre affich au hasard en rotation dans la boite latrale<br /><br />Entrez ici le nombre de produits  afficher dans cette boite latrale en mme temps.<br /><br />Combien de produits voulez-vous afficher dans cette boite latrale?', 3, 10, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (65, 'Nouveaux produits dans la boite latrale', 'MAX_RANDOM_SELECT_NEW', '1', 'Ceci est le nombre de nouveaux produits  mettre en rotation dan la boite latrale<br /><br />Entrez le nombre des produits  afficher dans cette boite latrale en mme temps.<br /><br />Combien de produits voulez-vous afficher dans cette boite?', 3, 11, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (66, 'Produits en Promotion dans la boite latrale', 'MAX_RANDOM_SELECT_SPECIALS', '1', 'Le nombre de produits en promotion  afficher en rotation dans la boite latrale<br /><br />Entrez le nombre de produits  afficher dans la boite latrale en mme temps.<br /><br />Combien de produits voulez-vous afficher dans cette boite?', 3, 12, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (67, 'Categories  lister par ligne', 'MAX_DISPLAY_CATEGORIES_PER_ROW', '3', 'Nombre de catgories  afficher par ligne', 3, 13, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (68, 'Listing de nouveaux produits- Nombre par page', 'MAX_DISPLAY_PRODUCTS_NEW', '10', 'Number of new products listed per page', 3, 14, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (69, 'Boite meilleures ventes', 'MAX_DISPLAY_BESTSELLERS', '10', 'Nombre de meilleures ventes  afficher par boite', 3, 15, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (70, 'Produits galement achets', 'MAX_DISPLAY_ALSO_PURCHASED', '6', 'Nombre de produits  afficher dans la boite ''Ce client  aussi achet''', 3, 16, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (71, 'Boite d''achats rcents- NOTE: boite dsactive', 'MAX_DISPLAY_PRODUCTS_IN_ORDER_HISTORY_BOX', '6', 'Nombre de produits  afficher dans la boite des achats rcents', 3, 17, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (72, 'Historique de commande client, listing par page', 'MAX_DISPLAY_ORDER_HISTORY', '10', 'Nombre de commandes  afficher dans la liste historique de commandes de ''Mon compte''', 3, 18, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (73, 'Affichage maximum de clients sur la page page Clients', 'MAX_DISPLAY_SEARCH_RESULTS_CUSTOMER', '20', '', 3, 19, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (74, 'Affichage maximum de commandes sur la page commandes', 'MAX_DISPLAY_SEARCH_RESULTS_ORDERS', '20', '', 3, 20, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (75, 'Affichage maximum de produits dans les rapports', 'MAX_DISPLAY_SEARCH_RESULTS_REPORTS', '20', '', 3, 21, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (76, 'Nombre maximum de Catgories de produits  lister', 'MAX_DISPLAY_RESULTS_CATEGORIES', '10', 'Nombre de produits  lister par page', 3, 22, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (77, 'Listing produits - Nombre par page', 'MAX_DISPLAY_PRODUCTS_LISTING', '10', 'Nombre maximum de produits  lister par page sur la page principale', 3, 30, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (78, 'Attributs de produits - Noms et valeurs  de options  afficher', 'MAX_ROW_LISTS_OPTIONS', '10', 'Nombre maximum de noms et valeurs d''option   afficher dans la page des attributs de produits', 3, 24, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (79, 'Attributs de produits - Affichage du controle des Attributs', 'MAX_ROW_LISTS_ATTRIBUTES_CONTROLLER', '30', 'Nombre maximum des attributs  afficher dans la page de controle d''attributs.', 3, 25, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (80, 'Attributs de produits - Affichage du gestionnaire de tlchargement', 'MAX_DISPLAY_SEARCH_RESULTS_DOWNLOADS_MANAGER', '30', 'Nombre maximum d''attributs de tlchargements  afficher dans la page du  gestionnaire de tlchargements', 3, 26, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (81, 'Produits  la une - Nombre  afficher en Admin', 'MAX_DISPLAY_SEARCH_RESULTS_FEATURED_ADMIN', '10', 'Nombre de produits  la une  lister par page - Admin', 3, 27, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (82, 'Nombre maximum affich de produits  la une - Page principale', 'MAX_DISPLAY_SEARCH_RESULTS_FEATURED', '9', 'Nombre de produits  la une  lister sur la page principale', 3, 28, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (83, 'Nombre maximum de produits  la une  afficher par page', 'MAX_DISPLAY_PRODUCTS_FEATURED_PRODUCTS', '10', 'Nombre de produits  la une  lister par page', 3, 29, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (84, 'Produits phares dans la boite latrale', 'MAX_RANDOM_SELECT_FEATURED_PRODUCTS', '1', 'Le nombre de produits PHARES en rotation dans la boite latrale<br /><br />Entrez le nombre de produits  afficher dans la boite latrale en mme temps.<br /><br />Combien de produits voulez-vous afficher dans cette boite latrale?', 3, 30, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (85, 'Affichage maximum de produits en promotion - Page principale', 'MAX_DISPLAY_SPECIAL_PRODUCTS_INDEX', '9', 'Nombre de produits en promotion  lister en page principale', 3, 31, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (86, 'Listing nouveaux produits - Limit  ...', 'SHOW_NEW_PRODUCTS_LIMIT', '0', 'Limiter le Listing des nouveaux produits  <br />0= Tous les produits<br />1= Mois courant<br />7= 7 jours<br />14= 14 jours<br />30= 30 jours<br />60= 60 jours<br />90= 90 jours<br />120= 120 jours', 3, 40, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''7'', ''14'', ''30'', ''60'', ''90'', ''120''), ');
INSERT INTO configuration VALUES (87, 'Affichage maximum de produits par page', 'MAX_DISPLAY_PRODUCTS_ALL', '10', 'Nombre de produits  afficher par page', 3, 45, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (88, 'Affichage maximum de drapeaux de langue dans la boite latrale de langue', 'MAX_LANGUAGE_FLAGS_COLUMNS', '3', 'Nombre de drapeaux de langue par ligne', 3, 50, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (89, 'Taille maximum d''un fichier upload', 'MAX_FILE_UPLOAD_SIZE', '2048000', 'Quel est la taille maximum possible d''un fichier  tlharger?<br />Par Dfaut= 2048000 (2 Mo)', 3, 60, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (90, 'Extensions de fichiers autorises pour l''upload', 'UPLOAD_FILENAME_EXTENSIONS', 'jpg,jpeg,gif,png,eps,cdr,ai,pdf,tif,tiff,bmp,zip', 'Listing des types de fichiers autoriss (extensions de fichiers) quand des fichiers sont envoys sur votre site par des clients. Sparer les valeurs par des virgules (,). N''incluez pas de point (.).<br /><br />onfiguration suggre: "jpg,jpeg,gif,png,eps,cdr,ai,pdf,tif,tiff,bmp,zip"', 3, 61, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_textarea(');
INSERT INTO configuration VALUES (91, 'Nombre maximum de dtails de commandes  afficher sur le listing des commandes Admin', 'MAX_DISPLAY_RESULTS_ORDERS_DETAILS_LISTING', '0', 'Nombre maximum de dtails de commande<br />0 = Illimits', 3, 65, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (92, 'Nombre maximum de PayPal IPN  afficher en  Admin', 'MAX_DISPLAY_SEARCH_RESULTS_PAYPAL_IPN', '20', 'Nombre maximum de PayPal IPN  afficher dans le listing Admin<br />20 par dfaut', 3, 66, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (93, 'Nombre de colonnes produits maximum affich dans le gestionnaire de catgories multiples', 'MAX_DISPLAY_PRODUCTS_TO_CATEGORIES_COLUMNS', '3', 'Nombre de colonnes produits maximum affich dans le gestionnaire de catgories multiples<br />3 par Dfaut', 3, 70, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (94, 'Affichage maximum EZ-Pages', 'MAX_DISPLAY_SEARCH_RESULTS_EZPAGE', '20', 'Affichage maximum de EZ-Pages<br />20 par Dfaut', 3, 71, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (95, 'Largeur des miniatures', 'SMALL_IMAGE_WIDTH', '100', 'La largeur en pixels des miniatures d''images', 4, 1, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (96, 'Hauteur des miniatures', 'SMALL_IMAGE_HEIGHT', '80', 'La hauteur en pixels des miniatures d''images', 4, 2, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (97, 'Largeur image en-tte - Admin', 'HEADING_IMAGE_WIDTH', '57', 'La largeur en pixels des images d''en-ttes en Admin<br />NOTE: cela permet d''ajuster l''espace sur les pages Admin ou peut tre utilis pour ajouter des images en haut de l''Admin', 4, 3, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (98, 'Hauteur image en-tte - Admin', 'HEADING_IMAGE_HEIGHT', '40', 'La hauteur en pixels des images d''en-ttes en Admin<br />NOTE: cela permet d''ajuster l''espace sur les pages Admin ou peut tre utilis pour ajouter des images en haut de l''Admin', 4, 4, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (99, 'Largeur image sous-catgorie', 'SUBCATEGORY_IMAGE_WIDTH', '100', 'La largeur en pixels des images de sous-catgories', 4, 5, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (100, 'Hauteur image sous-catgorie', 'SUBCATEGORY_IMAGE_HEIGHT', '57', 'La hauteur en pixels des images de sous-catgories', 4, 6, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (101, 'Calculer taille des images', 'CONFIG_CALCULATE_IMAGE_SIZE', 'true', 'Calculer la taille des images?', 4, 7, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (102, 'Image Requise', 'IMAGE_REQUIRED', 'true', 'Permet d''afficher des images "casses". Bon pour le dveloppement.', 4, 8, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (103, 'Image - Statut du panier', 'IMAGE_SHOPPING_CART_STATUS', '1', 'Affiche une image du produit dans le panier?<br />0= off 1= on', 4, 9, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (104, 'Image - Largeur du panier', 'IMAGE_SHOPPING_CART_WIDTH', '50', 'Par dfaut = 50', 4, 10, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (105, 'Image - Hauteur du panier', 'IMAGE_SHOPPING_CART_HEIGHT', '40', 'Par dfaut = 40', 4, 11, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (106, 'Largeur icne de catgorie - Pages infos produits', 'CATEGORY_ICON_IMAGE_WIDTH', '57', 'La largeur en pixels de l''icne de haut de catgorie pour les pages infos produits', 4, 13, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (107, 'Hauteur icnes catgories - Pages infos produits', 'CATEGORY_ICON_IMAGE_HEIGHT', '40', 'La hauteur en pixels des icnes de catgories pour les pages infos produits', 4, 14, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (108, 'Largeur image sous-catgorie principale', 'SUBCATEGORY_IMAGE_TOP_WIDTH', '150', 'La largeur en pixels de sous-catgorie principale<br />La sous-catgorie principale c''est quand la catgorie contient des sous-catgories', 4, 15, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (109, 'Hauteur image sous-catgorie principale', 'SUBCATEGORY_IMAGE_TOP_HEIGHT', '85', 'La hauteur en pixels de sous-catgorie principale<br />La sous-catgorie principale c''est quand la catgorie contient des sous-catgories', 4, 16, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (110, 'Infos produit - Largeur image', 'MEDIUM_IMAGE_WIDTH', '150', 'La largeur en pixels des images infos produits', 4, 20, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (111, 'Infos produit - Hauteur image', 'MEDIUM_IMAGE_HEIGHT', '120', 'La hauteur en pixels des images infos produits', 4, 21, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (112, 'Infos produit - Suffixe Image Medium', 'IMAGE_SUFFIX_MEDIUM', '_MED', 'Suffixe des images Medium des pages infos produit<br />Par dfaut = _MED', 4, 22, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (113, 'Infos produit - Suffixe Image Large', 'IMAGE_SUFFIX_LARGE', '_LRG', 'Suffixe des images Large des pages infos produit<br />Default = _LRG', 4, 23, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (114, 'Infos produit - Nombre d''images additionnelles par ligne', 'IMAGES_AUTO_ADDED', '3', 'Infos produit - Entrez le nombre d''images additionnelles  afficher par ligne<br />Par dfaut = 3', 4, 30, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (115, 'Image - Largeur listing produits', 'IMAGE_PRODUCT_LISTING_WIDTH', '100', 'Par Dfaut = 100', 4, 40, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (116, 'Image - Hauteur listing produits', 'IMAGE_PRODUCT_LISTING_HEIGHT', '80', 'Par Dfaut = 80', 4, 41, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (117, 'Image - Largeur listing nouveaux produits', 'IMAGE_PRODUCT_NEW_LISTING_WIDTH', '100', 'Par dfaut = 100', 4, 42, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (118, 'Image - Hauteur listing nouveaux produits', 'IMAGE_PRODUCT_NEW_LISTING_HEIGHT', '80', 'Par Dfaut = 80', 4, 43, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (119, 'Image - Largeur nouveaux produits', 'IMAGE_PRODUCT_NEW_WIDTH', '100', 'Par Dfaut = 100', 4, 44, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (120, 'Image - Hauteur nouveaux produits', 'IMAGE_PRODUCT_NEW_HEIGHT', '80', 'Par Dfaut = 80', 4, 45, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (121, 'Image - Largeur Produits  la une', 'IMAGE_FEATURED_PRODUCTS_LISTING_WIDTH', '100', 'Par Dfaut = 100', 4, 46, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (122, 'Image - Hauteur Produits  la une', 'IMAGE_FEATURED_PRODUCTS_LISTING_HEIGHT', '80', 'Par Dfaut = 80', 4, 47, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (123, 'Image - Largeur tous listing produits', 'IMAGE_PRODUCT_ALL_LISTING_WIDTH', '100', 'Par Dfaut = 100', 4, 48, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (124, 'Image - Hauteur tous Listing produits', 'IMAGE_PRODUCT_ALL_LISTING_HEIGHT', '80', 'Par Dfaut = 80', 4, 49, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (125, 'Image Produit - Etat pas d''image', 'PRODUCTS_IMAGE_NO_IMAGE_STATUS', '1', 'Utiliser l''image "Pas d''image" automatique quand aucune image n''est ajoute au produit<br />0= off<br />1= On', 4, 60, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (126, 'Image Produit - image "pas d''image"', 'PRODUCTS_IMAGE_NO_IMAGE', 'no_picture.gif', 'Utiliser l''image "Pas d''image" automatique quand aucune image n''est ajoute au produit<br />Par Dfaut = no_picture.gif', 4, 61, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (127, 'Image - Utiliser images proportionnelles sur produits et catgories', 'PROPORTIONAL_IMAGES_STATUS', '1', 'Utiliser des images proportionnelles sur les produits et catgories?<br /><br />NOTE: N''utilisez pas des hauteurs ou largeurs de 0 pour les images proportionnelles<br />0= off 1= on', 4, 75, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (128, 'Civilit Email', 'ACCOUNT_GENDER', 'true', 'Affiche le choix de civilit pendant la cration d''un compte et infos du compte', 5, 1, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (129, 'Date de naissance', 'ACCOUNT_DOB', 'true', 'Affiche le champs Date de naissance pendant la cration d''un compte et les infos d''un compte<br />NOTE: Enlevez la valeur minimum de date de naissance si pas requise<br />Mettez une valeur minimum > 0 si elle est requise', 5, 2, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (130, 'Socit', 'ACCOUNT_COMPANY', 'true', 'Affiche le champ socit pendant la cration d''un compte et avec les infos de compte', 5, 3, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (131, 'Adresse ligne 2', 'ACCOUNT_SUBURB', 'true', 'Affiche le champ ligne 2 de l''adresse pendant la cration d''un compte et sur les infos du compte', 5, 4, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (132, 'Etat', 'ACCOUNT_STATE', 'false', 'Affiche le champ tat pendant la cration d''un compte et sur les infos du compte', 5, 5, '2007-12-24 13:53:50', '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (133, 'Etat - Toujours afficher en liste?', 'ACCOUNT_STATE_DRAW_INITIAL_DROPDOWN', 'false', 'Quand le champ Etat est affich, doit-il toujours apparatre en menu droulant?', 5, 5, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (134, 'Cration de compte ID Pays par dfaut', 'SHOW_CREATE_ACCOUNT_DEFAULT_COUNTRY', '73', 'Etablir un ID Pays par dfaut pour la cration de compte:<br />Par dfaut : 223', 5, 6, '2007-12-24 13:54:06', '2007-11-04 19:39:58', 'zen_get_country_name', 'zen_cfg_pull_down_country_list_none(');
INSERT INTO configuration VALUES (135, 'Numro de Fax', 'ACCOUNT_FAX_NUMBER', 'true', 'Affiche le champ numro de Fax pendant la cration d''un compte et sur les infos du compte', 5, 10, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (136, 'Affiche la case  cocher Newsletter', 'ACCOUNT_NEWSLETTER_STATUS', '2', 'Affiche la case  cocher Newsletter<br />0= off<br />1= Affiche non coche<br />2= Affiche coche<br /><strong>Note: Mettre cette option coche par dfaut peut aller  l''encontre des lois de votre tat ou pays</strong>', 5, 45, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2''), ');
INSERT INTO configuration VALUES (137, 'Prfrence d''email client par dfaut', 'ACCOUNT_EMAIL_PREFERENCE', '1', 'Prfrence de type d''email client par dfaut<br />0= Texte<br />1= HTML<br />', 5, 46, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (138, 'Etat des notifications de produits client', 'CUSTOMERS_PRODUCTS_NOTIFICATION_STATUS', '1', 'On demande au client pour les notifications de produits aprs une commande russie et dans les prfrences de son compte<br />0= Ne demande jamais<br />1= Le demande (ignor sur la commande si dj slectionn dans les notifications globales)<br /><br />Note: La boite latrale doit tre dsactive sparment', 5, 50, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (139, 'Mode de boutique pour les clients - Voir boutique et prix', 'CUSTOMERS_APPROVAL', '0', 'Les clients doivent tre autoriss pour acheter<br />0= Non pas besoin<br />1= Doit s''identifier pour parcourir le catalogue<br />2= Peut parcourir mais ne voit aucun prix sans tre identifi<br />3= Showroom seulement<br /><br />Nous recommandons l''utilisation de l''Option 2 pour les moteurs de recherche si vous voulez que les clients ne voient pas les prix sans s''identifier.', 5, 55, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''), ');
INSERT INTO configuration VALUES (140, 'Autorisation des clients - Autorisation en cours', 'CUSTOMERS_APPROVAL_AUTHORIZATION', '0', 'Le client doit tre autoris pour acheter<br />0= Non pas besoin<br />1= Doit tre autoris pour parcourir le catalogue<br />2= Peut parcourir mais ne voit pas de prix sans autorisation<br />3= Le client peut parcourir et voir les prix mais ne peut acheter sans autorisation<br /><br />Nous recommandons les Options 2 ou 3 pour les moteurs de recherche', 5, 65, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''), ');
INSERT INTO configuration VALUES (141, 'Autorisation client: nom du fichier', 'CUSTOMERS_AUTHORIZATION_FILENAME', 'customers_authorization', 'Nom du fichier d''autorisation client<br />Note: ne mettez pas l''extension du fichier<br />Par Dfaut=customers_authorization', 5, 66, NULL, '2007-11-04 19:39:58', NULL, '');
INSERT INTO configuration VALUES (142, 'Autorisation Client: Cacher l''en-tte', 'CUSTOMERS_AUTHORIZATION_HEADER_OFF', 'false', 'Autorisation Client: Cacher l''en-tte <br />(true=cacher false=montrer)', 5, 67, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (143, 'Autorisation Client: Cacher colonne gauche', 'CUSTOMERS_AUTHORIZATION_COLUMN_LEFT_OFF', 'false', 'Autorisation Client: Cacher la colonne de gauche<br />(true=cacher false=montrer)', 5, 68, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (144, 'Autorisation Client: Cacher colonne droite', 'CUSTOMERS_AUTHORIZATION_COLUMN_RIGHT_OFF', 'false', 'Autorisation Client: Cacher la colonne de droite <br />(true=cacher false=montrer)', 5, 69, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (145, 'Autorisation Client: Cacher Footer', 'CUSTOMERS_AUTHORIZATION_FOOTER_OFF', 'false', 'Autorisation Client: Cacher le pied de page <br />(true=cacher false=montrer)', 5, 70, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (146, 'Autorisation Client: Cacher les prix', 'CUSTOMERS_AUTHORIZATION_PRICES_OFF', 'false', 'Autorisation Client: Cacher les prix <br />(true=cacher false=montrer)', 5, 71, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (147, 'Code de rfrence Client', 'CUSTOMERS_REFERRAL_STATUS', '0', 'Le Code de rfrence client est cr  partir de<br />0= Off<br />1= Premier coupon de rduction utilis<br />2= Le client peut l''ajouter pendant la cration du compte ou l''diter si blanc<br /><br />NOTE: Une fois que le code de rfrence client a t tabli, il peut uniquement tre chang dans l''Admin clients', 5, 80, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2''), ');
INSERT INTO configuration VALUES (148, 'Modules installs', 'MODULE_PAYMENT_INSTALLED', 'moneyorder.php', 'Liste des modules de paiements installs spars par un point virgule (;). C''est automatiquement mis  jour. Pas besoin d''diter. (Exemple: cc.php;cod.php;paypal.php)', 6, 0, '2008-02-25 15:55:05', '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (149, 'Modules Installs', 'MODULE_ORDER_TOTAL_INSTALLED', 'ot_subtotal.php;ot_shipping.php;ot_coupon.php;ot_group_pricing.php;ot_tax.php;ot_loworderfee.php;ot_gv.php;ot_total.php', 'Liste de modules order_total spars par un point virgule (;). C''est automatiquement mis  jour. Pas besoin d''diter. (Exemple: ot_subtotal.php;ot_tax.php;ot_shipping.php;ot_total.php)', 6, 0, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (150, 'Modules Installs', 'MODULE_SHIPPING_INSTALLED', 'chronopost.php;colissimo.php;flat.php;freeshipper.php;item.php;storepickup.php;zipship.php', 'Liste des modules de livraison spars par un point-virgule. C''est automatiquement mis  jour. Pas besoin d''diter. (Exemple: ups.php;flat.php;item.php)', 6, 0, '2008-02-26 21:11:39', '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (630, 'Zone 1 Handling Fee', 'MODULE_SHIPPING_ZIPSHIP_HANDLING_1', '0', 'Handling Fee for this shipping zone', 6, 0, NULL, '2008-02-26 21:11:39', NULL, NULL);
INSERT INTO configuration VALUES (631, 'Zone 2 Zip Codes', 'MODULE_SHIPPING_ZIPSHIP_CODES_2', '', 'Comma separated list of five character zip codes that are part of Zone 2.<br />Set as 00000 to indicate all five character zip codes that are not specifically defined.', 6, 0, NULL, '2008-02-26 21:11:39', NULL, 'zen_cfg_textarea(');
INSERT INTO configuration VALUES (632, 'Zone 2 Shipping Table', 'MODULE_SHIPPING_ZIPSHIP_COST_2', '50:5.50,51:0', 'Shipping rates to Zone 2 destinations based on a group of maximum order weights/prices. Example: 3:8.50,7:10.50,... Weight/Price less than or equal to 3 would cost 8.50 for Zone 2 destinations.', 6, 0, NULL, '2008-02-26 21:11:39', NULL, 'zen_cfg_textarea(');
INSERT INTO configuration VALUES (628, 'Zone 1 Zip Codes', 'MODULE_SHIPPING_ZIPSHIP_CODES_1', '33801,33803,33809', 'Comma separated list of five character zip codes that are part of Zone 1.<br />Set as 00000 to indicate all five character zip codes that are not specifically defined.', 6, 0, NULL, '2008-02-26 21:11:39', NULL, 'zen_cfg_textarea(');
INSERT INTO configuration VALUES (629, 'Zone 1 Shipping Table', 'MODULE_SHIPPING_ZIPSHIP_COST_1', '50:5.50,51:0', 'Shipping rates to Zone 1 destinations based on a group of maximum order weights/prices. Example: 3:8.50,7:10.50,... Weight/Price less than or equal to 3 would cost 8.50 for Zone 1 destinations.', 6, 0, NULL, '2008-02-26 21:11:39', NULL, 'zen_cfg_textarea(');
INSERT INTO configuration VALUES (626, 'Sort Order', 'MODULE_SHIPPING_ZIPSHIP_SORT_ORDER', '0', 'Sort order of display.', 6, 0, NULL, '2008-02-26 21:11:39', NULL, NULL);
INSERT INTO configuration VALUES (627, 'Skip Zipcodes, use a comma separated list of the five character Zip codes', 'MODULE_SHIPPING_ZIPSHIP_SKIPPED', '', 'Disable for the following Zip Codes:', 6, 0, NULL, '2008-02-26 21:11:39', NULL, 'zen_cfg_textarea(');
INSERT INTO configuration VALUES (158, 'Activer la livraison gratuite', 'MODULE_SHIPPING_FREESHIPPER_STATUS', 'True', 'Voulez-vous offrir la livraison gratuite?', 6, 0, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (159, 'Cot de livraison gratuite', 'MODULE_SHIPPING_FREESHIPPER_COST', '0.00', 'Quel est le cot de la livraison?', 6, 6, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (160, 'Frais de manutention', 'MODULE_SHIPPING_FREESHIPPER_HANDLING', '0', 'Frais de manutention pour ce mode de paiement.', 6, 0, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (161, 'Classe de taxe', 'MODULE_SHIPPING_FREESHIPPER_TAX_CLASS', '0', 'utiliser la classe de taxe suivante sur les frais de lviraison.', 6, 0, NULL, '2007-11-04 19:39:58', 'zen_get_tax_class_title', 'zen_cfg_pull_down_tax_classes(');
INSERT INTO configuration VALUES (162, 'Zone de livraison', 'MODULE_SHIPPING_FREESHIPPER_ZONE', '0', 'Si une zone est slectionne, active seulement le mode de livraison pour cette zone.', 6, 0, NULL, '2007-11-04 19:39:58', 'zen_get_zone_class_title', 'zen_cfg_pull_down_zone_classes(');
INSERT INTO configuration VALUES (163, 'Ordre de tri', 'MODULE_SHIPPING_FREESHIPPER_SORT_ORDER', '0', 'Ordre de tri de l''affichage.', 6, 0, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (164, 'Activer le retrait en boutique', 'MODULE_SHIPPING_STOREPICKUP_STATUS', 'True', 'Voulez-vous offrir la possibilit de retirer la marchandise en boutique?', 6, 0, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (165, 'Frais de livraison', 'MODULE_SHIPPING_STOREPICKUP_COST', '0.00', 'Les frais de livraison pour toutes les commandes utilisant ce mode de livraison.', 6, 0, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (166, 'Classe de taxe', 'MODULE_SHIPPING_STOREPICKUP_TAX_CLASS', '0', 'Utiliser la classe de taxe suivante sur les frais de livraison.', 6, 0, NULL, '2007-11-04 19:39:58', 'zen_get_tax_class_title', 'zen_cfg_pull_down_tax_classes(');
INSERT INTO configuration VALUES (167, 'base de taxe', 'MODULE_SHIPPING_STOREPICKUP_TAX_BASIS', 'Shipping', 'la base sur laquelle les taxes doivent tre calcules. Les options sont <br />Shipping - Base sur l''adresse de livraison du client<br />Billing - base sur l''adresse de facturation du client<br />Store - Base sur l''adresse de la boutique si la zone de livraison/facturation et la mme que celle du magasin', 6, 0, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''Shipping'', ''Billing''), ');
INSERT INTO configuration VALUES (168, 'Zone de livraison', 'MODULE_SHIPPING_STOREPICKUP_ZONE', '0', 'Si une zone est slectionne, active seulement les modes de livraison pour cette zone.', 6, 0, NULL, '2007-11-04 19:39:58', 'zen_get_zone_class_title', 'zen_cfg_pull_down_zone_classes(');
INSERT INTO configuration VALUES (169, 'Ordre de tri', 'MODULE_SHIPPING_STOREPICKUP_SORT_ORDER', '0', 'Ordre d''affichage.', 6, 0, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (170, 'Activer livraison par article', 'MODULE_SHIPPING_ITEM_STATUS', 'True', 'Voulez-vous offrir la possibilit de livraison par article?', 6, 0, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (171, 'Frais de livraison', 'MODULE_SHIPPING_ITEM_COST', '2.50', 'Le cot de livraison sera multipli par le nombre d''articles dans une commande qui utilise ce mode de livraison.', 6, 0, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (172, 'Frais de manutention', 'MODULE_SHIPPING_ITEM_HANDLING', '0', 'Frais de manutention pour ce mode de livraison.', 6, 0, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (173, 'Classe de taxe', 'MODULE_SHIPPING_ITEM_TAX_CLASS', '0', 'Utiliser la classe de taxe suivante sur les frais de livraison.', 6, 0, NULL, '2007-11-04 19:39:58', 'zen_get_tax_class_title', 'zen_cfg_pull_down_tax_classes(');
INSERT INTO configuration VALUES (174, 'Base de taxe', 'MODULE_SHIPPING_ITEM_TAX_BASIS', 'Shipping', 'Sur quelle base doit tre calcule la taxe de livraison. Les options sont<br />Shipping - Base sur l''adresse de livraison du client<br />Billing - Base sur l''adresse de facturation du client<br />Store - Base sur l''adresse de la boutique si la zone de livraison/facturation est la mme que la zone de la boutique', 6, 0, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''Shipping'', ''Billing'', ''Store''), ');
INSERT INTO configuration VALUES (175, 'Zone de livraison', 'MODULE_SHIPPING_ITEM_ZONE', '0', 'Si une zone est slectionne, oactive seulement les modes de paiement disponibles pour cette zone.', 6, 0, NULL, '2007-11-04 19:39:58', 'zen_get_zone_class_title', 'zen_cfg_pull_down_zone_classes(');
INSERT INTO configuration VALUES (176, 'Ordre de tri', 'MODULE_SHIPPING_ITEM_SORT_ORDER', '0', 'Ordre d''affichage.', 6, 0, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (625, 'Tax Basis', 'MODULE_SHIPPING_ZIPSHIP_TAX_BASIS', 'Shipping', 'On what basis is Shipping Tax calculated. Options are<br />Shipping - Based on customers Shipping Address<br />Billing Based on customers Billing address<br />Store - Based on Store address if Billing/Shipping Zone equals Store zone', 6, 0, NULL, '2008-02-26 21:11:39', NULL, 'zen_cfg_select_option(array(''Shipping'', ''Billing'', ''Store''), ');
INSERT INTO configuration VALUES (623, 'Calculation Method', 'MODULE_SHIPPING_ZIPSHIP_METHOD', 'Weight', 'Calculate cost based on Weight, Price or Item?', 6, 0, NULL, '2008-02-26 21:11:39', NULL, 'zen_cfg_select_option(array(''Weight'', ''Price'', ''Item''), ');
INSERT INTO configuration VALUES (624, 'Tax Class', 'MODULE_SHIPPING_ZIPSHIP_TAX_CLASS', '0', 'Use the following tax class on the shipping fee.', 6, 0, NULL, '2008-02-26 21:11:39', 'zen_get_tax_class_title', 'zen_cfg_pull_down_tax_classes(');
INSERT INTO configuration VALUES (181, 'Active le module commande par Chque/Espces', 'MODULE_PAYMENT_MONEYORDER_STATUS', 'True', 'Voulez-vous accepter les paiements par chque ou espces?', 6, 1, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (182, 'Mettez l''ordre du chque  :', 'MODULE_PAYMENT_MONEYORDER_PAYTO', 'Le nom du propritaire de la boutique', 'Quel ordre faut-il mettre sur les chques de rglement de commandes?', 6, 1, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (183, 'Ordre d''affichage.', 'MODULE_PAYMENT_MONEYORDER_SORT_ORDER', '0', 'Ordre d''affichage. Le plus petit est affich en premier.', 6, 0, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (184, 'Zone de paiement', 'MODULE_PAYMENT_MONEYORDER_ZONE', '0', 'Si une zone est slectionn, active seulement les modes de paiements pour cette zone.', 6, 2, NULL, '2007-11-04 19:39:58', 'zen_get_zone_class_title', 'zen_cfg_pull_down_zone_classes(');
INSERT INTO configuration VALUES (185, 'Ordre d''affichage', 'MODULE_PAYMENT_MONEYORDER_ORDER_STATUS_ID', '0', 'Mettre le statut des commandes passes avec ce module de paiement sur cette valeur', 6, 0, NULL, '2007-11-04 19:39:58', 'zen_get_order_status_name', 'zen_cfg_pull_down_order_statuses(');
INSERT INTO configuration VALUES (186, 'Inclure Taxes', 'MODULE_ORDER_TOTAL_GROUP_PRICING_INC_TAX', 'false', 'Inclure le montat d''une taxe avant de calculer la remise?', 6, 6, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (187, 'Ce module est install', 'MODULE_ORDER_TOTAL_GROUP_PRICING_STATUS', 'true', '', 6, 1, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true''), ');
INSERT INTO configuration VALUES (188, 'Ordre de tri', 'MODULE_ORDER_TOTAL_GROUP_PRICING_SORT_ORDER', '290', 'L''ordre d''affichage.', 6, 2, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (189, 'Inclure la livraison', 'MODULE_ORDER_TOTAL_GROUP_PRICING_INC_SHIPPING', 'false', 'Inclure le montant de la livraison avant le calcul des remises?', 6, 5, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (190, 'Re-calculer Taxes', 'MODULE_ORDER_TOTAL_GROUP_PRICING_CALC_TAX', 'Standard', 'Re-calculer Taxes', 6, 7, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''None'', ''Standard'', ''Credit Note''), ');
INSERT INTO configuration VALUES (191, 'Classe de taxe', 'MODULE_ORDER_TOTAL_GROUP_PRICING_TAX_CLASS', '0', 'Utiliser la classe de taxes suivante lors du traitement de remises groupes comme note de crdit.', 6, 0, NULL, '2007-11-04 19:39:58', 'zen_get_tax_class_title', 'zen_cfg_pull_down_tax_classes(');
INSERT INTO configuration VALUES (192, 'Active forfait de livraison', 'MODULE_SHIPPING_FLAT_STATUS', 'True', 'Voulez-vous proposer un forfait de livraison?', 6, 0, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (193, 'Frais de livraison', 'MODULE_SHIPPING_FLAT_COST', '5.00', 'Les frais de livraison pour toutes les commandes passes utilisant ce mode de livraison.', 6, 0, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (194, 'Classe de taxes', 'MODULE_SHIPPING_FLAT_TAX_CLASS', '0', 'Utiliser la classe de taxe suivante sur les frais de livraison.', 6, 0, NULL, '2007-11-04 19:39:58', 'zen_get_tax_class_title', 'zen_cfg_pull_down_tax_classes(');
INSERT INTO configuration VALUES (195, 'Base de taxe', 'MODULE_SHIPPING_FLAT_TAX_BASIS', 'Shipping', 'Sur quelle base doivent tre calcules les taxes de livraison. Les options sont<br />Shipping - Base sur l''adresse de livraison du client<br />Billing Base sur l''adresse de facturation du client<br />Store - Base sur l''adresse de la boutique si la zone de facturation/livraison est la mme que la zone de la boutique', 6, 0, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''Shipping'', ''Billing'', ''Store''), ');
INSERT INTO configuration VALUES (196, 'Zone de livraison', 'MODULE_SHIPPING_FLAT_ZONE', '0', 'Si une zone est slectionne, active seulement ce mode de livraison pour cette zone.', 6, 0, NULL, '2007-11-04 19:39:58', 'zen_get_zone_class_title', 'zen_cfg_pull_down_zone_classes(');
INSERT INTO configuration VALUES (197, 'Ordre de tri', 'MODULE_SHIPPING_FLAT_SORT_ORDER', '0', 'L''ordre d''affichage.', 6, 0, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (198, 'Devise par dfaut', 'DEFAULT_CURRENCY', 'EUR', 'Devise par dfaut', 6, 0, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (199, 'Langue par dfaut', 'DEFAULT_LANGUAGE', 'fr', 'Langue par dfaut', 6, 0, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (200, 'Statut par dfaut des nouvelle commandes', 'DEFAULT_ORDERS_STATUS_ID', '1', 'Quand une nouvelle commande est passe, ce statut de commande lui sera assign.', 6, 0, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (201, 'Montrer la configuration_key Admin', 'ADMIN_CONFIGURATION_KEY_ON', '0', 'Passez cette valeur sur 1 pour voir les noms de configuration_key dans l''affichage de la configuration', 6, 0, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (202, 'Pays d''origine', 'SHIPPING_ORIGIN_COUNTRY', '73', 'Slectionnez le pays d''origine  utiliser dans le calcul des frais de livraison.', 7, 1, '2008-02-22 13:14:10', '2007-11-04 19:39:58', 'zen_get_country_name', 'zen_cfg_pull_down_country_list(');
INSERT INTO configuration VALUES (203, 'Code postal', 'SHIPPING_ORIGIN_ZIP', '78000', 'Entrez le code Postal (ZIP) de la boutique pour l''utilisation dans le calcul de la livraison. NOTE: Pour les codes aux USA, utilisez seulement le code  5 chiffres.', 7, 2, '2008-02-22 13:14:19', '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (204, 'Entrez le poids maximum que vous pouvez livrer par commande', 'SHIPPING_MAX_WEIGHT', '50', 'Les transporteurs ont une limite de poids qu''il est possible d''expdier pour un colis. Celui-ci est un poids max commun pour tous.', 7, 3, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (205, 'Tare de colis Petit  Moyen - ajouteadded percentage:poids', 'SHIPPING_BOX_WEIGHT', '0:3', 'Quel est le poids d''un colis standard de petit  moyen colis?<br />Exemple: 10% + 1kg 10:1<br />10% + 0kgs 10:0<br />0% + 5kgs 0:5<br />0% + 0kgs 0:0', 7, 4, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (206, 'Colis plus gros - ajoute percentage:poids', 'SHIPPING_BOX_PADDING', '10:0', 'Quel est le poids classique d''un colis pour les gros colis?<br />Exemple: 10% + 1kg 10:1<br />10% + 0kgs 10:0<br />0% + 5kgs 0:5<br />0% + 0kgs 0:0', 7, 5, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (207, 'Affiche le nombre de colis et le statut du poids', 'SHIPPING_BOX_WEIGHT_DISPLAY', '3', 'Affiche le poids de livraison et le nombre de colis?<br /><br />0= off<br />1= Colis seulement<br />2= Poids seulement<br />3= Colis et Poids', 7, 15, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''), ');
INSERT INTO configuration VALUES (208, 'Configuration de l''affichage de l''estimateur de livraison pour le Panier', 'SHOW_SHIPPING_ESTIMATOR_BUTTON', '1', '<br />0= Off<br />1= S''Affiche comme bouton dans le panier<br />2= S''Affiche comme listing sur la page du Panier', 7, 20, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2''), ');
INSERT INTO configuration VALUES (209, 'Livraison gratuite commande avec poids 0', 'ORDER_WEIGHT_ZERO_STATUS', '0', 'S''il n''y a pas de poids  la commande, est-ce que c''est livraison gratuite?<br />0= non<br />1= oui<br /><br />Note: Lors de l''utilisation de Livraison Gratuite, Activer le module de livraison gratuite s''affichera seulement sur une livraison gratuite.', 7, 15, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (210, 'Affiche l''Image du produit', 'PRODUCT_LIST_IMAGE', '1', 'Voulez-vous afficher l''image du produit?', 8, 1, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (211, 'Affiche le nom du fabricant du produit', 'PRODUCT_LIST_MANUFACTURER', '0', 'Voulez-vous afficher les nom du fabricant du produit?', 8, 2, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (212, 'Affiche le Modle du produit', 'PRODUCT_LIST_MODEL', '0', 'Voulez-vous afficher le modle du produit?', 8, 3, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (213, 'Affiche le nom du produit', 'PRODUCT_LIST_NAME', '2', 'Voulez-vous afficher le nom du produit?', 8, 4, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (214, 'Affiche le prix du produit/Ajouter au panier', 'PRODUCT_LIST_PRICE', '3', 'Voulez-vous afficher le prix du produit / Ajouter au panier', 8, 5, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (215, 'Affiche la quantit de produits', 'PRODUCT_LIST_QUANTITY', '0', 'Voulez-vous afficher la quantit de produits en stock?', 8, 6, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (216, 'Affiche le poids du produit', 'PRODUCT_LIST_WEIGHT', '0', 'Voulez-vous afficher le poids du produit?', 8, 7, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (217, 'Largeur de colonne de prix du produit/Ajouter au panier', 'PRODUCTS_LIST_PRICE_WIDTH', '125', 'Dfinit la largeur de la colonne du prix/Ajouter au panier<br />Par dfaut= 125', 8, 8, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (218, 'Affiche la catgorie/Filtre par fabricant (0=off; 1=on)', 'PRODUCT_LIST_FILTER', '1', 'Voulez-vous afficher le filtre par catgorie/Fabricant?', 8, 9, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (219, 'Navigation de page Prc/Suiv (1-haut, 2-bas, 3-les deux)', 'PREV_NEXT_BAR_LOCATION', '3', 'Configure l''emplacement des liens de navigation de pages Prc/Suiv', 8, 10, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''1'', ''2'', ''3''), ');
INSERT INTO configuration VALUES (220, 'Affiche le classement par dfaut du Listing produits', 'PRODUCT_LISTING_DEFAULT_SORT_ORDER', '', 'Classement par dfaut du Listing des produits?<br />NOTE: Laisser vide pour un classement des produits. Classer le listing de produits dans l''ordre que vous voulez pour que l''affichage par dfaut commence au paramtre de tri. Exemple: 2a', 8, 15, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (221, 'Affiche le bouton Ajouter au panier sur les produits (0=off; 1=on; 2=on avec la Qt par produit)', 'PRODUCT_LIST_PRICE_BUY_NOW', '1', 'Voulez-vous afficher le bouton Ajouter au panier?', 8, 20, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2''), ');
INSERT INTO configuration VALUES (222, 'Affiche la boite Qt de produits multiple et Configure l''emplacement du bouton', 'PRODUCT_LISTING_MULTIPLE_ADD_TO_CART', '3', 'Voulez-vous afficher l''Ajout de quantit de produits multiples et configurer l''emplacement du bouton?<br />0= off<br />1= Haut<br />2= Bas<br />3= Les deux', 8, 25, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''), ');
INSERT INTO configuration VALUES (223, 'Afficher la description Produit', 'PRODUCT_LIST_DESCRIPTION', '150', 'Voulez-vous afficher la description Produit?<br /><br />0= OFF<br />150= Longueur suggre, ou entrez le nombre de caractres maximum  afficher', 8, 30, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (224, 'Listing produits, classement Ascendant', 'PRODUCT_LIST_SORT_ORDER_ASCENDING', '+', 'Qu''est-ce que vous voulez utiliser pour indiquer un classement Ascendant?<br />Par Dfaut = +', 8, 40, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_textarea_small(');
INSERT INTO configuration VALUES (225, 'Listing produits, classement Descendant', 'PRODUCT_LIST_SORT_ORDER_DESCENDING', '-', 'Qu''est-ce que vous voulez utiliser pour indiquer un classement Descendant?<br />Par Dfaut = -', 8, 41, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_textarea_small(');
INSERT INTO configuration VALUES (226, 'Inclure la liste de classement alphabtique de produits', 'PRODUCT_LIST_ALPHA_SORTER', 'true', 'Voulez-vous inclure la liste de classement alphabtique de produits?', 8, 50, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (227, 'Inclure l''image de sous-catgorie du listing produit', 'PRODUCT_LIST_CATEGORIES_IMAGE_STATUS', 'true', 'Voulez-vous inclure l''image de sous-catgorie du listing produit?', 8, 52, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (228, 'Inclure l''image de catgorie principale du listing produits', 'PRODUCT_LIST_CATEGORIES_IMAGE_STATUS_TOP', 'true', 'Voulez-vous inclure l''image de catgorie principale sur le listing des produits?', 8, 53, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (229, 'Montrer les sous-catgories sur la navigation de page principale', 'PRODUCT_LIST_CATEGORY_ROW_STATUS', '1', 'Affiche les sous-catgories sur la page principale lors de la navigation sur les catgories<br /><br />0= off<br />1= on', 8, 60, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (230, 'Vrifie le niveau de stock', 'STOCK_CHECK', 'true', 'Vrifie qu''il y a un stock suffisant de produits disponible', 9, 1, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (231, 'Soustraire le stock', 'STOCK_LIMITED', 'true', 'Soustraire les produits en stock par les produits commands', 9, 2, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (232, 'Autoriser la commande', 'STOCK_ALLOW_CHECKOUT', 'true', 'Autorise le client  commander mme si le stock est insuffisant', 9, 3, NULL, '2007-11-04 19:39:58', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (233, 'Marquer les produits puiss', 'STOCK_MARK_PRODUCT_OUT_OF_STOCK', '***', 'Affiche quelque chose  l''cran pour que les clients voient quel stock de produit est puis', 9, 4, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (234, 'Niveau Re-commande du stock', 'STOCK_REORDER_LEVEL', '5', 'Dfinit quand il faut recommander du stock', 9, 5, NULL, '2007-11-04 19:39:58', NULL, NULL);
INSERT INTO configuration VALUES (235, 'Statut des produits dans le catalogue qui sont en stock puis', 'SHOW_PRODUCTS_SOLD_OUT', '0', 'Affiche les produits lorsqu''ils sont puiss<br /><br />0= met le statut du produit  OFF<br />1= laisse le statut du produit  ON', 9, 10, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (236, 'Affiche une image Epuis  la place de Ajouter au Panier', 'SHOW_PRODUCTS_SOLD_OUT_IMAGE', '1', 'Affiche une image "Epuis"  la place du bouton "Ajouter au panier"<br /><br />0= off<br />1= on', 9, 11, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (237, 'Dcimales de quantit de produit', 'QUANTITY_DECIMALS', '0', 'Autoriser combien de dcimales sur les Quantits<br /><br />0= off', 9, 15, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''), ');
INSERT INTO configuration VALUES (238, 'Affiche le Panier - Case supprimer ou bouton Supprimer', 'SHOW_SHOPPING_CART_DELETE', '3', 'Affiche le bouton Supprimer du Panieret /ou des cases  cocher<br /><br />1= Bouton supprimer seulement<br />2= Case  cocher seulement<br />3= Les deux', 9, 20, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''1'', ''2'', ''3''), ');
INSERT INTO configuration VALUES (239, 'Affiche le Panier - Emplacement du bouton Actuliser le Panier', 'SHOW_SHOPPING_CART_UPDATE', '3', 'Affiche le bouton Actualiser Panier  l''emplacement:<br /><br />1= A ct de chaque boite de Qt<br />2= Sous chaque produit<br />3= Les deux', 9, 22, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''1'', ''2'', ''3''), ');
INSERT INTO configuration VALUES (240, 'Affiche les nouveaux produits sur une page de Panier vide', 'SHOW_SHOPPING_CART_EMPTY_NEW_PRODUCTS', '1', 'Affiche les nouveaux produits sur une page de Panier vide<br />0= off ou mettez l''ordre de tri', 9, 30, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (241, 'Montre les produits  la une sur une page de Panier vide', 'SHOW_SHOPPING_CART_EMPTY_FEATURED_PRODUCTS', '2', 'Montre les produits  la une sur une page de Panier vide<br />0= off ou configurez un ordre de tri', 9, 31, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (242, 'Montre les produits en promotion sur une page de Panier vide', 'SHOW_SHOPPING_CART_EMPTY_SPECIALS_PRODUCTS', '3', 'Montre les produits en promotion sur une page de Panier vide<br />0= off ou configurez un ordre de tri', 9, 32, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (243, 'Montre les produits  venir sur une Page de Panier vide', 'SHOW_SHOPPING_CART_EMPTY_UPCOMING', '4', 'Montre les produits  venir sur une Page de Panier vide<br />0= off or configurez l''ordre de tri', 9, 33, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (244, 'Stocker le temps d''une page', 'STORE_PAGE_PARSE_TIME', 'false', 'Stocker le temps que cela prend  afficher une page', 10, 1, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (245, 'Destination des Logs', 'STORE_PAGE_PARSE_TIME_LOG', '/var/log/www/zen/page_parse_time.log', 'Rpertoire et nom du fichier de la page des logs', 10, 2, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (246, 'Format de date des Logs', 'STORE_PARSE_DATE_TIME_FORMAT', '%d/%m/%Y %H:%M:%S', 'Le format de la date', 10, 3, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (247, 'Affiche le temps d''affichage de la page', 'DISPLAY_PAGE_PARSE_TIME', 'false', 'Affiche le temps d''affichage de le page en bas de chaque page<br />Vous n''avez pas besoin de stocker les temps pour les afficher sur le catalogue', 10, 4, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (248, 'Stocker les requtes de base de donnes', 'STORE_DB_TRANSACTIONS', 'false', 'Stocker les requtes de base de donnes dans les logs de temps d''affichage de pages (PHP4 seulement)', 10, 5, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (249, 'Mthode d''envoi des E-Mail', 'EMAIL_TRANSPORT', 'PHP', 'Dfinit la mthode d''envoi des mails.<br /><strong>PHP</strong> est actif par dfaut, et utilise les fonctions PHP intgres pour l''envoi.<br />Les serveurs utilisant Windows et MacOS doivent changer ce paramtre en <strong>SMTP</strong>.<br /><br /><strong>SMTPAUTH</strong> doit tre utilis seulement si votre serveur requiert une autorisation SMTP pour envoyer des messages. Vous devez aussi configurer vos paramtres SMTPAUTH dans les champs appropris de la partie Admin.<br /><br /><strong>sendmail</strong> est pour les serveurs linux/unix qui utilisent le programme sendmail<br /><strong>"sendmail-f"</strong> est seulement pour les serveurs qui ncessitent l''utilisation du paramtre -f parameter pour envoyer un mail. C''est un paramtre de scurit souvent utilis pour prvenir le spoofing. Cela provoquera des erreurs si votre serveur mail n ''est pas configur pour l''utiliser.<br /><br /><strong>Qmail</strong> est utilis pour les serveurs linux/unix qui utilisent Qmail comme sendmail /var/qmail/bin/sendmail.', 12, 1, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''PHP'', ''sendmail'', ''sendmail-f'', ''smtp'', ''smtpauth'', ''Qmail''),');
INSERT INTO configuration VALUES (250, 'Compte Email SMTP', 'EMAIL_SMTPAUTH_MAILBOX', 'YourEmailAccountNameHere', 'Entrez le nom du compte (me@mydomain.com) donn par votre hbergeur. C''est le compte dont votre serveur a besoin pour l''authentification SMTP.<br />Utile seulement si vous utilisez l''authentification SMTP pour les emails.', 12, 101, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (251, 'Mot de passe de compte SMTP Email', 'EMAIL_SMTPAUTH_PASSWORD', 'YourPasswordHere', 'Entrez le mot de passe de votre boite mail SMTP. <br />Utile seulement si vous utilisez l''authentification SMTP pour les email.', 12, 101, NULL, '2007-11-04 19:39:59', 'zen_cfg_password_display', NULL);
INSERT INTO configuration VALUES (252, 'Nom d''hte SMTP Email', 'EMAIL_SMTPAUTH_MAIL_SERVER', 'mail.EnterYourDomain.com', 'Entrez le nom de domaine de votre serveur mail SMTP.<br />ex: mail.mondomaine.com<br />ou 55.66.77.88<br />Utile seulement si vous utilisez l''authentification SMTP pour les emails.', 12, 101, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (253, 'Port du serveur SMTP Email', 'EMAIL_SMTPAUTH_MAIL_SERVER_PORT', '25', 'Entrez le numro du port qu''utilise le serveur SMTP.<br />Utile seulement si vous utilisez l''authentification SMTP Authentication pour les email.', 12, 101, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (254, 'Convertir les devises pour les emails Texte', 'CURRENCIES_TRANSLATIONS', '&pound;,:&euro;,', 'De quelles conversions de devises avez-vous besoin pour les emails au format texte?<br />Par Dfaut = &amp;pound;,:&amp;euro;,', 12, 120, NULL, '2003-11-21 00:00:00', NULL, 'zen_cfg_textarea_small(');
INSERT INTO configuration VALUES (255, 'E-Mail Linefeeds', 'EMAIL_LINEFEED', 'LF', 'Dfinit la squence de caractres utilise pour sparer les en-ttes email.', 12, 2, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''LF'', ''CRLF''),');
INSERT INTO configuration VALUES (256, 'Utiliser MIME HTML lors de l''envoi des E-mail', 'EMAIL_USE_HTML', 'true', 'Envoyer les e-mails au format HTML', 12, 3, '2008-02-25 15:43:42', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (257, 'Vrifier les adresses E-Mail avec le DNS', 'ENTRY_EMAIL_ADDRESS_CHECK', 'false', 'Vrifier les adresses e-mail avec un serveur DNS', 12, 6, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (258, 'Envoyer E-Mails', 'SEND_EMAILS', 'true', 'Envoyer des e-mails', 12, 5, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (259, 'Activer l''archivage des Emails?', 'EMAIL_ARCHIVE', 'false', 'Si vous voulez avoir les emails archivs/stocks lorsqu''ils sont envoys, configurez l''option sur "true".', 12, 6, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (260, 'Erreurs E-Mail', 'EMAIL_FRIENDLY_ERRORS', 'false', 'Voulez-vous afficher des erreurs plus comprhensibles si les emails chouent?  Mettre cette option sur false affichera les erreurs PHP classiques et fera certainement chouer le script. Mettez le sur false en cas de problme, et true pour une boutique en production.', 12, 7, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (261, 'Adresse Email (Affiche pour vous contacter)', 'STORE_OWNER_EMAIL_ADDRESS', 'root@localhost', 'Adresse Email du propritaire. Utilise  l''affichage seulement pour informer les clients de la manire de vous contacter.', 12, 10, '2008-02-25 15:38:50', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (262, 'Adresse Email (champ FROM)', 'EMAIL_FROM', 'root@localhost', 'Adresse  partir de laquelle les messages seront envoys par dfaut. Peut tre crase lors de l''criture d''un mail dans les modules admin.', 12, 11, '2008-02-25 15:38:53', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (263, 'Emails doivent tre envoys d''un domaine connu?', 'EMAIL_SEND_MUST_BE_STORE', 'No', 'Does your mailserver require that all outgoing emails have their "from" address match a known domain that exists on your webserver?<br /><br />This is often required in order to prevent spoofing and spam broadcasts.  If set to Yes, this will cause the email address (sent FROM) to be used as the "from" address on all outgoing mail.', 12, 11, NULL, '0001-01-01 00:00:00', NULL, 'zen_cfg_select_option(array(''No'', ''Yes''), ');
INSERT INTO configuration VALUES (264, 'Format des Emails Admin?', 'ADMIN_EXTRA_EMAIL_FORMAT', 'HTML', 'Veuillez slectionner le format des extra  emails Admin', 12, 12, '2008-02-25 15:45:40', '0001-01-01 00:00:00', NULL, 'zen_cfg_select_option(array(''TEXT'', ''HTML''), ');
INSERT INTO configuration VALUES (265, 'Envoyer une copie des confirmations de commandes ', 'SEND_EXTRA_ORDER_EMAILS_TO', 'root@localhost', 'Envoyer des COPIES des emails de confirmations de commandes aux adresses email suivantes, dans ce format: Nom 1 &lt;email@address1&gt;, Nom 2 &lt;email@address2&gt;', 12, 12, '2008-02-25 15:39:12', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (266, 'Envoyer une copie des emails de crations de comptes  - Statut', 'SEND_EXTRA_CREATE_ACCOUNT_EMAILS_TO_STATUS', '0', 'Envoyer copie de statut de cration de compte<br />0= off 1= on', 12, 13, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''),');
INSERT INTO configuration VALUES (267, 'Envoyer copie des emails de cration de compte ', 'SEND_EXTRA_CREATE_ACCOUNT_EMAILS_TO', 'root@localhost', 'Envoyer une copie des emails de cration de compte  aux adresse suivantes, dans ce format: Nom 1 &lt;email@address1&gt;, Nom 2 &lt;email@address2&gt;', 12, 14, '2008-02-25 15:39:17', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (268, 'Envoyer une copie des emails "Envoyer  un ami"  - Statut', 'SEND_EXTRA_TELL_A_FRIEND_EMAILS_TO_STATUS', '0', 'Envoyer une copie des emails "Envoyer  un ami"<br />0= off 1= on', 12, 15, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''),');
INSERT INTO configuration VALUES (269, 'Envoyer copie des emails "Envoyer  un ami" ', 'SEND_EXTRA_TELL_A_FRIEND_EMAILS_TO', 'root@localhost', 'Envoyer une copie des emails "Envoyer  un ami" aux adresses emails suivantes, dans ce format: Nom 1 &lt;email@address1&gt;, Nom 2 &lt;email@address2&gt;', 12, 16, '2008-02-25 15:39:22', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (270, 'Envoyer une copie des chques cadeaux envoys  - Statut', 'SEND_EXTRA_GV_CUSTOMER_EMAILS_TO_STATUS', '0', 'Envoyer une copie des chques cadeaux envoys<br />0= off 1= on', 12, 17, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''),');
INSERT INTO configuration VALUES (271, 'Envoyer une copie des chques cadeaux clients ', 'SEND_EXTRA_GV_CUSTOMER_EMAILS_TO', 'root@localhost', 'Envoyer une copie des chques cadeaux clients aux adresses email suivantes, dans ce format: Nom 1 &lt;email@address1&gt;, Nom 2 &lt;email@address2&gt;', 12, 18, '2008-02-25 15:39:28', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (272, 'Envoyer une copie des chques cadeaux Admin  - Etat', 'SEND_EXTRA_GV_ADMIN_EMAILS_TO_STATUS', '0', 'Envoyer une copie des chques cadeaux Admin, tat : <br />0= off 1= on', 12, 19, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''),');
INSERT INTO configuration VALUES (273, 'Envoyer une copie des mails chques cadeaux Admin ', 'SEND_EXTRA_GV_ADMIN_EMAILS_TO', 'root@localhost', 'Envoyer une copie des mails chques cadeaux Admin aux adresses suivantes, dans ce format: Nom 1 &lt;email@address1&gt;, Nom 2 &lt;email@address2&gt;', 12, 20, '2008-02-25 15:39:34', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (274, 'Envoyer une copie des mails coupons de rduction Admin  - Etat', 'SEND_EXTRA_DISCOUNT_COUPON_ADMIN_EMAILS_TO_STATUS', '0', 'Envoyer une copie des mails coupons de rduction Admin - Etat : <br />0= off 1= on', 12, 21, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''),');
INSERT INTO configuration VALUES (275, 'Envoyer une copie des mails coupons de rduction Clients Admin ', 'SEND_EXTRA_DISCOUNT_COUPON_ADMIN_EMAILS_TO', 'root@localhost', 'Envoyer une copie des mails coupons de rduction Clients Admin aux adresses suivantes, dans ce format: Nom 1 &lt;email@address1&gt;, Nom 2 &lt;email@address2&gt;', 12, 22, '2008-02-25 15:39:40', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (276, 'Envoyer une copie des statuts de commandes Admin  - Etat', 'SEND_EXTRA_ORDERS_STATUS_ADMIN_EMAILS_TO_STATUS', '0', 'Envoyer une copie des statuts de commandes Admin  - Etat : <br />0= off 1= on', 12, 23, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''),');
INSERT INTO configuration VALUES (277, 'Envoyer une copie des statuts de commandes Admin  ', 'SEND_EXTRA_ORDERS_STATUS_ADMIN_EMAILS_TO', 'root@localhost', 'Envoyer une copie des statuts de commandes Admin aux adresses email suivantes, dans ce format: Nom 1 &lt;email@address1&gt;, Nom 2 &lt;email@address2&gt;', 12, 24, '2008-02-25 15:39:46', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (278, 'Envoyer une alerte des avis produits en cours par email - Etat', 'SEND_EXTRA_REVIEW_NOTIFICATION_EMAILS_TO_STATUS', '0', 'Envoyer une alerte des avis produits en cours par email - Etat : <br />0= off 1= on', 12, 25, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''),');
INSERT INTO configuration VALUES (279, 'Envoyer une alerte des avis produits en cours par email  ', 'SEND_EXTRA_REVIEW_NOTIFICATION_EMAILS_TO', 'root@localhost', 'Envoyer une alerte des avis produits en cours par email aux adresses email suivantes, dans ce format: Nom 1 &lt;email@address1&gt;, Nom 2 &lt;email@address2&gt;', 12, 26, '2008-02-25 15:39:51', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (280, 'Configure la liste droulante "Nous contacter" ', 'CONTACT_US_LIST', '', 'Sur la page "Nous contacter" Page, configure la liste des adresses emails, dans ce format: Nom 1 &lt;email@address1&gt;, Nom 2 &lt;email@address2&gt;', 12, 40, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_textarea(');
INSERT INTO configuration VALUES (281, 'Autoriser les invits  informer un ami', 'ALLOW_GUEST_TO_TELL_A_FRIEND', 'false', 'Autorise les invits  utiliser la fonction informer un ami d''un produit. <br />Si c''est rgl sur [false], alors il sera demand  l''invit de s''identifier pour utiliser la fonction.', 12, 50, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (282, 'Nous contacter - Afficher le nom et adresse de la boutique', 'CONTACT_US_STORE_NAME_ADDRESS', '1', 'Inclure les nom et adresse de la boutique<br />0= off 1= on', 12, 50, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (283, 'Envoyer des mails Stock Bas', 'SEND_LOWSTOCK_EMAIL', '0', 'Envoyer un email quand le niveau de stock d''un produit est bas<br />0= off<br />1= on', 12, 60, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''),');
INSERT INTO configuration VALUES (284, 'Envoyer des mails Stock Bas ', 'SEND_EXTRA_LOW_STOCK_EMAILS_TO', 'root@localhost', 'Envoyer un email quand le niveau de stock d''un produit est bas  cette adresse email, dans ce format: Nom 1 &lt;email@address1&gt;, Nom 2 &lt;email@address2&gt;', 12, 61, '2008-02-25 15:39:57', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (285, 'Affiche le lien "Se dsinscrire de la newsletter" ?', 'SHOW_NEWSLETTER_UNSUBSCRIBE_LINK', 'true', 'Affiche le lien "Se dsinscrire de la newsletter" dans la boite "informations" latrale ?', 12, 70, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (286, 'Affichage compteur des destinataires', 'AUDIENCE_SELECT_DISPLAY_COUNTS', 'true', 'Lors de l''affichage de listes des destinataires disponibles, est-ce que le recipients-count doit tre inclut? <br /><em>(Cela peut ralentir si vous avez beaucoup de clients ou beaucoup de requtes)</em>', 12, 90, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (287, 'Activer tlchargements', 'DOWNLOAD_ENABLED', 'true', 'Activer les fonctions de tlchargement de produits.', 13, 1, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (288, 'Tlcharger avec redirection', 'DOWNLOAD_BY_REDIRECT', 'true', 'Utiliser une redirection du navigateur pour les tlchargements. Dsactivez sur les systmes non-Unix.<br /><br />Note: Configurez /pub en chmod 777 si la redirection est active', 13, 2, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (289, 'Tlcharger en streaming', 'DOWNLOAD_IN_CHUNKS', 'false', 'Si le tlchargement par redirection est dsactiv, et que votre rglage PHP memory_limit est sous les 8 Mo, vous pouvez activer ce paramtre pour que les fichiers soient diffuss en segments au navigateur.<br /><br />N''a pas d''effet si le tlchargement par redirections est activ.', 13, 2, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (290, 'Expiration tlchargements (Nombre de jours)', 'DOWNLOAD_MAX_DAYS', '7', 'Configure le nombre de jours avant que le tlchargement n''expire. 0 signifie que c''est illimit.', 13, 3, NULL, '2007-11-04 19:39:59', NULL, '');
INSERT INTO configuration VALUES (291, 'Nombre de tlchargements autoriss - Par produit', 'DOWNLOAD_MAX_COUNT', '5', 'Nombre maximum de tlchargements autoriss. 0 signifie aucun tlchargement autoris.', 13, 4, NULL, '2007-11-04 19:39:59', NULL, '');
INSERT INTO configuration VALUES (292, 'Gestionnaire tlchargements, valeur des tats de commande', 'DOWNLOADS_ORDERS_STATUS_UPDATED_VALUE', '4', 'Quel statut de commande annule les jours et limites de tlchargements - Par dfaut c''est 4', 13, 10, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (293, 'Gestionnaire tlchargements, valeur des tats de commande >= valeur basse', 'DOWNLOADS_CONTROLLER_ORDERS_STATUS', '2', 'Gestionnaire tlchargements, valeur des tats de commande - Par Dfaut >= 2<br /><br />Les tlchargements sont disponibles pour les commandes bases sur l''tat des commandes. Les commandes avec un tat plus grand que cette valeur seront disponibles en tlchargement. Le statut de commande est configur par les modules de paiement. Ici la valeur la plus basse de cette plage.', 13, 12, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (294, 'Gestionnaire tlchargements, valeur des tats de commande <= valeur haute', 'DOWNLOADS_CONTROLLER_ORDERS_STATUS_END', '4', 'Gestionnaire tlchargements, valeur des tats de commande - Par Dfaut <= 4<br /><br />Les tlchargements sont disponibles pour les commandes bases sur l''tat des commandes. Les commandes avec un tat plus grand que cette valeur seront disponibles en tlchargement. Le statut de commande est configur par les modules de paiement. Ici la valeur la plus haute de cette plage.', 13, 13, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (295, 'Activer le facteur de prix', 'ATTRIBUTES_ENABLED_PRICE_FACTOR', 'true', 'Activer l''attribut facteur de prix.', 13, 25, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (296, 'Active les remises de prix sur Qt', 'ATTRIBUTES_ENABLED_QTY_PRICES', 'true', 'Active l''attribut de remises de prix sur Quantit.', 13, 26, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (297, 'Active les attributs Images', 'ATTRIBUTES_ENABLED_IMAGES', 'true', 'Active les attributs Images.', 13, 28, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (298, 'Active le texte de prix par mot ou lettre', 'ATTRIBUTES_ENABLED_TEXT_PRICES', 'true', 'Active l''attribut texte de prix par mot ou lettre', 13, 35, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (299, 'Texte du Prix - Espaces gratuits', 'TEXT_SPACES_FREE', '1', 'Sur les prix, les espaces sont gratuits<br /><br />0= off 1= on', 13, 36, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (300, 'Type d''option ReadOnly - Ignorer les ajouts au panier', 'PRODUCTS_OPTIONS_TYPE_READONLY_IGNORED', '1', 'Quand un produit utilise les attributs READONLY (lecture seule), est-ce que le bouton Ajouter au panier doit tre actif ou inactif?<br />0= OFF<br />1= ON', 13, 37, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (301, 'Active la Compression GZip', 'GZIP_LEVEL', '0', '0= off 1= on', 14, 1, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''),');
INSERT INTO configuration VALUES (302, 'Rpertoire des Sessions', 'SESSION_WRITE_DIRECTORY', '/tmp', 'Si les sessions sont stocke en fichiers, les stocker dans ce rpertoire.', 15, 1, '2008-03-05 11:05:40', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (303, 'Domaine du Cookie', 'SESSION_USE_FQDN', 'True', 'Si "True" alors le nom de domaine complet sera utilis pour stocker le cookie, ex. www.mondomaine.com. Si "False" alors le nom de domaine sera utilis partiellement, ex. mondomaine.com. Si vous n''tes pas sr, laissez cette option  true.', 15, 2, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (304, 'Forcer Utilisation des Cookies', 'SESSION_FORCE_COOKIE_USE', 'False', 'Forcer l''utilisation des sessions quand les cookies sont activs uniquement.', 15, 2, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (305, 'Vrifier SSL Session ID', 'SESSION_CHECK_SSL_SESSION_ID', 'False', 'Valider le SSL_SESSION_ID sur chaque requte de page scurise HTTPS.', 15, 3, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (306, 'Vrifier le navigateur', 'SESSION_CHECK_USER_AGENT', 'False', 'Vrifier la navigateur client (user agent)  chaque requte de page.', 15, 4, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (307, 'Vrifier les adresses IP', 'SESSION_CHECK_IP_ADDRESS', 'False', 'Vrifier l''adresse IP des clients sur chaque requte de page.', 15, 5, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (308, 'Interdire les sessions aux Robots', 'SESSION_BLOCK_SPIDERS', 'True', 'Interdit la cration d''une sessions  tous les robots de moteurs de recherche connus.', 15, 6, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (309, 'Recrer Session', 'SESSION_RECREATE', 'True', 'Recrer une session pour gnrer un nouvel ID de session quand le client s''identifie ou cr un compte (PHP >=4.1 seulement).', 15, 7, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (310, 'Conversion IP en Nom d''hte', 'SESSION_IP_TO_HOST_ADDRESS', 'true', 'Convertir les adresses IP en nom d''hte<br /><br />Note: sur certains serveurs cela peut ralentir le dmarrage initial d''une session ou les Emails', 15, 10, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (311, 'Longueur du code de rduction', 'SECURITY_CODE_LENGTH', '10', 'Entrez la longueur du code de rduction<br />Le plus long possible sera le plus scuris', 16, 1, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (312, 'Etat de commande par dfaut pour les commandes avec un solde  zro', 'DEFAULT_ZERO_BALANCE_ORDERS_STATUS_ID', '2', 'Lorsque le solde d''une commande est de zro, cet tat de commande lui sera assign.', 16, 0, NULL, '2007-11-04 19:39:59', 'zen_get_order_status_name', 'zen_cfg_pull_down_order_statuses(');
INSERT INTO configuration VALUES (313, 'Numro ID# d''un code de rduction  l''inscription client', 'NEW_SIGNUP_DISCOUNT_COUPON', '', 'Slectionnez le coupon<br />', 16, 75, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_coupon_id(');
INSERT INTO configuration VALUES (314, 'Montant du chque cadeau pour nouvelle inscription', 'NEW_SIGNUP_GIFT_VOUCHER_AMOUNT', '', 'Laissez blanc pour aucun<br />Ou entrez un montant, ex: 10 for 10.00', 16, 76, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (315, 'Coupons de rduction maximum Par Page', 'MAX_DISPLAY_SEARCH_RESULTS_DISCOUNT_COUPONS', '20', 'Coupons de rduction maximum  lister par Page', 16, 81, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (316, 'Coupons de rduction maximum Par Page de rapport', 'MAX_DISPLAY_SEARCH_RESULTS_DISCOUNT_COUPONS_REPORTS', '20', 'Nombre de coupons de rduction  lister sur une page de rapports', 16, 81, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (317, 'Autorisation Carte de crdit - VISA', 'CC_ENABLED_VISA', '1', 'Accepter les VISA 0= off 1= on', 17, 1, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (318, 'Autorisation Carte de crdit - MasterCard', 'CC_ENABLED_MC', '1', 'Accepter les MasterCard 0= off 1= on', 17, 2, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (319, 'Autorisation Carte de crdit - AmericanExpress', 'CC_ENABLED_AMEX', '0', 'Accepter AmericanExpress 0= off 1= on', 17, 3, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (320, 'Autorisation Carte de crdit - Diners Club', 'CC_ENABLED_DINERS_CLUB', '0', 'Accepter les Diners Club 0= off 1= on', 17, 4, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (321, 'Autorisation Carte de crdit - Discover Card', 'CC_ENABLED_DISCOVER', '0', 'Accepter les Discover Card 0= off 1= on', 17, 5, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (322, 'Autorisation Carte de crdit - JCB', 'CC_ENABLED_JCB', '0', 'Accepter les JCB 0= off 1= on', 17, 6, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (323, 'Autorisation Carte de crdit - AUSTRALIAN BANKCARD', 'CC_ENABLED_AUSTRALIAN_BANKCARD', '0', 'Accepter les AUSTRALIAN BANKCARD 0= off 1= on', 17, 7, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (324, 'Autorisation Carte de crdit - SOLO', 'CC_ENABLED_SOLO', '0', 'Accepter les cartes SOLO 0= off 1= on', 17, 8, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (325, 'Autorisation Carte de crdit - Switch', 'CC_ENABLED_SWITCH', '0', 'Accepter les cartes SWITCH 0= off 1= on', 17, 9, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (326, 'Autorisation Carte de crdit - Maestro', 'CC_ENABLED_MAESTRO', '0', 'Accepter les cartes MAESTRO 0= off 1= on', 17, 10, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (327, 'Cartes de crdit autorises - Afficher au paiement', 'SHOW_ACCEPTED_CREDIT_CARDS', '0', 'Montrer les cartes de crdit acceptes sur la page de paiement?<br />0= off<br />1= En Texte<br />2= En Images<br /><br />Note: images et textes doivent tre dfinis  la fois en base de donnes et fichiers de langues pour chaque type de carte.', 17, 50, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2''), ');
INSERT INTO configuration VALUES (328, 'Ce module est install', 'MODULE_ORDER_TOTAL_GV_STATUS', 'true', '', 6, 1, NULL, '2003-10-30 22:16:40', NULL, 'zen_cfg_select_option(array(''true''),');
INSERT INTO configuration VALUES (329, 'Ordre de tri', 'MODULE_ORDER_TOTAL_GV_SORT_ORDER', '840', 'Ordre d''affichage.', 6, 2, NULL, '2003-10-30 22:16:40', NULL, NULL);
INSERT INTO configuration VALUES (330, 'Cumuler Bon d''Achats', 'MODULE_ORDER_TOTAL_GV_QUEUE', 'true', 'Voulez-vous cumuler les achats de bons d''achat?', 6, 3, NULL, '2003-10-30 22:16:40', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (331, 'Inclure la Livraison', 'MODULE_ORDER_TOTAL_GV_INC_SHIPPING', 'true', 'Inclure la livraison dans le calcul', 6, 5, NULL, '2003-10-30 22:16:40', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (332, 'Inclure Taxes', 'MODULE_ORDER_TOTAL_GV_INC_TAX', 'true', 'Inclure les Taxes dans le calcul.', 6, 6, NULL, '2003-10-30 22:16:40', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (333, 'Re-calculer les Taxes', 'MODULE_ORDER_TOTAL_GV_CALC_TAX', 'None', 'Re-calculer les Taxes', 6, 7, NULL, '2003-10-30 22:16:40', NULL, 'zen_cfg_select_option(array(''None'', ''Standard'', ''Credit Note''),');
INSERT INTO configuration VALUES (334, 'Classe de Taxes', 'MODULE_ORDER_TOTAL_GV_TAX_CLASS', '0', 'Utiliser la classe de taxes suivante pour le traitement du bon d''achat comme avoir.', 6, 0, NULL, '2003-10-30 22:16:40', 'zen_get_tax_class_title', 'zen_cfg_pull_down_tax_classes(');
INSERT INTO configuration VALUES (335, 'Crditer avec les Taxes', 'MODULE_ORDER_TOTAL_GV_CREDIT_TAX', 'false', 'Ajouter une Taxe au bon d''achat lorsque le compte est crdit', 6, 8, NULL, '2003-10-30 22:16:40', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (336, 'Etat de commande', 'MODULE_ORDER_TOTAL_GV_ORDER_STATUS_ID', '0', 'Configure l''tat des commandes passes avec un bon d''achat qui couvre tout le paiement', 6, 0, NULL, '2007-11-04 19:39:59', 'zen_get_order_status_name', 'zen_cfg_pull_down_order_statuses(');
INSERT INTO configuration VALUES (337, 'Ce module est install', 'MODULE_ORDER_TOTAL_LOWORDERFEE_STATUS', 'true', '', 6, 1, NULL, '2003-10-30 22:16:43', NULL, 'zen_cfg_select_option(array(''true''),');
INSERT INTO configuration VALUES (338, 'Ordre de tri', 'MODULE_ORDER_TOTAL_LOWORDERFEE_SORT_ORDER', '400', 'Ordre d''affichage.', 6, 2, NULL, '2003-10-30 22:16:43', NULL, NULL);
INSERT INTO configuration VALUES (339, 'Autoriser les frais de commande', 'MODULE_ORDER_TOTAL_LOWORDERFEE_LOW_ORDER_FEE', 'false', 'Voulez-vous utiliser les frais de commande?', 6, 3, NULL, '2003-10-30 22:16:43', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (340, 'Frais de commande pour commandes en dessous de', 'MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER', '50', 'Ajouter les frais de commande pour les commandes en dessous de ce montant.', 6, 4, NULL, '2003-10-30 22:16:43', 'currencies->format', NULL);
INSERT INTO configuration VALUES (341, 'Frais de commande', 'MODULE_ORDER_TOTAL_LOWORDERFEE_FEE', '5', 'Pour un calcul en pourcentage - inclure un % Exemple: 10%<br />Pour un motent statique entrez juste le montant - Exemple: 5 pour 5.00', 6, 5, NULL, '2003-10-30 22:16:43', '', NULL);
INSERT INTO configuration VALUES (342, 'Frais de commande pour les commandes faites ', 'MODULE_ORDER_TOTAL_LOWORDERFEE_DESTINATION', 'both', 'Ajouter des frais de commande pour les commandes envoyes  cette destination.', 6, 6, NULL, '2003-10-30 22:16:43', NULL, 'zen_cfg_select_option(array(''national'', ''international'', ''both''),');
INSERT INTO configuration VALUES (343, 'Classe de taxe', 'MODULE_ORDER_TOTAL_LOWORDERFEE_TAX_CLASS', '0', 'Utiliser la classe de taxe suivante sur les frais de commande.', 6, 7, NULL, '2003-10-30 22:16:43', 'zen_get_tax_class_title', 'zen_cfg_pull_down_tax_classes(');
INSERT INTO configuration VALUES (344, 'Pas de frais de commande sur les produits virtuels', 'MODULE_ORDER_TOTAL_LOWORDERFEE_VIRTUAL', 'false', 'Ne pas ajouter de frais de commande quand le panier ne contient que des produits virtuels', 6, 8, NULL, '2004-04-20 22:16:43', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (345, 'Pas de frais de commande sur les bons d''achat', 'MODULE_ORDER_TOTAL_LOWORDERFEE_GV', 'false', 'Ne pas ajouter de frais de commande quand le panier n''est compos que de bons d''achat', 6, 9, NULL, '2004-04-20 22:16:43', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (346, 'Ce module est install', 'MODULE_ORDER_TOTAL_SHIPPING_STATUS', 'true', '', 6, 1, NULL, '2003-10-30 22:16:46', NULL, 'zen_cfg_select_option(array(''true''),');
INSERT INTO configuration VALUES (347, 'Ordre de tri', 'MODULE_ORDER_TOTAL_SHIPPING_SORT_ORDER', '200', 'Ordre d''affichage.', 6, 2, NULL, '2003-10-30 22:16:46', NULL, NULL);
INSERT INTO configuration VALUES (348, 'Active la livraison gratuite', 'MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING', 'false', 'Voulez-vous activer la livraison gratuite?', 6, 3, NULL, '2003-10-30 22:16:46', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (349, 'Livraison gratuite pour les commandes au dessus de', 'MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER', '50', 'Fournit la livraison gratuite pour les commandes au dessus du montant spcifi.', 6, 4, NULL, '2003-10-30 22:16:46', 'currencies->format', NULL);
INSERT INTO configuration VALUES (350, 'Livraison gratuite pour les commandes...', 'MODULE_ORDER_TOTAL_SHIPPING_DESTINATION', 'national', 'Livraison gratuite pour la zone gographique spcifie.', 6, 5, NULL, '2003-10-30 22:16:46', NULL, 'zen_cfg_select_option(array(''national'', ''international'', ''both''),');
INSERT INTO configuration VALUES (351, 'Ce module est install', 'MODULE_ORDER_TOTAL_SUBTOTAL_STATUS', 'true', '', 6, 1, NULL, '2003-10-30 22:16:49', NULL, 'zen_cfg_select_option(array(''true''),');
INSERT INTO configuration VALUES (352, 'Ordre de tri', 'MODULE_ORDER_TOTAL_SUBTOTAL_SORT_ORDER', '100', 'L''ordre d''affichage.', 6, 2, NULL, '2003-10-30 22:16:49', NULL, NULL);
INSERT INTO configuration VALUES (353, 'Ce module est install', 'MODULE_ORDER_TOTAL_TAX_STATUS', 'true', '', 6, 1, NULL, '2003-10-30 22:16:52', NULL, 'zen_cfg_select_option(array(''true''),');
INSERT INTO configuration VALUES (354, 'Ordre d''affichage', 'MODULE_ORDER_TOTAL_TAX_SORT_ORDER', '300', 'Configure l''ordre d''affichage.', 6, 2, NULL, '2003-10-30 22:16:52', NULL, NULL);
INSERT INTO configuration VALUES (355, 'Ce module est install', 'MODULE_ORDER_TOTAL_TOTAL_STATUS', 'true', '', 6, 1, NULL, '2003-10-30 22:16:55', NULL, 'zen_cfg_select_option(array(''true''),');
INSERT INTO configuration VALUES (356, 'Ordre d''affichage', 'MODULE_ORDER_TOTAL_TOTAL_SORT_ORDER', '999', 'Configure l''ordre d''affichage.', 6, 2, NULL, '2003-10-30 22:16:55', NULL, NULL);
INSERT INTO configuration VALUES (357, 'Classe de Taxe', 'MODULE_ORDER_TOTAL_COUPON_TAX_CLASS', '0', 'Utiliser la classe de taxe suivante lors du traitement des coupons de rduction en tant qu''avoir.', 6, 0, NULL, '2003-10-30 22:16:36', 'zen_get_tax_class_title', 'zen_cfg_pull_down_tax_classes(');
INSERT INTO configuration VALUES (358, 'Inclure Taxes', 'MODULE_ORDER_TOTAL_COUPON_INC_TAX', 'false', 'inclure les taxes dans le calcul.', 6, 6, NULL, '2003-10-30 22:16:36', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (359, 'Ordre d''affichage', 'MODULE_ORDER_TOTAL_COUPON_SORT_ORDER', '280', 'Configure l''ordre d''affichage.', 6, 2, NULL, '2003-10-30 22:16:36', NULL, NULL);
INSERT INTO configuration VALUES (360, 'Inclure la livraison', 'MODULE_ORDER_TOTAL_COUPON_INC_SHIPPING', 'false', 'Inclure la livraison dans le calcul', 6, 5, NULL, '2003-10-30 22:16:36', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (361, 'Ce module est install', 'MODULE_ORDER_TOTAL_COUPON_STATUS', 'true', '', 6, 1, NULL, '2003-10-30 22:16:36', NULL, 'zen_cfg_select_option(array(''true''),');
INSERT INTO configuration VALUES (362, 'Re-calculer Taxes', 'MODULE_ORDER_TOTAL_COUPON_CALC_TAX', 'Standard', 'Re-Calculer Taxes', 6, 7, NULL, '2003-10-30 22:16:36', NULL, 'zen_cfg_select_option(array(''None'', ''Standard'', ''Credit Note''),');
INSERT INTO configuration VALUES (363, 'Etat de la dmo Admin', 'ADMIN_DEMO', '0', 'La dmo de l''Admin doit tre active?<br />0= off 1= on', 6, 0, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (364, 'Slection du type d''option produit', 'PRODUCTS_OPTIONS_TYPE_SELECT', '0', 'Le nombre reprsentant le type d''option de produit slectionn.', 0, NULL, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (365, 'Text product option type', 'PRODUCTS_OPTIONS_TYPE_TEXT', '1', 'Valeur numrique du type d''option du texte produit', 6, NULL, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (366, 'Type d''option produit des boutons radio', 'PRODUCTS_OPTIONS_TYPE_RADIO', '2', 'Valeur numrique du type d''option produit des boutons radio', 6, NULL, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (367, 'Type d''option produit des cases  cocher', 'PRODUCTS_OPTIONS_TYPE_CHECKBOX', '3', 'Valeur numrique des Types d''option produit des cases  cocher', 6, NULL, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (368, 'Type d''option produit du champ fichier', 'PRODUCTS_OPTIONS_TYPE_FILE', '4', 'Valeur numrique du Type d''option produit du champ fichier', 6, NULL, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (369, 'ID des valeurs d''options produits textes et fichiers', 'PRODUCTS_OPTIONS_VALUES_TEXT_ID', '0', 'Valeur numrique de products_options_values_id utilis parl es attributs textes et fichiers.', 6, NULL, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (370, 'Prfixe upload', 'UPLOAD_PREFIX', 'upload_', 'Prefixe utilis pour diffrencier les options d''upload (envois) et les autres options', 0, NULL, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (371, 'Prfixe Texte', 'TEXT_PREFIX', 'txt_', 'Prefixe utilis pour diffrencier les valeur d''options Texte et les autres options', 0, NULL, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (372, 'Type d''option lecture seule', 'PRODUCTS_OPTIONS_TYPE_READONLY', '5', 'Valeur numrique du type d''option produit fichiers', 6, NULL, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (373, 'Infos Produit - Ordre d''affichage des options de produits', 'PRODUCTS_OPTIONS_SORT_ORDER', '0', 'Ordre d''affichage des noms des options sur les Infos produits<br />0= Ordre d''affichage, nom d''option<br />1= Nom d''option', 18, 35, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''),');
INSERT INTO configuration VALUES (374, 'Infos produits - Affichage Options produits des attributs', 'PRODUCTS_OPTIONS_SORT_BY_PRICE', '1', 'Ordre d''affichage des valeurs d''option produits sur les attributs des infos produits<br />0= Ordre d''affichage, Prix<br />1= Ordre d''affichage, Valeur de l''option', 18, 36, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''),');
INSERT INTO configuration VALUES (375, 'Infos produits - Affiche les noms des options sous l''attribut Image', 'PRODUCT_IMAGES_ATTRIBUTES_NAMES', '1', 'Infos produits - Affiche les noms des options sous l''attribut Image?<br />0= off 1= on', 18, 41, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (376, 'Infos produits - Affiche les prix remiss', 'SHOW_SALE_DISCOUNT_STATUS', '1', 'Infos produits - Affiche le montant des prix remiss?<br />0= off 1= on', 18, 45, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (377, 'Infos produits - Affiche les prix remiss en euros ou pourcentage', 'SHOW_SALE_DISCOUNT', '1', 'Infos produits - Affiche le montant des prix remiss en:<br />1= % 2= montant en ', 18, 46, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''1'', ''2''), ');
INSERT INTO configuration VALUES (378, 'Infos produits - Nombre de dcimales  afficher sur les pourcentage de remises', 'SHOW_SALE_DISCOUNT_DECIMALS', '0', 'Infos produits - Combien de dcimales faut-il afficher sur les pourcentages de remise?:<br />Par dfaut = 0', 18, 47, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (379, 'Infos Produits - Prix gratuit Etat de l''image et texte ', 'OTHER_IMAGE_PRICE_IS_FREE_ON', '1', 'Infos Produits - Affiche l''image ou le texte Prix Gratuit sur les prix affichs<br />0= Texte<br />1= Image', 18, 50, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (380, 'Infos Produits - Prix sur demande, tat de l''image et texte', 'PRODUCTS_PRICE_IS_CALL_IMAGE_ON', '1', 'Infos Produits - Affiche l''image ou le texte "prix sur demande" <br />0= Texte<br />1= Image', 18, 51, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (381, 'Etat de la liste Qt de produits - Ajout de nouveaux produits', 'PRODUCTS_QTY_BOX_STATUS', '1', 'Sur quoi doit tre rgle la liste de Quantit de produits par dfaut lors de l''ajout de nouveaux produits?<br /><br />0= off<br />1= on<br />NOTE: Affiche la liste Qt de produits sur ON ou juste "ajouter au panier" sur 1', 18, 55, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (382, 'Avis de produits en attente de validation', 'REVIEWS_APPROVAL', '1', 'Est-ce que les avis sur le produits ncessite une validation?<br /><br />Note: Quand l''tat des avis est sur off, cela ne s''affichera pas non plus<br /><br />0= off 1= on', 18, 62, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (383, 'Meta Tags - Inclure le modle du produit dans le titre', 'META_TAG_INCLUDE_MODEL', '0', 'Voulez-vous inclure la rfrence du produit dans le Meta Tag Title (titre de page)?<br /><br />0= off 1= on', 18, 69, '2008-02-28 12:45:07', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (384, 'Meta Tags - Inclure le prix du produit dans le titre', 'META_TAG_INCLUDE_PRICE', '0', 'Voulez-vous inclure le prix du produit dans le Meta Tag Title (titre de page)?<br /><br />0= off 1= on', 18, 70, '2008-02-28 12:45:11', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (385, 'Longueur maximum des Meta Tags gnrs pour la Description?', 'MAX_META_TAG_DESCRIPTION_LENGTH', '50', 'Configure la longueur maximum des Meta Tags gnrs pour la Description  (nb de mots) Par Dfaut 50:', 18, 71, NULL, '2007-11-04 19:39:59', '', '');
INSERT INTO configuration VALUES (386, 'Produits aussi achets, colonnes par ligne ', 'SHOW_PRODUCT_INFO_COLUMNS_ALSO_PURCHASED_PRODUCTS', '3', 'Produits aussi achets, colonnes par ligne<br />0= off ou configurez l''ordre affichage', 18, 72, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4'', ''5'', ''6'', ''7'', ''8'', ''9'', ''10'', ''11'', ''12''), ');
INSERT INTO configuration VALUES (387, 'Prcdent Suivant - Position de la barre de navigation', 'PRODUCT_INFO_PREVIOUS_NEXT', '1', 'Position de la barre de navigation Prcdent/Suivant<br />0= off<br />1= Haut de Page<br />2= Bas of Page<br />3= Les deux (haut et bas de page)', 18, 21, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Off''), array(''id''=>''1'', ''text''=>''Top of Page''), array(''id''=>''2'', ''text''=>''Bottom of Page''), array(''id''=>''3'', ''text''=>''Both Top & Bottom of Page'')),');
INSERT INTO configuration VALUES (388, 'Prcdent Suivant - Ordre d''affichage', 'PRODUCT_INFO_PREVIOUS_NEXT_SORT', '1', 'L''affichage des produits est class par<br />0= ID Produit<br />1= Nom Produit<br />2= Rfrence<br />3= Prix, Nom Produit<br />4= Prix, Rfrence<br />5= Nom produit, Rfrence<br />6= Ordre d''affichage des produits', 18, 22, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Product ID''), array(''id''=>''1'', ''text''=>''Name''), array(''id''=>''2'', ''text''=>''Product Model''), array(''id''=>''3'', ''text''=>''Product Price - Name''), array(''id''=>''4'', ''text''=>''Product Price - Model''), array(''id''=>''5'', ''text''=>''Product Name - Model''), array(''id''=>''6'', ''text''=>''Product Sort Order'')),');
INSERT INTO configuration VALUES (389, 'Prcdent Suivant - Etat image ou bouton', 'SHOW_PREVIOUS_NEXT_STATUS', '0', 'Configuration de l''tat du bouton ou image de produits :<br />0= Off<br />1= On', 18, 20, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Off''), array(''id''=>''1'', ''text''=>''On'')),');
INSERT INTO configuration VALUES (390, 'Prcdent Suivant - Configuration bouton ou image', 'SHOW_PREVIOUS_NEXT_IMAGES', '0', 'Configuration de l''affichage du bouton ou image produit Prcdent/Suivant<br />0= Bouton seulement<br />1= Bouton et image Produit<br />2= Image produit seulement', 18, 21, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Button Only''), array(''id''=>''1'', ''text''=>''Button and Product Image''), array(''id''=>''2'', ''text''=>''Product Image Only'')),');
INSERT INTO configuration VALUES (391, 'Prcdent Suivant - Largeur image?', 'PREVIOUS_NEXT_IMAGE_WIDTH', '50', 'Largeur de l''image Prcdent/Suivant?', 18, 22, NULL, '2007-11-04 19:39:59', '', '');
INSERT INTO configuration VALUES (392, 'Prcdent Suivant - Hauteur image?', 'PREVIOUS_NEXT_IMAGE_HEIGHT', '40', 'Hauteur de l''image Prcdent/Suivant?', 18, 23, NULL, '2007-11-04 19:39:59', '', '');
INSERT INTO configuration VALUES (393, 'Prcdent Suivant - La navigation inclut la catgorie en cours', 'PRODUCT_INFO_CATEGORIES', '1', 'Alignement du nom et image de Catgorie de produits sous la barre de navigation Prcdent/Suivant<br />0= off<br />1= Aligner  gauche<br />2= Aligner au centre<br />3= Aligner  droite', 18, 20, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Off''), array(''id''=>''1'', ''text''=>''Align Left''), array(''id''=>''2'', ''text''=>''Align Center''), array(''id''=>''3'', ''text''=>''Align Right'')),');
INSERT INTO configuration VALUES (394, 'Prcdent Suivant - La navigation inclut le nom et image de catgorie (Etat)', 'PRODUCT_INFO_CATEGORIES_IMAGE_STATUS', '2', 'Etat du nom et image de catgorie<br />0= Le nom de catgorie et image s''affichent toujours<br />1= Nom de catgorie seulement<br />2= Nom de catgorie et image quand elle existe', 18, 20, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Category Name and Image Always''), array(''id''=>''1'', ''text''=>''Category Name only''), array(''id''=>''2'', ''text''=>''Category Name and Image when not blank'')),');
INSERT INTO configuration VALUES (395, 'Largeur de colonne - Boites de gauche', 'BOX_WIDTH_LEFT', '150px', 'Largeur des boites de la colonne de gauche (menus gauche)<br />px peut-tre inclut pour dsigner le nombre de pixels<br />Par dfaut = 150px', 19, 1, NULL, '2003-11-21 22:16:36', NULL, NULL);
INSERT INTO configuration VALUES (396, 'Largeur colonne - Boites de droite', 'BOX_WIDTH_RIGHT', '150px', 'Largeur des boites de la colonne de droite<br />px peut tre inclus<br />Par dfaut = 150px', 19, 2, NULL, '2003-11-21 22:16:36', NULL, NULL);
INSERT INTO configuration VALUES (397, 'Sparateur de barre de navigation du Haut', 'BREAD_CRUMBS_SEPARATOR', '&nbsp;::&nbsp;', 'Entrez le symbole du sparateur qui apparaitra entre les lments de la barre de navigation en Haut<br />Note: Inclure les espaces avec le symbole &amp;nbsp; si vous en voulez dans le sparateur.<br />Par dfaut = &amp;nbsp;::&amp;nbsp;', 19, 3, NULL, '2003-11-21 22:16:36', NULL, 'zen_cfg_textarea_small(');
INSERT INTO configuration VALUES (398, 'Etat de la barre de navigation', 'DEFINE_BREADCRUMB_STATUS', '1', 'Active les liens de ma barre de navigation?<br />0= OFF<br />1= ON<br />2= OFF pour la page d''accueil seulement', 19, 4, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2''), ');
INSERT INTO configuration VALUES (399, 'Bestsellers - Nombre de remplissage', 'BEST_SELLERS_FILLER', '&nbsp;', 'Avec quoi voulez-vous remplir les nombres?<br />Par Dfaut = &amp;nbsp;', 19, 5, NULL, '2003-11-21 22:16:36', NULL, 'zen_cfg_textarea_small(');
INSERT INTO configuration VALUES (400, 'Bestsellers - Couper les noms de produits', 'BEST_SELLERS_TRUNCATE', '35', 'A quel taille voulez-vous couper les noms de produits?<br />Par Dfaut = 35', 19, 6, NULL, '2003-11-21 22:16:36', NULL, NULL);
INSERT INTO configuration VALUES (401, 'Bestsellers - Couper les noms de produits suivis de ...', 'BEST_SELLERS_TRUNCATE_MORE', 'true', 'Quand on coupe un nom de produit, on le fait suivre de ...<br />Par dfaut = true', 19, 7, '2003-03-21 13:08:25', '2003-03-21 11:42:47', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (402, 'Boite catgorie - Affiche les liens promotions', 'SHOW_CATEGORIES_BOX_SPECIALS', 'true', 'Affiche le liens de promotions dans la boite Catgorie', 19, 8, '2003-03-21 13:08:25', '2003-03-21 11:42:47', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (403, 'Boite catgories - Affiche lien nouveaux produits', 'SHOW_CATEGORIES_BOX_PRODUCTS_NEW', 'true', 'Affiche le lien nouveaux produits dans la boite des catgories', 19, 9, '2003-03-21 13:08:25', '2003-03-21 11:42:47', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (404, 'Etat de la boite Panier', 'SHOW_SHOPPING_CART_BOX_STATUS', '1', 'Le panier s''affiche<br />0= Toujours<br />1= Seulement plein<br />2= seulement plein sur une page autre que celle du Panier', 19, 10, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2''), ');
INSERT INTO configuration VALUES (405, 'Boite Catgories - Affiche le lien des produits  la une', 'SHOW_CATEGORIES_BOX_FEATURED_PRODUCTS', 'true', 'Affiche le lien des produits  la une dans la Boite Catgories', 19, 11, '2003-03-21 13:08:25', '2003-03-21 11:42:47', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (406, 'Boite Catgories - Affiche le lien Tous les produits', 'SHOW_CATEGORIES_BOX_PRODUCTS_ALL', 'true', 'Affiche le lien Tous les produits dans la Boite Catgories', 19, 12, '2003-03-21 13:08:25', '2003-03-21 11:42:47', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (407, 'Colonne de gauche - Etat Global', 'COLUMN_LEFT_STATUS', '1', 'Affiche la colonne de gauche, sauf si une page est conue pour toujours l''afficher?<br />0= la colonne de gauche est toujours dsactive<br />1= La colonne de gauche est active, sauf page contraire', 19, 15, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (408, 'Colonne de droite - Etat Global', 'COLUMN_RIGHT_STATUS', '1', 'Affiche la colonne de droite, sauf si une page est conue pour toujours l''afficher?<br />0= la colonne de droite est toujours dsactive<br />1= La colonne de droite est active, sauf page contraire', 19, 16, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (409, 'Largeur de colonne - Gauche', 'COLUMN_WIDTH_LEFT', '150px', 'Largeur de la colonne de gauche<br />px peut tre inclus<br />Par Dfaut = 150px', 19, 20, NULL, '2003-11-21 22:16:36', NULL, NULL);
INSERT INTO configuration VALUES (410, 'Largeur de colonne - Droite', 'COLUMN_WIDTH_RIGHT', '150px', 'Largeur de la colonne de droite<br />px peut tre inclus<br />Par Dfaut = 150px', 19, 21, NULL, '2003-11-21 22:16:36', NULL, NULL);
INSERT INTO configuration VALUES (411, 'Sparateur de catgories entre les liens', 'SHOW_CATEGORIES_SEPARATOR_LINK', '1', 'Affiche les sparateurs de catgories entre leurs noms et liens?<br />0= off<br />1= on', 19, 24, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (412, 'Sparateur de catgories entre le Nom et Nombre', 'CATEGORIES_SEPARATOR', '-&gt;', 'Quel sparateur voulez-vous entre le nom de catgorie et le nombre?<br />Par Dfaut = -&amp;gt;', 19, 25, NULL, '2003-11-21 22:16:36', NULL, 'zen_cfg_textarea_small(');
INSERT INTO configuration VALUES (413, 'Sparateur de catgories entre le Nom catgorie et les sous catgories', 'CATEGORIES_SEPARATOR_SUBS', '|_&nbsp;', 'Quel sparateur voulez-vous entre le Nom de catgorie et ses sous-catgories?<br />Par Dfaut = |_&amp;nbsp;', 19, 26, NULL, '2004-03-25 22:16:36', NULL, 'zen_cfg_textarea_small(');
INSERT INTO configuration VALUES (414, 'Prfixe pour le nombre de produits d''une catgorie', 'CATEGORIES_COUNT_PREFIX', '&nbsp;(', 'Quel prfixe voulez-vous mettre avant le nombre de produits d''une catgorie?<br />Par Dfaut= (', 19, 27, NULL, '2003-01-21 22:16:36', NULL, 'zen_cfg_textarea_small(');
INSERT INTO configuration VALUES (415, 'Suffixe pour le nombre de produits d''une catgorie', 'CATEGORIES_COUNT_SUFFIX', ')', 'Quel suffixe voulez-vous mettre aprs le nombre de produits d''une catgorie??<br />Par Dfaut= )', 19, 28, NULL, '2003-01-21 22:16:36', NULL, 'zen_cfg_textarea_small(');
INSERT INTO configuration VALUES (416, 'Indentation des sous-catgories', 'CATEGORIES_SUBCATEGORIES_INDENT', '&nbsp;&nbsp;', 'Quel type d''identation voulez-vous utiliser pour les noms des sous-catgories?<br />Par Dfaut= &nbsp;&nbsp;', 19, 29, NULL, '2004-06-24 22:16:36', NULL, 'zen_cfg_textarea_small(');
INSERT INTO configuration VALUES (417, 'Etat des catgories avec 0 Produits', 'CATEGORIES_COUNT_ZERO', '0', 'Affiche le nombre de produits d''une catgorie vide?<br />0= off<br />1= on', 19, 30, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (418, 'Coupe la boite Catgories', 'CATEGORIES_SPLIT_DISPLAY', 'True', 'oupe la boite Catgories affiche par type de produits', 19, 31, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (419, 'Panier - Affiche le total', 'SHOW_TOTALS_IN_CART', '1', 'Afficher le total sous le Panier?<br />0= off<br />1= on: poids des articles<br />2= on: poids des articles, mais pas de poids quand 0<br />3= on: Montant des articles', 19, 31, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''), ');
INSERT INTO configuration VALUES (420, 'Bienvenue client - Afficher sur la page d''accueil', 'SHOW_CUSTOMER_GREETING', '1', 'Toujours afficher le bienvenue client sur la page d''accueil?<br />0= off<br />1= on', 19, 40, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (421, 'Catgories - Toujours afficher sur la page principale', 'SHOW_CATEGORIES_ALWAYS', '0', 'Toujours afficher les catgories sur la page principale<br />0= off<br />1= on<br />Une catgorie par dfaut peut tre configure pour le niveau Haut', 19, 45, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (422, 'Page principale - Ouverture avec les catgories', 'CATEGORIES_START_MAIN', '0', '0= Catgories principales<br />Ou entrez l''ID de la catgorie<br />Note: Les sous-catgories peuvent tre aussi utilises. Exemple: 3_10', 19, 46, NULL, '2007-11-04 19:39:59', '', '');
INSERT INTO configuration VALUES (423, 'Catgories - Toujours ouvertes pour afficher les sous-catgories', 'SHOW_CATEGORIES_SUBCATEGORIES_ALWAYS', '1', 'Toujours afficher les catgories et sous-catgories<br />0= off, affiche seulement les catgories principales<br />1= on, Toujours afficher les catgories + sous-catgories', 19, 47, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (424, 'Groupes d''affichage de banires - Position en-tte 1', 'SHOW_BANNERS_GROUP_SET1', '', 'Les groupes d''affichage de bannires peut tre un groupe d''une bannire ou de multiples bannires<br /><br />Pour un groupe de bannires multiple, entrez le nom du groupe de bannires spar par deux points <strong>:</strong><br /><br />Exemple: Wide-Banners:SideBox-Banners<br /><br />Quel groupe(s) de bannires voulez-vous utiliser pour la position en-tte 1?<br />Laissez vide pour aucun', 19, 55, NULL, '2007-11-04 19:39:59', '', '');
INSERT INTO configuration VALUES (425, 'Groupes d''affichage de banires - Position en-tte 2', 'SHOW_BANNERS_GROUP_SET2', '', 'Les groupes d''affichage de bannires peut tre un groupe d''une bannire ou de multiples bannires<br /><br />Pour un groupe de bannires multiple, entrez le nom du groupe de bannires spar par deux points <strong>:</strong><br /><br />Exemple: Wide-Banners:SideBox-Banners<br /><br />Quel groupe(s) de bannires voulez-vous utiliser pour la position en-tte 1?<br />Laissez vide pour aucun', 19, 56, NULL, '2007-11-04 19:39:59', '', '');
INSERT INTO configuration VALUES (426, 'Groupes d''affichage de banires - Position en-tte 3', 'SHOW_BANNERS_GROUP_SET3', '', 'Les groupes d''affichage de bannires peut tre un groupe d''une bannire ou de multiples bannires<br /><br />Pour un groupe de bannires multiple, entrez le nom du groupe de bannires spar par deux points <strong>:</strong><br /><br />Exemple: Wide-Banners:SideBox-Banners<br /><br />Quel groupe(s) de bannires voulez-vous utiliser pour la position en-tte 3?<br />Laissez vide pour aucun', 19, 57, NULL, '2007-11-04 19:39:59', '', '');
INSERT INTO configuration VALUES (427, 'Groupes d''affichage de banires - Position pied de page 1', 'SHOW_BANNERS_GROUP_SET4', '', 'Les groupes d''affichage de bannires peut tre un groupe d''une bannire ou de multiples bannires<br /><br />Pour un groupe de bannires multiple, entrez le nom du groupe de bannires spar par deux points <strong>:</strong><br /><br />Exemple: Wide-Banners:SideBox-Banners<br /><br />Quel groupe(s) de bannires voulez-vous utiliser pour la position pied de page 1?<br />Laissez vide pour aucun', 19, 65, NULL, '2007-11-04 19:39:59', '', '');
INSERT INTO configuration VALUES (428, 'Groupes d''affichage de banires - Position pied de page 2', 'SHOW_BANNERS_GROUP_SET5', '', 'Les groupes d''affichage de bannires peut tre un groupe d''une bannire ou de multiples bannires<br /><br />Pour un groupe de bannires multiple, entrez le nom du groupe de bannires spar par deux points <strong>:</strong><br /><br />Exemple: Wide-Banners:SideBox-Banners<br /><br />Quel groupe(s) de bannires voulez-vous utiliser pour la position pied de page 2?<br />Laissez vide pour aucun', 19, 66, NULL, '2007-11-04 19:39:59', '', '');
INSERT INTO configuration VALUES (429, 'Groupes d''affichage de bannires - Position pied de page 3', 'SHOW_BANNERS_GROUP_SET6', 'Wide-Banners', 'Les groupes d''affichage de bannires peut tre un groupe d''une bannire ou de multiples bannires<br /><br />Pour un groupe de bannires multiple, entrez le nom du groupe de bannires spar par deux points <strong>:</strong><br /><br />Exemple: Wide-Banners:SideBox-Banners<br /><br />Quel groupe(s) de bannires voulez-vous utiliser pour la position pied de page 3?<br />Laissez vide pour aucun', 19, 67, NULL, '2007-11-04 19:39:59', '', '');
INSERT INTO configuration VALUES (430, 'Groupes d''affichage de bannires - Boite latrale banner_box', 'SHOW_BANNERS_GROUP_SET7', 'SideBox-Banners', 'Les groupes d''affichage de bannires peut tre un groupe d''une bannire ou de multiples bannires<br /><br />Pour un groupe de bannires multiple, entrez le nom du groupe de bannires spar par deux points <strong>:</strong><br /><br />Exemple: Wide-Banners:SideBox-Banners<br />Le groupe par Dfaut est SideBox-Banners<br /><br />Quel groupe(s) de bannires voulez-vous utilisez dans la Boite latrale - banner_box?<br />Laisser vide pour aucun', 19, 70, NULL, '2007-11-04 19:39:59', '', '');
INSERT INTO configuration VALUES (431, 'Groupes d''affichage de bannires - Boite latrale banner_box2', 'SHOW_BANNERS_GROUP_SET8', 'SideBox-Banners', 'Les groupes d''affichage de bannires peut tre un groupe d''une bannire ou de multiples bannires<br /><br />Pour un groupe de bannires multiple, entrez le nom du groupe de bannires spar par deux points <strong>:</strong><br /><br />Exemple: Wide-Banners:SideBox-Banners<br />Le groupe par Dfaut est SideBox-Banners<br /><br />Quel groupe(s) de bannires voulez-vous utilisez dans la Boite latrale - banner_box2?<br />Laisser vide pour aucun', 19, 71, NULL, '2007-11-04 19:39:59', '', '');
INSERT INTO configuration VALUES (432, 'Groupes d''affichage de bannires - Boite latrale banner_box_all', 'SHOW_BANNERS_GROUP_SET_ALL', 'BannersAll', 'Le groupe d''affichage de bannire peut seulement provenir d''un (1) groupe de bannires pour cette boite latrale<br /><br />Le groupe par dfaut est BannersAll<br /><br />Quel groupe de bannire voulez-vous utiliser dans la boite latrale - banner_box_all?<br />Laissez blanc pour aucun', 19, 72, NULL, '2007-11-04 19:39:59', '', '');
INSERT INTO configuration VALUES (433, 'Pied de page - Affiche l''adresse IP', 'SHOW_FOOTER_IP', '0', 'Affiche l''adresse IP du client dans le pied de page<br />0= off<br />1= on<br />Est-ce que l''adresse IP du client doit s''afficher dans le pied de page?', 19, 80, '2008-02-21 15:31:17', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (434, 'Remises sur quantit de produits - Ajouter combien de remises vides?', 'DISCOUNT_QTY_ADD', '5', 'Combien de remises vides doivent tre ajoutes pour le prix du produit?', 19, 90, NULL, '2007-11-04 19:39:59', '', '');
INSERT INTO configuration VALUES (435, 'Remises sur quantit de produits - Afficher combien par ligne?', 'DISCOUNT_QUANTITY_PRICES_COLUMN', '5', 'Combien de Remises sur quantit de produits doivent s''afficher par lignes sur les pages Infos produits?', 19, 95, NULL, '2007-11-04 19:39:59', '', '');
INSERT INTO configuration VALUES (436, 'Ordre d''affichage des Catgories/Produits', 'CATEGORIES_PRODUCTS_SORT_ORDER', '0', 'Categories/Products Display Sort Order<br />0= Categories/Products Sort Order/Name<br />1= Categories/Products Name<br />2= Products Model<br />3= Products Qty+, Products Name<br />4= Products Qty-, Products Name<br />5= Products Price+, Products Name<br />6= Products Price-, Products Name', 19, 100, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4'', ''5'', ''6''), ');
INSERT INTO configuration VALUES (437, 'Noms et valeurs des options fonctionnalits Globales d''ajout, copie et suppression - Etat', 'OPTION_NAMES_VALUES_GLOBAL_STATUS', '1', 'Noms et valeurs des options fonctionnalits Globales d''ajout, copie et suppression - Etat<br />0= Cacher les fonctionnalits<br />1= Afficher les fonctionnalits<br />2= Rfrences produits', 19, 110, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (438, 'Onglet catgories Menu ON/OFF', 'CATEGORIES_TABS_STATUS', '1', 'Onglet catgories<br />Cela active l''affichage des catgories de votre boutique comme menu dans votre en-tte de page. Il y a beaucoup d''utilisation possible avec cela.<br />0= Cacher l''onglet catgorie<br />1= Afficher l''onglet catgories', 19, 112, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (439, 'Plan du site - inclure les liens Mon Compte?', 'SHOW_ACCOUNT_LINKS_ON_SITE_MAP', 'No', 'Est-ce que les liens vers Mon Compte doivent s''afficher dans le plan du site?<br />Note: Les robots essaieront d''indexer cette page, et ne doivent pas tre envoys sur les pages scurises, puisqu''il n''y a aucun intrt  indexer une page d''identification.<br /><br />Par dfaut: false', 19, 115, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''Yes'', ''No''), ');
INSERT INTO configuration VALUES (440, 'Saute les catgories 1-produit', 'SKIP_SINGLE_PRODUCT_CATEGORIES', 'True', 'Saute les catgories avec un seul produit<br />Si cette option est sur True, alors si le client clique sur le lien d''une catgorie contenant un seul produit, la boutique l''enverra directement sur la page de ce produit, au lieu d''avoir  cliquer sur le produit contenu dans la catgorie.<br />Par dfaut: True', 19, 120, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (441, 'Utiliser la page split-login', 'USE_SPLIT_LOGIN_MODE', 'False', 'La page d''identification peut tre affiche dans deux modes: Coupe (Split) ou Verticale.<br />Dans le mode coup, les options de cration de compte sont accessibles en cliquant sur un bouton pour avoir la page crer un compte. Dans le mode vertical, les champs de cration de compte sont affichs sur la mme page, sous les champs de login, pour viter un clic pour la cration d''un compte.<br />Default: False', 19, 121, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''True'', ''False''), ');
INSERT INTO configuration VALUES (442, 'Boutons CSS', 'IMAGE_USE_CSS_BUTTONS', 'No', 'Boutons CSS<br />Utiliser les boutons CSS au lieu des images (GIF/JPG)?<br />Les styles des boutons doivent tre configurs dans la feuille de style si vous activez cette option.', 19, 147, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''No'', ''Yes''), ');
INSERT INTO configuration VALUES (443, '<strong>Ferm temporairement pour maintenance: ON/OFF</strong>', 'DOWN_FOR_MAINTENANCE', 'false', 'Ferm pour maintenance <br />(true=ferm false=ouvert)', 20, 1, '2008-02-28 14:11:22', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (444, 'ferm pour Maintenance: nom du fichier', 'DOWN_FOR_MAINTENANCE_FILENAME', 'down_for_maintenance', 'fichier du ferm pour maintenance<br />Note: n''incluez pas l''extension<br />Par dfaut=down_for_maintenance', 20, 2, NULL, '2007-11-04 19:39:59', NULL, '');
INSERT INTO configuration VALUES (445, 'Ferm pour Maintenance: cacher l''en-tte', 'DOWN_FOR_MAINTENANCE_HEADER_OFF', 'false', 'Ferm pour Maintenance: cacher l''en-tte <br />(true=cacher false=afficher)', 20, 3, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (446, 'Ferm pour Maintenance: Cacher la colonne Gauche', 'DOWN_FOR_MAINTENANCE_COLUMN_LEFT_OFF', 'false', 'Ferm pour Maintenance: Cacher la colonne Gauche <br />(true=cacher false=afficher)', 20, 4, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (447, 'Ferm pour Maintenance: Cacher la colonne Droite', 'DOWN_FOR_MAINTENANCE_COLUMN_RIGHT_OFF', 'false', 'Ferm pour Maintenance: Cacher la colonne Droite <br />(true=cacher false=afficher)', 20, 5, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (448, 'Ferm pour Maintenance: Cacher le pied de page', 'DOWN_FOR_MAINTENANCE_FOOTER_OFF', 'false', 'Ferm pour Maintenance: Cacher le pied de page <br />(true=cacher false=afficher)', 20, 6, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (449, 'Ferm pour Maintenance: cacher les prix', 'DOWN_FOR_MAINTENANCE_PRICES_OFF', 'false', 'Ferm pour Maintenance: cacher les prix <br />(true=cacher false=afficher)', 20, 7, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (450, 'Ferm pour Maintenance (exclure cette Adresse IP)', 'EXCLUDE_ADMIN_IP_FOR_MAINTENANCE', 'votre IP (ADMIN)', 'Cette adresse IP est autorise  accder  la boutique quand elle est ferme pour maintenance (webmaster)<br />Pour entrer plusieurs adresses IP, sparez les avec une virgule. Si vous ne savez pas votre adresse IP, regardez dans le pied de page de la boutique.', 20, 8, '2003-03-21 13:43:22', '2003-03-21 21:20:07', NULL, NULL);
INSERT INTO configuration VALUES (451, 'AVERTISSEMENT PUBLIC avant d''tre ferm pour maintenance: ON/OFF', 'WARN_BEFORE_DOWN_FOR_MAINTENANCE', 'false', 'mettre un AVERTISSEMENT quelques temps avant d''tre ferm pour maintenance<br />(true=on false=off)<br />Si vous mettez l''option ''Ferm pour Maintenance: ON/OFF'' sur true, cette option se mettra obligatoirement sur false', 20, 9, '2003-03-21 13:08:25', '2003-03-21 11:42:47', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (452, 'Date et heure de l''avertissement avant la maintenance', 'PERIOD_BEFORE_DOWN_FOR_MAINTENANCE', '15/05/2003  2-3 PM', 'Date et heure de l''avertissement avant la maintenance, entrez le date et de la maintenance du site', 20, 10, '2003-03-21 13:08:25', '2003-03-21 11:42:47', NULL, NULL);
INSERT INTO configuration VALUES (453, 'Afficher quand le webmaster active la maintenance', 'DISPLAY_MAINTENANCE_TIME', 'true', 'Afficher quand le webmaster active la maintenance <br />(true=on false=off)<br />', 20, 11, '2008-02-28 14:10:06', '2003-03-21 11:42:47', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (454, 'Afficher la priode de maintenance', 'DISPLAY_MAINTENANCE_PERIOD', 'true', 'Afficher la priode de maintenance <br />(true=on false=off)<br />', 20, 12, '2008-02-28 14:10:10', '2003-03-21 11:42:47', NULL, 'zen_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (455, 'Temps de maintenance du site', 'TEXT_MAINTENANCE_PERIOD_TIME', '2h00', 'Entrez le temps de maintenance du site (hh:mm)', 20, 13, '2003-03-21 13:08:25', '2003-03-21 11:42:47', NULL, NULL);
INSERT INTO configuration VALUES (456, 'Confirmer les Conditions de vente pendant la commande', 'DISPLAY_CONDITIONS_ON_CHECKOUT', 'false', 'Afficher les Conditions de vente pendant la procdure de commande, avec lesquelles le client doit tre en accord.', 11, 1, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (457, 'Confirmer la notice de confidentialit pendant la cration d''un compte', 'DISPLAY_PRIVACY_CONDITIONS', 'false', 'Afficher la notice de confidentialit pendant la cration d''un compte, pour laquelle le client doit tre en accord.', 11, 2, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''true'', ''false''), ');
INSERT INTO configuration VALUES (458, 'Affichage Image produit', 'PRODUCT_NEW_LIST_IMAGE', '1102', 'Voulez-vous afficher l''Image produit?<br /><br />0= off<br />Premier chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre de breaks after<br />', 21, 1, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (459, 'Affichage Quantit produit', 'PRODUCT_NEW_LIST_QUANTITY', '1202', 'Voulez-vous afficher la quantit de produit?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 21, 2, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (460, 'Affichage du bouton Acheter maintenant', 'PRODUCT_NEW_BUY_NOW', '1300', 'Voulez-vous afficher le bouton acheter maintenant<br /><br />0= off<br />1er chiffre : Gauche ou Droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs digit<br />', 21, 3, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (461, 'Affichage Nom du produit', 'PRODUCT_NEW_LIST_NAME', '2101', 'Voulez-vous afficher les noms de produit?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffres : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 21, 4, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (462, 'Affichage rfrence Produit', 'PRODUCT_NEW_LIST_MODEL', '2201', 'Voulez-vous afficher la rfrence du produit?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 21, 5, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (463, 'Affichage du fabricant produit', 'PRODUCT_NEW_LIST_MANUFACTURER', '2302', 'Voulez-vous afficher le fabricant du produit?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 21, 6, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (464, 'Affichage du prix des produits', 'PRODUCT_NEW_LIST_PRICE', '2402', 'Voulez-vous afficher le prix des produits?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de saut aprs<br />', 21, 7, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (465, 'Affichage du poids du produit', 'PRODUCT_NEW_LIST_WEIGHT', '2502', 'Voulez-vous afficher le poids des produits?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 21, 8, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (466, 'Affichage de la date d''ajout du produit', 'PRODUCT_NEW_LIST_DATE_ADDED', '2601', 'Voulez-vous afficher la date d''ajout du produit?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 21, 9, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (467, 'Affichage de la description produit', 'PRODUCT_NEW_LIST_DESCRIPTION', '150', 'How many characters do you want to display of the Product Description?<br /><br />0= OFF<br />150= Suggested Length, or enter the maximum number of characters to display', 21, 10, NULL, '2007-11-04 19:39:59', NULL, '');
INSERT INTO configuration VALUES (468, 'Affichage des nouveaux produits - Ordre d''affichage par dfaut', 'PRODUCT_NEW_LIST_SORT_DEFAULT', '6', 'Quel ordre d''affichage par dfaut doit tre utilis pour l''affichage des nouveaux produits?<br />Par Dfaut= 6 pour la date de Nouveau  Ancien<br /><br />1= Nom des produits<br />2= Noms produits dcroissants<br />3= Prix bas  lev, Noms produits<br />4= Prix lev  bas, Nom des produits<br />5= Rfrence<br />6= Date d''ajout dcroissante<br />7= Date d''ajout<br />8= ordre d''affichage produits', 21, 11, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''1'', ''2'', ''3'', ''4'', ''5'', ''6'', ''7'', ''8''), ');
INSERT INTO configuration VALUES (469, 'Group ID par dfaut des nouveaux produits', 'PRODUCT_NEW_LIST_GROUP_ID', '21', 'Attention: Ne changez cela que si le group ID a chang par rapport  celui par dfaut : 21<br />Quel est le configuration_group_id pour le listing des nouveaux produits?', 21, 12, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (470, 'Afficher la liste de Qt pour les produits multiples et l''emplacement du bouton', 'PRODUCT_NEW_LISTING_MULTIPLE_ADD_TO_CART', '3', 'Voulez-vous afficher la liste de Qt pour l''ajout de multiples produits et le bouton pour configurer l''emplacement?<br />0= off<br />1= Haut<br />2= Bas<br />3= Les deux', 21, 25, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''), ');
INSERT INTO configuration VALUES (471, 'Masquer les produits  venir de l''inclusion avec les Nouveaux Produits', 'SHOW_NEW_PRODUCTS_UPCOMING_MASKED', '0', 'Voulez-vous masquer les produits  venir de la liste des Nouveaux Produits, boites latrales et au centre?<br />0= off<br />1= on', 21, 30, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (472, 'Affichage Image produit', 'PRODUCT_FEATURED_LIST_IMAGE', '1102', 'Voulez-vous afficher l''image du produit?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 22, 1, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (473, 'Affichage de la quantit produits', 'PRODUCT_FEATURED_LIST_QUANTITY', '1202', 'Voulez-vous afficher la quantit de produits?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffres : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 22, 2, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (474, 'Affichage du bouton Acheter maintenant', 'PRODUCT_FEATURED_BUY_NOW', '1300', 'Voulez-vous afficher le bouton acheter maintenant<br /><br />0= off<br />1er chiffre : Gauche ou Droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs digit<br />', 22, 3, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (475, 'Affichage Nom du produit', 'PRODUCT_FEATURED_LIST_NAME', '2101', 'Voulez-vous afficher les noms de produit?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffres : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 22, 4, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (476, 'Affichage rfrence Produit', 'PRODUCT_FEATURED_LIST_MODEL', '2201', 'Voulez-vous afficher la rfrence du produit?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 22, 5, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (477, 'Affichage du fabricant produit', 'PRODUCT_FEATURED_LIST_MANUFACTURER', '2302', 'Voulez-vous afficher le fabricant du produit?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 22, 6, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (478, 'Affichage du prix des produits', 'PRODUCT_FEATURED_LIST_PRICE', '2402', 'Voulez-vous afficher le prix des produits?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de saut aprs<br />', 22, 7, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (479, 'Affichage du poids du produit', 'PRODUCT_FEATURED_LIST_WEIGHT', '2502', 'Voulez-vous afficher le poids des produits?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 22, 8, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (480, 'Affichage de la date d''ajout du produit', 'PRODUCT_FEATURED_LIST_DATE_ADDED', '2601', 'Voulez-vous afficher la date d''ajout du produit?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 22, 9, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (481, 'Affichage de la Description du produit', 'PRODUCT_FEATURED_LIST_DESCRIPTION', '150', 'How many characters do you want to display of the Product Description?<br /><br />0= OFF<br />150= Suggested Length, or enter the maximum number of characters to display', 22, 10, NULL, '2007-11-04 19:39:59', NULL, '');
INSERT INTO configuration VALUES (482, 'Affichage des produits - Ordre d''affichage par dfaut', 'PRODUCT_FEATURED_LIST_SORT_DEFAULT', '1', 'Quel ordre d''affichage par dfaut doit tre utilis pour les produits  la une?<br />par Dfaut= 1 pour les noms produits<br /><br />1= Nom des produits<br />2= Nom des produits Dcroissants<br />3= Prix du plus bas au plus lev, Nom produits<br />4= Prix du plus lev au plus bas, Noms produits<br />5= Rfrences<br />6= Dates d''ajout dcroissantes<br />7= Dates d''ajout<br />8= Ordre d''affichage des produits', 22, 11, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''1'', ''2'', ''3'', ''4'', ''5'', ''6'', ''7'', ''8''), ');
INSERT INTO configuration VALUES (483, 'ID groupe par dfaut Produits  la une', 'PRODUCT_FEATURED_LIST_GROUP_ID', '22', 'Attention: Ne changez cette valeur que si l''ID groupe des produits  la une  changer par rapport  la config par dfaut<br />Quel est le  configuration_group_id des produits  la une?', 22, 12, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (484, 'Afficher la liste de Qt pour les produits multiples et l''emplacement du bouton', 'PRODUCT_FEATURED_LISTING_MULTIPLE_ADD_TO_CART', '3', 'Voulez-vous afficher la liste de Qt pour l''ajout de multiples produits et le bouton pour configurer l''emplacement?<br />0= off<br />1= Haut<br />2= Bas<br />3= Les deux', 22, 25, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''), ');
INSERT INTO configuration VALUES (485, 'Affichage Image produit', 'PRODUCT_ALL_LIST_IMAGE', '1102', 'Voulez-vous afficher l''image du produit?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 23, 1, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (486, 'Affichage de la quantit produits', 'PRODUCT_ALL_LIST_QUANTITY', '1202', 'Voulez-vous afficher la quantit de produits?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffres : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 23, 2, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (487, 'Affichage du bouton Acheter maintenant', 'PRODUCT_ALL_BUY_NOW', '1300', 'Voulez-vous afficher le bouton acheter maintenant<br /><br />0= off<br />1er chiffre : Gauche ou Droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs digit<br />', 23, 3, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (488, 'Affichage Nom du produit', 'PRODUCT_ALL_LIST_NAME', '2101', 'Voulez-vous afficher les noms de produit?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffres : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 23, 4, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (489, 'Affichage rfrence Produit', 'PRODUCT_ALL_LIST_MODEL', '2201', 'Voulez-vous afficher la rfrence du produit?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 23, 5, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (490, 'Affichage du fabricant produit', 'PRODUCT_ALL_LIST_MANUFACTURER', '2302', 'Voulez-vous afficher le fabricant du produit?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 23, 6, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (491, 'Affichage du prix des produits', 'PRODUCT_ALL_LIST_PRICE', '2402', 'Voulez-vous afficher le prix des produits?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de saut aprs<br />', 23, 7, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (492, 'Affichage du poids du produit', 'PRODUCT_ALL_LIST_WEIGHT', '2502', 'Voulez-vous afficher le poids des produits?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 23, 8, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (493, 'Affichage de la date d''ajout du produit', 'PRODUCT_ALL_LIST_DATE_ADDED', '2601', 'Voulez-vous afficher la date d''ajout du produit?<br /><br />0= off<br />1er chiffre : gauche ou droite<br />2me et 3me chiffre : ordre d''affichage<br />4me chiffre : nombre de sauts aprs<br />', 23, 9, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (494, 'Affichage de la Description du produit', 'PRODUCT_ALL_LIST_DESCRIPTION', '150', 'How many characters do you want to display of the Product Description?<br /><br />0= OFF<br />150= Suggested Length, or enter the maximum number of characters to display', 23, 10, NULL, '2007-11-04 19:39:59', NULL, '');
INSERT INTO configuration VALUES (495, 'Affichage des produits - Ordre d''affichage par dfaut', 'PRODUCT_ALL_LIST_SORT_DEFAULT', '1', 'Quel ordre d''affichage par dfaut doit tre utilis pour les produits  la une?<br />par Dfaut= 1 pour les noms produits<br /><br />1= Nom des produits<br />2= Nom des produits Dcroissants<br />3= Prix du plus bas au plus lev, Nom produits<br />4= Prix du plus lev au plus bas, Noms produits<br />5= Rfrences<br />6= Dates d''ajout dcroissantes<br />7= Dates d''ajout<br />8= Ordre d''affichage des produits', 23, 11, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''1'', ''2'', ''3'', ''4'', ''5'', ''6'', ''7'', ''8''), ');
INSERT INTO configuration VALUES (496, 'ID groupe par dfaut de Tous les produits', 'PRODUCT_ALL_LIST_GROUP_ID', '23', 'Attention: Ne changez cette valeur que si l''ID groupe des produits  la une  changer par rapport  la config par dfaut de 23<br />Quel est le  configuration_group_id de "Tous les produits"?', 23, 12, NULL, '2007-11-04 19:39:59', NULL, NULL);
INSERT INTO configuration VALUES (497, 'Afficher la liste de Qt pour les produits multiples et l''emplacement du bouton', 'PRODUCT_ALL_LISTING_MULTIPLE_ADD_TO_CART', '3', 'Voulez-vous afficher la liste de Qt pour l''ajout de multiples produits et le bouton pour configurer l''emplacement?<br />0= off<br />1= Haut<br />2= Bas<br />3= Les deux', 23, 25, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''), ');
INSERT INTO configuration VALUES (498, 'Affiche les Nouveaux Produits sur la page principale', 'SHOW_PRODUCT_INFO_MAIN_NEW_PRODUCTS', '1', 'Affiche les Nouveaux Produits sur la page principale<br />0= off ou configurez un ordre d''affichage', 24, 65, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (499, 'Affiche les Produits  la une sur la page principale', 'SHOW_PRODUCT_INFO_MAIN_FEATURED_PRODUCTS', '2', 'Affiche les Produits  la une sur la page principale<br />0= off ou configurez un ordre d''affichage', 24, 66, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (500, 'Affiche les Produits en promotion sur la page principale', 'SHOW_PRODUCT_INFO_MAIN_SPECIALS_PRODUCTS', '3', 'Affiche les Produits en promotion sur la page principale<br />0= off ou configurez un ordre d''affichage', 24, 67, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (501, 'Affiche les Produits  venir sur la page principale', 'SHOW_PRODUCT_INFO_MAIN_UPCOMING', '4', 'Affiche les Produits  venir sur la page principale<br />0= off ou configurez un ordre d''affichage', 24, 68, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (502, 'Affiche les Nouveaux Produits sur la page principale - Catgorie avec sous-catgories', 'SHOW_PRODUCT_INFO_CATEGORY_NEW_PRODUCTS', '1', 'Affiche les Nouveaux Produits sur la page principale - Catgorie avec sous-catgories<br />0= off ou configurez un ordre d''affichage', 24, 70, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (503, 'Affiche les Produits  la une sur la page principale - Catgorie avec sous-catgories', 'SHOW_PRODUCT_INFO_CATEGORY_FEATURED_PRODUCTS', '2', 'Affiche les Produits  la une sur la page principale - Catgorie avec sous-catgories<br />0= off ou configurez un ordre d''affichage', 24, 71, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (504, 'Affiche les Produits en promotion sur la page principale - Catgorie avec sous-catgories', 'SHOW_PRODUCT_INFO_CATEGORY_SPECIALS_PRODUCTS', '3', 'Affiche les Produits en promotion sur la page principale - Catgorie avec sous-catgories<br />0= off ou configurez un ordre d''affichage', 24, 72, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (505, 'Affiche les Produits  venir sur la page principale - Catgorie avec sous-catgories', 'SHOW_PRODUCT_INFO_CATEGORY_UPCOMING', '4', 'Affiche les Produits  venir sur la page principale - Catgorie avec sous-catgories<br />0= off ou configurez un ordre d''affichage', 24, 73, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (506, 'Affiche les Nouveaux Produits sur la page principale - pages d''Erreurs et produits manquants', 'SHOW_PRODUCT_INFO_MISSING_NEW_PRODUCTS', '1', 'Affiche les Nouveaux Produits sur la page principale - pages d''Erreurs et produits manquants<br />0= off ou configurez un ordre d''affichage', 24, 75, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (507, 'Affiche les Produits  la une sur la page principale - pages d''Erreurs et produits manquants', 'SHOW_PRODUCT_INFO_MISSING_FEATURED_PRODUCTS', '2', 'Affiche les Produits  la une sur la page principale - pages d''Erreurs et produits manquants<br />0= off ou configurez un ordre d''affichage', 24, 76, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (508, 'Affiche les Produits en promotion sur la page principale - pages d''Erreurs et produits manquants', 'SHOW_PRODUCT_INFO_MISSING_SPECIALS_PRODUCTS', '3', 'Affiche les Produits en promotion sur la page principale - pages d''Erreurs et produits manquants<br />0= off ou configurez un ordre d''affichage', 24, 77, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (509, 'Affiche les Produits  venir sur la page principale - pages d''Erreurs et produits manquants', 'SHOW_PRODUCT_INFO_MISSING_UPCOMING', '4', 'Affiche les Produits  venir sur la page principale - pages d''Erreurs et produits manquants<br />0= off ou configurez un ordre d''affichage', 24, 78, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (510, 'Affichage nouveaux produits - Sous le listing des produits', 'SHOW_PRODUCT_INFO_LISTING_BELOW_NEW_PRODUCTS', '1', 'Affichage nouveaux produits sous le listing des produits<br />0= off ou configurez un ordre d''affichage', 24, 85, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (511, 'Afficher les produits  la une - sous le listing produits', 'SHOW_PRODUCT_INFO_LISTING_BELOW_FEATURED_PRODUCTS', '2', 'Afficher les produits  la une sous le listing produits<br />0= off ou configurez l''ordre d''affichage', 24, 86, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (512, 'Afficher les produits en promotion - sous le listing produits', 'SHOW_PRODUCT_INFO_LISTING_BELOW_SPECIALS_PRODUCTS', '3', 'Afficher les produits en promotion sous le listing produits<br />0= off ou configurez l''ordre d''affichage', 24, 87, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (513, 'Afficher les produits  venir - sous le listing produits', 'SHOW_PRODUCT_INFO_LISTING_BELOW_UPCOMING', '4', 'Afficher les produits  venir sous le listing produits<br />0= off ou configurez l''ordre d''affichage', 24, 88, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3'', ''4''), ');
INSERT INTO configuration VALUES (514, 'Nouveaux produits, colonnes par ligne', 'SHOW_PRODUCT_INFO_COLUMNS_NEW_PRODUCTS', '3', 'Nouveaux produits, nombre de colonnes par ligne', 24, 95, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''1'', ''2'', ''3'', ''4'', ''5'', ''6'', ''7'', ''8'', ''9'', ''10'', ''11'', ''12''), ');
INSERT INTO configuration VALUES (515, 'Produits  la une, colonnes par ligne', 'SHOW_PRODUCT_INFO_COLUMNS_FEATURED_PRODUCTS', '3', 'Produits  la une, nb de colonnes par ligne', 24, 96, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''1'', ''2'', ''3'', ''4'', ''5'', ''6'', ''7'', ''8'', ''9'', ''10'', ''11'', ''12''), ');
INSERT INTO configuration VALUES (516, 'Produits en promotion, colonnes par ligne', 'SHOW_PRODUCT_INFO_COLUMNS_SPECIALS_PRODUCTS', '3', 'Produits en promotion, nb de colonnes par ligne', 24, 97, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''1'', ''2'', ''3'', ''4'', ''5'', ''6'', ''7'', ''8'', ''9'', ''10'', ''11'', ''12''), ');
INSERT INTO configuration VALUES (517, 'Filtrer le Listing Produits pour la catgorie principale courant quand c''est activ', 'SHOW_PRODUCT_INFO_ALL_PRODUCTS', '1', 'Filtrer les produits quand le Listing produits est activ pour la catgorie courante, ou afficher les produits de toutes les catgories?<br />0= Filtre Off 1=Filtre On ', 24, 100, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''), ');
INSERT INTO configuration VALUES (518, 'Configurer l''Etat de la page principale', 'DEFINE_MAIN_PAGE_STATUS', '1', 'Activer le lien/texte de la page principale dfinie?<br />0= Lien ON, Texte dfini OFF<br />1= ien ON, Texte dfini ON<br />2= Lien OFF, Texte dfini ON<br />3= Lien OFF, Texte dfini OFF', 25, 60, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''),');
INSERT INTO configuration VALUES (519, 'Configurer l''Etat de Nous contacter', 'DEFINE_CONTACT_US_STATUS', '1', 'Activer le lien/texte de la page Nous contacter?<br />0= Lien ON, Texte dfini OFF<br />1= Lien ON, Texte dfini ON<br />2= Lien OFF, Texte dfini ON<br />3= Lien OFF, Texte dfini OFF', 25, 61, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''),');
INSERT INTO configuration VALUES (520, 'Configurer la page Confidentialit', 'DEFINE_PRIVACY_STATUS', '1', 'Activer le Lien/Texte de la page confidentialit?<br />0= Lien ON, Texte dfini OFF<br />1= Lien ON, Texte dfini ON<br />2= Lien OFF, Texte dfini ON<br />3= Lien OFF, Texte dfini OFF', 25, 62, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''),');
INSERT INTO configuration VALUES (521, 'Configurer Livraison & retours', 'DEFINE_SHIPPINGINFO_STATUS', '1', 'Activer le lien/texte Livraisons & retours?<br />0= Lien ON, Texte dfini OFF<br />1= Lien ON, Texte dfini ON<br />2= Lien OFF, Texte dfini ON<br />3= Lien OFF, Texte dfini OFF', 25, 63, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''),');
INSERT INTO configuration VALUES (522, 'Configurer les conditions d''utilisation', 'DEFINE_CONDITIONS_STATUS', '1', 'Activer le Lien/Texte des conditions d''utilisation dfinies?<br />0= Lien ON, Texte dfini OFF<br />1= Lien ON, Texte dfini ON<br />2= Lien OFF, Texte dfini ON<br />3= Lien OFF, Texte dfini OFF', 25, 64, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''),');
INSERT INTO configuration VALUES (523, 'Configurer Commande russie', 'DEFINE_CHECKOUT_SUCCESS_STATUS', '1', 'Activer le lien/texte de la page Commande russie dfinie?<br />0= Lien ON, Texte dfini OFF<br />1= Lien ON, Texte dfini ON<br />2= Lien OFF, Texte dfini ON<br />3= Lien OFF, Texte dfini OFF', 25, 65, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''),');
INSERT INTO configuration VALUES (524, 'Configurer Coupon de rduction', 'DEFINE_DISCOUNT_COUPON_STATUS', '1', 'Activer le lien/texte de la page Coupon de rduction dfinie?<br />0= Lien ON, Texte dfini OFF<br />1= Lien ON, Texte dfini ON<br />2= Lien OFF, Texte dfini ON<br />3= Lien OFF, Texte dfini OFF', 25, 66, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''),');
INSERT INTO configuration VALUES (525, 'Configurer l''tat du Plan du site', 'DEFINE_SITE_MAP_STATUS', '1', 'Activer le lien/texte de la page Plan du site dfinie?<br />0= Lien ON, Texte dfinie OFF<br />1= Lien ON, Texte dfinie ON<br />2= Lien OFF, Texte dfinie ON<br />3= Lien OFF, Texte dfinie OFF', 25, 67, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''),');
INSERT INTO configuration VALUES (526, 'Configurer l''tat de Page-Non-Trouve', 'DEFINE_PAGE_NOT_FOUND_STATUS', '1', 'Activer le Texte de la Page-Non-Trouve dfinie?<br />0= Texte dfini OFF<br />1= Texte dfini ON', 25, 67, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''),');
INSERT INTO configuration VALUES (527, 'Configurer Page 2', 'DEFINE_PAGE_2_STATUS', '1', 'Activer le Lien/Texte de la Page 2 dfinie?<br />0= Lien ON, Texte dfini OFF<br />1= Lien ON, Texte dfinie ON<br />2= Lien OFF, Texte dfini ON<br />3= Lien OFF, Texte dfini OFF', 25, 82, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''),');
INSERT INTO configuration VALUES (528, 'Configurer Page 3', 'DEFINE_PAGE_3_STATUS', '1', 'Activer le Lien/texte de la Page 3 dfinie?<br />0= Lien ON, Texte dfini OFF<br />1= Lien ON, Texte dfini ON<br />2= Lien OFF, Texte dfini ON<br />3= Lien OFF, Texte dfini OFF', 25, 83, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''),');
INSERT INTO configuration VALUES (529, 'Define Page 4', 'DEFINE_PAGE_4_STATUS', '1', 'Enable the Defined Page 4 Link/Text?<br />0= Link ON, Define Text OFF<br />1= Link ON, Define Text ON<br />2= Link OFF, Define Text ON<br />3= Link OFF, Define Text OFF', 25, 84, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2'', ''3''),');
INSERT INTO configuration VALUES (530, 'Etat de l''affichage EZ-Pages - HeaderBar', 'EZPAGES_STATUS_HEADER', '1', 'L''Affichage du contenu EZ-Pages peut tre globalement activ/dsactiv  partir de la barre d''en-tte<br />0 = Off<br />1 = On<br />2= Seulement pour l''IP ADMIN configure dans l''option "ferm pour Maintenance"<br />NOTE: ne s''affichera que pour l''admin et non pour le public', 30, 10, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2''), ');
INSERT INTO configuration VALUES (531, 'Etat d''affichage EZ-Pages - FooterBar', 'EZPAGES_STATUS_FOOTER', '1', 'L''affichage du contenu EZ-Pages peut tre globalement activ/dsactiv  partir de la barre de Footer<br />0 = Off<br />1 = On<br />2= Sur l''adresse IP ADMIN seulement, situ dans les options de maintenance<br />NOTE: ne s''affichera que pour l''admin et non pour le public', 30, 11, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2''), ');
INSERT INTO configuration VALUES (532, 'Etat d''affichage EZ-Pages - Sidebox', 'EZPAGES_STATUS_SIDEBOX', '1', 'l''affichage du contenu EZ-Pages peut tre globalement activ/dsactiv enabled/disabled pour la boite latrale<br />0 = Off<br />1 = On<br />2= Sur l''adresse IP ADMIN seulement situ dans les options de Maintenance<br />NOTE: ne s''affichera que pour l''admin et non pour le public', 30, 12, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2''), ');
INSERT INTO configuration VALUES (533, 'EZ-Pages sparateur de lien d''en-tte', 'EZPAGES_SEPARATOR_HEADER', '&nbsp;::&nbsp;', 'EZ-Pages sparateur de lien d''en-tte<br />Par Dfaut = &amp;nbsp;::&amp;nbsp;', 30, 20, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_textarea_small(');
INSERT INTO configuration VALUES (534, 'EZ-Pages sparateur de lien de pied de page', 'EZPAGES_SEPARATOR_FOOTER', '&nbsp;::&nbsp;', 'EZ-Pages sparateur de lien de pied de page<br />Par Dfaut = &amp;nbsp;::&amp;nbsp;', 30, 21, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_textarea_small(');
INSERT INTO configuration VALUES (535, 'Boutons Prc/Suiv EZ-Pages', 'EZPAGES_SHOW_PREV_NEXT_BUTTONS', '2', 'Affiche les boutons Prc/Continuer/Suiv sur les pages EZ-Pages?<br />0=OFF (pas de boutons)<br />1="Continuer"<br />2="Prc/Continuer/Suiv"<br /><br />Paramtre par dfaut: 2.', 30, 30, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1'', ''2''), ');
INSERT INTO configuration VALUES (536, 'Sommaire des chapitres EZ-Pages - Etat', 'EZPAGES_SHOW_TABLE_CONTENTS', '1', 'Activer le sommaire des chapitres des EZ-Pages?<br />0= OFF<br />1= ON', 30, 35, '2007-11-04 19:39:59', '2007-11-04 19:39:59', NULL, 'zen_cfg_select_option(array(''0'', ''1''),');
INSERT INTO configuration VALUES (537, 'EZ-Pages Pages to disable headers', 'EZPAGES_DISABLE_HEADER_DISPLAY_LIST', '', '"pages" EZ-Pages sur lesquelles il ne faut PAS afficher l''en-tte normale de votre site.<br />Listez simplement les nombres ID des pages spares par une virgule sans espaces.<br />Le numro ID des pages peuvent tre rcuprs sur crans EZ-Pages de Admin->Outils.<br />ie: 1,5,2<br />ou laissez vide.', 30, 40, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_textarea_small(');
INSERT INTO configuration VALUES (538, 'Pages EZ-Pages sans pieds de page', 'EZPAGES_DISABLE_FOOTER_DISPLAY_LIST', '', '"pages" EZ-Pages sur lesquelles il ne faut PAS afficher le "footer" normale de votre site.<br />Listez simplement les numros ID spars par une virgule sans espaces.<br />Les numros ID des pages peuvent tre rcuprs sur les crans EZ-Pages de Admin->Outils.<br />ie: 3,7<br />ou laissez vide.', 30, 41, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_textarea_small(');
INSERT INTO configuration VALUES (539, 'Pages EZ-Pages sans colonne Gauche', 'EZPAGES_DISABLE_LEFTCOLUMN_DISPLAY_LIST', '', '"pages" EZ-Pages sur lesquelles il ne faut PAS afficher la colonne de gauche (boites latrales) normale de votre site.<br />Listez simplement les numros ID spars par une virgule sans espaces.<br />Les numros ID des pages peuvent tre rcuprs sur les crans EZ-Pages de Admin->Outils.<br />ie: 21<br />or leave blank.', 30, 42, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_textarea_small(');
INSERT INTO configuration VALUES (540, 'Pages EZ-Pages sans colonne Droite', 'EZPAGES_DISABLE_RIGHTCOLUMN_DISPLAY_LIST', '', '"pages" EZ-Pages sur lesquelles il ne faut PAS afficher la colonne de droite (boites latrales) normale de votre site.<br />Listez simplement les numros ID spars par une virgule sans espaces.<br />Les numros ID des pages peuvent tre rcuprs sur les crans EZ-Pages de Admin->Outils.<br />ie: 3,82,13<br />or leave blank.', 30, 43, NULL, '2007-11-04 19:39:59', NULL, 'zen_cfg_textarea_small(');





INSERT INTO configuration_group VALUES (1, 'Ma Boutique', 'Informations g&eacute;n&eacute;rales sur ma boutique', 1, 1);
INSERT INTO configuration_group VALUES (2, 'Valeurs Minimum', 'Les valeurs minimum pour les fonctions / donn&eacute;es', 2, 1);
INSERT INTO configuration_group VALUES (3, 'Valeurs Maximum', 'Les valeurs maximum pour les fonctions / donn&eacute;es', 3, 1);
INSERT INTO configuration_group VALUES (4, 'Images', 'Parametres des images', 4, 1);
INSERT INTO configuration_group VALUES (5, 'D&eacute;tails clients', 'Configuration des comptes clients', 5, 1);
INSERT INTO configuration_group VALUES (6, 'Options des modules', 'Cach&eacute; de la configuration', 6, 0);
INSERT INTO configuration_group VALUES (7, 'Livraison/Emballage', 'Les options de livraison disponibles sur ma boutique', 7, 1);
INSERT INTO configuration_group VALUES (8, 'Listing des produits', 'Configuration des options de listing des produits', 8, 1);
INSERT INTO configuration_group VALUES (9, 'Stock', 'Options de configuration du stock', 9, 1);
INSERT INTO configuration_group VALUES (10, 'Historique / Logs', 'Options de configuration des journaux de connexion', 10, 1);
INSERT INTO configuration_group VALUES (11, 'R&egrave;glement / juridique', 'Options de r&egrave;glement', 16, 1);
INSERT INTO configuration_group VALUES (12, 'Options E-mail', 'Configuration g&eacute;nrale sur l''envoi des E-mail et le format HTML', 12, 1);
INSERT INTO configuration_group VALUES (13, 'Param&egrave;tres des attributs', 'Configure les param&egrave;tres des attributs de produits', 13, 1);
INSERT INTO configuration_group VALUES (14, 'Compression GZip ', 'Options de compressions Gzip', 14, 1);
INSERT INTO configuration_group VALUES (15, 'Sessions', 'Options de sessions', 15, 1);
INSERT INTO configuration_group VALUES (16, 'Coupons / Ch&egrave;ques cadeaux', 'Coupons de reduction et ch&egrave;ques cadeaux', 16, 1);
INSERT INTO configuration_group VALUES (17, 'Cartes de cr&eacute;dit', 'Acceptation des cartes de cr&eacute;dit', 17, 1);
INSERT INTO configuration_group VALUES (18, 'Infos produit', 'Options d''affichage des informations d&eacute;taill&eacute;es des produits', 18, 1);
INSERT INTO configuration_group VALUES (19, 'Configuration du th&egrave;me', 'Options du th&egrave;me et mise en page', 19, 1);
INSERT INTO configuration_group VALUES (20, 'Maintenance du site', 'Options de maintenance du site', 20, 1);
INSERT INTO configuration_group VALUES (21, 'listing nouveaux produits', 'Listing des nouveaux produits', 21, 1);
INSERT INTO configuration_group VALUES (22, 'Listing produits phares', 'Listing des produits phares', 22, 1);
INSERT INTO configuration_group VALUES (23, 'Listings tous les produits', 'Listings de tous les produits', 23, 1);
INSERT INTO configuration_group VALUES (24, 'Listing Accueil', 'Listing des produits en page d''accueil', 24, 1);
INSERT INTO configuration_group VALUES (25, 'Statut des pages', 'Pour definir les pages principales et les options des &eacute;editeurs HTML', 25, 1);
INSERT INTO configuration_group VALUES (30, 'Param&egrave;tres EZ-Pages', 'Param&egrave;tres EZ-Pages', 30, 1);

INSERT INTO countries VALUES (240,'Aaland Islands','AX','ALA','1');
INSERT INTO countries VALUES (1,'Afghanistan','AF','AFG','1');
INSERT INTO countries VALUES (2,'Albania','AL','ALB','1');
INSERT INTO countries VALUES (3,'Algeria','DZ','DZA','1');
INSERT INTO countries VALUES (4,'American Samoa','AS','ASM','1');
INSERT INTO countries VALUES (5,'Andorra','AD','AND','1');
INSERT INTO countries VALUES (6,'Angola','AO','AGO','1');
INSERT INTO countries VALUES (7,'Anguilla','AI','AIA','1');
INSERT INTO countries VALUES (8,'Antarctica','AQ','ATA','1');
INSERT INTO countries VALUES (9,'Antigua and Barbuda','AG','ATG','1');
INSERT INTO countries VALUES (10,'Argentina','AR','ARG','1');
INSERT INTO countries VALUES (11,'Armenia','AM','ARM','1');
INSERT INTO countries VALUES (12,'Aruba','AW','ABW','1');
INSERT INTO countries VALUES (13,'Australia','AU','AUS','1');
INSERT INTO countries VALUES (14,'Austria','AT','AUT','5');
INSERT INTO countries VALUES (15,'Azerbaijan','AZ','AZE','1');
INSERT INTO countries VALUES (16,'Bahamas','BS','BHS','1');
INSERT INTO countries VALUES (17,'Bahrain','BH','BHR','1');
INSERT INTO countries VALUES (18,'Bangladesh','BD','BGD','1');
INSERT INTO countries VALUES (19,'Barbados','BB','BRB','1');
INSERT INTO countries VALUES (20,'Belarus','BY','BLR','1');
INSERT INTO countries VALUES (21,'Belgium','BE','BEL','1');
INSERT INTO countries VALUES (22,'Belize','BZ','BLZ','1');
INSERT INTO countries VALUES (23,'Benin','BJ','BEN','1');
INSERT INTO countries VALUES (24,'Bermuda','BM','BMU','1');
INSERT INTO countries VALUES (25,'Bhutan','BT','BTN','1');
INSERT INTO countries VALUES (26,'Bolivia','BO','BOL','1');
INSERT INTO countries VALUES (27,'Bosnia and Herzegowina','BA','BIH','1');
INSERT INTO countries VALUES (28,'Botswana','BW','BWA','1');
INSERT INTO countries VALUES (29,'Bouvet Island','BV','BVT','1');
INSERT INTO countries VALUES (30,'Brazil','BR','BRA','1');
INSERT INTO countries VALUES (31,'British Indian Ocean Territory','IO','IOT','1');
INSERT INTO countries VALUES (32,'Brunei Darussalam','BN','BRN','1');
INSERT INTO countries VALUES (33,'Bulgaria','BG','BGR','1');
INSERT INTO countries VALUES (34,'Burkina Faso','BF','BFA','1');
INSERT INTO countries VALUES (35,'Burundi','BI','BDI','1');
INSERT INTO countries VALUES (36,'Cambodia','KH','KHM','1');
INSERT INTO countries VALUES (37,'Cameroon','CM','CMR','1');
INSERT INTO countries VALUES (38,'Canada','CA','CAN','2');
INSERT INTO countries VALUES (39,'Cape Verde','CV','CPV','1');
INSERT INTO countries VALUES (40,'Cayman Islands','KY','CYM','1');
INSERT INTO countries VALUES (41,'Central African Republic','CF','CAF','1');
INSERT INTO countries VALUES (42,'Chad','TD','TCD','1');
INSERT INTO countries VALUES (43,'Chile','CL','CHL','1');
INSERT INTO countries VALUES (44,'China','CN','CHN','1');
INSERT INTO countries VALUES (45,'Christmas Island','CX','CXR','1');
INSERT INTO countries VALUES (46,'Cocos (Keeling) Islands','CC','CCK','1');
INSERT INTO countries VALUES (47,'Colombia','CO','COL','1');
INSERT INTO countries VALUES (48,'Comoros','KM','COM','1');
INSERT INTO countries VALUES (49,'Congo','CG','COG','1');
INSERT INTO countries VALUES (50,'Cook Islands','CK','COK','1');
INSERT INTO countries VALUES (51,'Costa Rica','CR','CRI','1');
INSERT INTO countries VALUES (52,'Cote D\'Ivoire','CI','CIV','1');
INSERT INTO countries VALUES (53,'Croatia','HR','HRV','1');
INSERT INTO countries VALUES (54,'Cuba','CU','CUB','1');
INSERT INTO countries VALUES (55,'Cyprus','CY','CYP','1');
INSERT INTO countries VALUES (56,'Czech Republic','CZ','CZE','1');
INSERT INTO countries VALUES (57,'Denmark','DK','DNK','1');
INSERT INTO countries VALUES (58,'Djibouti','DJ','DJI','1');
INSERT INTO countries VALUES (59,'Dominica','DM','DMA','1');
INSERT INTO countries VALUES (60,'Dominican Republic','DO','DOM','1');
INSERT INTO countries VALUES (61,'East Timor','TP','TMP','1');
INSERT INTO countries VALUES (62,'Ecuador','EC','ECU','1');
INSERT INTO countries VALUES (63,'Egypt','EG','EGY','1');
INSERT INTO countries VALUES (64,'El Salvador','SV','SLV','1');
INSERT INTO countries VALUES (65,'Equatorial Guinea','GQ','GNQ','1');
INSERT INTO countries VALUES (66,'Eritrea','ER','ERI','1');
INSERT INTO countries VALUES (67,'Estonia','EE','EST','1');
INSERT INTO countries VALUES (68,'Ethiopia','ET','ETH','1');
INSERT INTO countries VALUES (69,'Falkland Islands (Malvinas)','FK','FLK','1');
INSERT INTO countries VALUES (70,'Faroe Islands','FO','FRO','1');
INSERT INTO countries VALUES (71,'Fiji','FJ','FJI','1');
INSERT INTO countries VALUES (72,'Finland','FI','FIN','1');
INSERT INTO countries VALUES (73,'France','FR','FRA','1');
INSERT INTO countries VALUES (74,'France, Metropolitan','FX','FXX','1');
INSERT INTO countries VALUES (75,'French Guiana','GF','GUF','1');
INSERT INTO countries VALUES (76,'French Polynesia','PF','PYF','1');
INSERT INTO countries VALUES (77,'French Southern Territories','TF','ATF','1');
INSERT INTO countries VALUES (78,'Gabon','GA','GAB','1');
INSERT INTO countries VALUES (79,'Gambia','GM','GMB','1');
INSERT INTO countries VALUES (80,'Georgia','GE','GEO','1');
INSERT INTO countries VALUES (81,'Germany','DE','DEU','5');
INSERT INTO countries VALUES (82,'Ghana','GH','GHA','1');
INSERT INTO countries VALUES (83,'Gibraltar','GI','GIB','1');
INSERT INTO countries VALUES (84,'Greece','GR','GRC','1');
INSERT INTO countries VALUES (85,'Greenland','GL','GRL','1');
INSERT INTO countries VALUES (86,'Grenada','GD','GRD','1');
INSERT INTO countries VALUES (87,'Guadeloupe','GP','GLP','1');
INSERT INTO countries VALUES (88,'Guam','GU','GUM','1');
INSERT INTO countries VALUES (89,'Guatemala','GT','GTM','1');
INSERT INTO countries VALUES (90,'Guinea','GN','GIN','1');
INSERT INTO countries VALUES (91,'Guinea-bissau','GW','GNB','1');
INSERT INTO countries VALUES (92,'Guyana','GY','GUY','1');
INSERT INTO countries VALUES (93,'Haiti','HT','HTI','1');
INSERT INTO countries VALUES (94,'Heard and Mc Donald Islands','HM','HMD','1');
INSERT INTO countries VALUES (95,'Honduras','HN','HND','1');
INSERT INTO countries VALUES (96,'Hong Kong','HK','HKG','1');
INSERT INTO countries VALUES (97,'Hungary','HU','HUN','1');
INSERT INTO countries VALUES (98,'Iceland','IS','ISL','1');
INSERT INTO countries VALUES (99,'India','IN','IND','1');
INSERT INTO countries VALUES (100,'Indonesia','ID','IDN','1');
INSERT INTO countries VALUES (101,'Iran (Islamic Republic of)','IR','IRN','1');
INSERT INTO countries VALUES (102,'Iraq','IQ','IRQ','1');
INSERT INTO countries VALUES (103,'Ireland','IE','IRL','1');
INSERT INTO countries VALUES (104,'Israel','IL','ISR','1');
INSERT INTO countries VALUES (105,'Italy','IT','ITA','1');
INSERT INTO countries VALUES (106,'Jamaica','JM','JAM','1');
INSERT INTO countries VALUES (107,'Japan','JP','JPN','1');
INSERT INTO countries VALUES (108,'Jordan','JO','JOR','1');
INSERT INTO countries VALUES (109,'Kazakhstan','KZ','KAZ','1');
INSERT INTO countries VALUES (110,'Kenya','KE','KEN','1');
INSERT INTO countries VALUES (111,'Kiribati','KI','KIR','1');
INSERT INTO countries VALUES (112,'Korea, Democratic People\'s Republic of','KP','PRK','1');
INSERT INTO countries VALUES (113,'Korea, Republic of','KR','KOR','1');
INSERT INTO countries VALUES (114,'Kuwait','KW','KWT','1');
INSERT INTO countries VALUES (115,'Kyrgyzstan','KG','KGZ','1');
INSERT INTO countries VALUES (116,'Lao People\'s Democratic Republic','LA','LAO','1');
INSERT INTO countries VALUES (117,'Latvia','LV','LVA','1');
INSERT INTO countries VALUES (118,'Lebanon','LB','LBN','1');
INSERT INTO countries VALUES (119,'Lesotho','LS','LSO','1');
INSERT INTO countries VALUES (120,'Liberia','LR','LBR','1');
INSERT INTO countries VALUES (121,'Libyan Arab Jamahiriya','LY','LBY','1');
INSERT INTO countries VALUES (122,'Liechtenstein','LI','LIE','1');
INSERT INTO countries VALUES (123,'Lithuania','LT','LTU','1');
INSERT INTO countries VALUES (124,'Luxembourg','LU','LUX','1');
INSERT INTO countries VALUES (125,'Macau','MO','MAC','1');
INSERT INTO countries VALUES (126,'Macedonia, The Former Yugoslav Republic of','MK','MKD','1');
INSERT INTO countries VALUES (127,'Madagascar','MG','MDG','1');
INSERT INTO countries VALUES (128,'Malawi','MW','MWI','1');
INSERT INTO countries VALUES (129,'Malaysia','MY','MYS','1');
INSERT INTO countries VALUES (130,'Maldives','MV','MDV','1');
INSERT INTO countries VALUES (131,'Mali','ML','MLI','1');
INSERT INTO countries VALUES (132,'Malta','MT','MLT','1');
INSERT INTO countries VALUES (133,'Marshall Islands','MH','MHL','1');
INSERT INTO countries VALUES (134,'Martinique','MQ','MTQ','1');
INSERT INTO countries VALUES (135,'Mauritania','MR','MRT','1');
INSERT INTO countries VALUES (136,'Mauritius','MU','MUS','1');
INSERT INTO countries VALUES (137,'Mayotte','YT','MYT','1');
INSERT INTO countries VALUES (138,'Mexico','MX','MEX','1');
INSERT INTO countries VALUES (139,'Micronesia, Federated States of','FM','FSM','1');
INSERT INTO countries VALUES (140,'Moldova, Republic of','MD','MDA','1');
INSERT INTO countries VALUES (141,'Monaco','MC','MCO','1');
INSERT INTO countries VALUES (142,'Mongolia','MN','MNG','1');
INSERT INTO countries VALUES (143,'Montserrat','MS','MSR','1');
INSERT INTO countries VALUES (144,'Morocco','MA','MAR','1');
INSERT INTO countries VALUES (145,'Mozambique','MZ','MOZ','1');
INSERT INTO countries VALUES (146,'Myanmar','MM','MMR','1');
INSERT INTO countries VALUES (147,'Namibia','NA','NAM','1');
INSERT INTO countries VALUES (148,'Nauru','NR','NRU','1');
INSERT INTO countries VALUES (149,'Nepal','NP','NPL','1');
INSERT INTO countries VALUES (150,'Netherlands','NL','NLD','1');
INSERT INTO countries VALUES (151,'Netherlands Antilles','AN','ANT','1');
INSERT INTO countries VALUES (152,'New Caledonia','NC','NCL','1');
INSERT INTO countries VALUES (153,'New Zealand','NZ','NZL','1');
INSERT INTO countries VALUES (154,'Nicaragua','NI','NIC','1');
INSERT INTO countries VALUES (155,'Niger','NE','NER','1');
INSERT INTO countries VALUES (156,'Nigeria','NG','NGA','1');
INSERT INTO countries VALUES (157,'Niue','NU','NIU','1');
INSERT INTO countries VALUES (158,'Norfolk Island','NF','NFK','1');
INSERT INTO countries VALUES (159,'Northern Mariana Islands','MP','MNP','1');
INSERT INTO countries VALUES (160,'Norway','NO','NOR','1');
INSERT INTO countries VALUES (161,'Oman','OM','OMN','1');
INSERT INTO countries VALUES (162,'Pakistan','PK','PAK','1');
INSERT INTO countries VALUES (163,'Palau','PW','PLW','1');
INSERT INTO countries VALUES (164,'Panama','PA','PAN','1');
INSERT INTO countries VALUES (165,'Papua New Guinea','PG','PNG','1');
INSERT INTO countries VALUES (166,'Paraguay','PY','PRY','1');
INSERT INTO countries VALUES (167,'Peru','PE','PER','1');
INSERT INTO countries VALUES (168,'Philippines','PH','PHL','1');
INSERT INTO countries VALUES (169,'Pitcairn','PN','PCN','1');
INSERT INTO countries VALUES (170,'Poland','PL','POL','1');
INSERT INTO countries VALUES (171,'Portugal','PT','PRT','1');
INSERT INTO countries VALUES (172,'Puerto Rico','PR','PRI','1');
INSERT INTO countries VALUES (173,'Qatar','QA','QAT','1');
INSERT INTO countries VALUES (174,'Reunion','RE','REU','1');
INSERT INTO countries VALUES (175,'Romania','RO','ROM','1');
INSERT INTO countries VALUES (176,'Russian Federation','RU','RUS','1');
INSERT INTO countries VALUES (177,'Rwanda','RW','RWA','1');
INSERT INTO countries VALUES (178,'Saint Kitts and Nevis','KN','KNA','1');
INSERT INTO countries VALUES (179,'Saint Lucia','LC','LCA','1');
INSERT INTO countries VALUES (180,'Saint Vincent and the Grenadines','VC','VCT','1');
INSERT INTO countries VALUES (181,'Samoa','WS','WSM','1');
INSERT INTO countries VALUES (182,'San Marino','SM','SMR','1');
INSERT INTO countries VALUES (183,'Sao Tome and Principe','ST','STP','1');
INSERT INTO countries VALUES (184,'Saudi Arabia','SA','SAU','1');
INSERT INTO countries VALUES (185,'Senegal','SN','SEN','1');
INSERT INTO countries VALUES (186,'Seychelles','SC','SYC','1');
INSERT INTO countries VALUES (187,'Sierra Leone','SL','SLE','1');
INSERT INTO countries VALUES (188,'Singapore','SG','SGP', '4');
INSERT INTO countries VALUES (189,'Slovakia (Slovak Republic)','SK','SVK','1');
INSERT INTO countries VALUES (190,'Slovenia','SI','SVN','1');
INSERT INTO countries VALUES (191,'Solomon Islands','SB','SLB','1');
INSERT INTO countries VALUES (192,'Somalia','SO','SOM','1');
INSERT INTO countries VALUES (193,'South Africa','ZA','ZAF','1');
INSERT INTO countries VALUES (194,'South Georgia and the South Sandwich Islands','GS','SGS','1');
INSERT INTO countries VALUES (195,'Spain','ES','ESP','3');
INSERT INTO countries VALUES (196,'Sri Lanka','LK','LKA','1');
INSERT INTO countries VALUES (197,'St. Helena','SH','SHN','1');
INSERT INTO countries VALUES (198,'St. Pierre and Miquelon','PM','SPM','1');
INSERT INTO countries VALUES (199,'Sudan','SD','SDN','1');
INSERT INTO countries VALUES (200,'Suriname','SR','SUR','1');
INSERT INTO countries VALUES (201,'Svalbard and Jan Mayen Islands','SJ','SJM','1');
INSERT INTO countries VALUES (202,'Swaziland','SZ','SWZ','1');
INSERT INTO countries VALUES (203,'Sweden','SE','SWE','1');
INSERT INTO countries VALUES (204,'Switzerland','CH','CHE','1');
INSERT INTO countries VALUES (205,'Syrian Arab Republic','SY','SYR','1');
INSERT INTO countries VALUES (206,'Taiwan','TW','TWN','1');
INSERT INTO countries VALUES (207,'Tajikistan','TJ','TJK','1');
INSERT INTO countries VALUES (208,'Tanzania, United Republic of','TZ','TZA','1');
INSERT INTO countries VALUES (209,'Thailand','TH','THA','1');
INSERT INTO countries VALUES (210,'Togo','TG','TGO','1');
INSERT INTO countries VALUES (211,'Tokelau','TK','TKL','1');
INSERT INTO countries VALUES (212,'Tonga','TO','TON','1');
INSERT INTO countries VALUES (213,'Trinidad and Tobago','TT','TTO','1');
INSERT INTO countries VALUES (214,'Tunisia','TN','TUN','1');
INSERT INTO countries VALUES (215,'Turkey','TR','TUR','1');
INSERT INTO countries VALUES (216,'Turkmenistan','TM','TKM','1');
INSERT INTO countries VALUES (217,'Turks and Caicos Islands','TC','TCA','1');
INSERT INTO countries VALUES (218,'Tuvalu','TV','TUV','1');
INSERT INTO countries VALUES (219,'Uganda','UG','UGA','1');
INSERT INTO countries VALUES (220,'Ukraine','UA','UKR','1');
INSERT INTO countries VALUES (221,'United Arab Emirates','AE','ARE','1');
INSERT INTO countries VALUES (222,'United Kingdom','GB','GBR','6');
INSERT INTO countries VALUES (223,'United States','US','USA', '2');
INSERT INTO countries VALUES (224,'United States Minor Outlying Islands','UM','UMI','1');
INSERT INTO countries VALUES (225,'Uruguay','UY','URY','1');
INSERT INTO countries VALUES (226,'Uzbekistan','UZ','UZB','1');
INSERT INTO countries VALUES (227,'Vanuatu','VU','VUT','1');
INSERT INTO countries VALUES (228,'Vatican City State (Holy See)','VA','VAT','1');
INSERT INTO countries VALUES (229,'Venezuela','VE','VEN','1');
INSERT INTO countries VALUES (230,'Viet Nam','VN','VNM','1');
INSERT INTO countries VALUES (231,'Virgin Islands (British)','VG','VGB','1');
INSERT INTO countries VALUES (232,'Virgin Islands (U.S.)','VI','VIR','1');
INSERT INTO countries VALUES (233,'Wallis and Futuna Islands','WF','WLF','1');
INSERT INTO countries VALUES (234,'Western Sahara','EH','ESH','1');
INSERT INTO countries VALUES (235,'Yemen','YE','YEM','1');
INSERT INTO countries VALUES (236,'Yugoslavia','YU','YUG','1');
INSERT INTO countries VALUES (237,'Zaire','ZR','ZAR','1');
INSERT INTO countries VALUES (238,'Zambia','ZM','ZMB','1');
INSERT INTO countries VALUES (239,'Zimbabwe','ZW','ZWE','1');

INSERT INTO currencies VALUES (1,'US Dollar','USD','$','','.',',','2','1.0000', now());
INSERT INTO currencies VALUES (2,'Euro','EUR','&euro;','','.',',','2','0.7413', now());
INSERT INTO currencies VALUES (3,'GB Pound','GBP','&pound;','','.',',','2','0.5030', now());
INSERT INTO currencies VALUES (4,'Canadian Dollar','CAD','$','','.',',','2','1.1059', now());
INSERT INTO currencies VALUES (5,'Australian Dollar','AUD','$','','.',',','2','1.2407', now());
#INSERT INTO currencies VALUES (6,'Japanese Yen','JPY','&yen;','','.',',','2','115.0750', now());

INSERT INTO languages VALUES (2, 'English', 'en', 'icon.gif', 'english', 2);
INSERT INTO languages VALUES (1, 'Franais', 'fr', 'icon.gif', 'french', 1);

INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'banner_box_all.php', 1, 1, 5, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'banner_box.php', 1, 0, 300, 1, 127);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'banner_box2.php', 1, 1, 15, 1, 15);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'best_sellers.php', 1, 1, 30, 70, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'categories.php', 1, 0, 10, 10, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'currencies.php', 1, 1, 80, 60, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'document_categories.php', 1, 0, 0, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'ezpages.php', 1, 1, -1, 2, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'featured.php', 1, 0, 45, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'information.php', 1, 0, 50, 40, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'languages.php', 1, 1, 70, 50, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'manufacturers.php', 1, 0, 30, 20, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'manufacturer_info.php', 1, 1, 35, 95, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'more_information.php', 1, 0, 200, 200, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'music_genres.php', 1, 1, 0, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'order_history.php', 1, 1, 0, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'product_notifications.php', 1, 1, 55, 85, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'record_companies.php', 1, 1, 0, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'reviews.php', 1, 0, 40, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'search.php', 1, 1, 10, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'search_header.php', 0, 0, 0, 0, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'shopping_cart.php', 1, 1, 20, 30, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'specials.php', 1, 1, 45, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'tell_a_friend.php', 1, 1, 65, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'whats_new.php', 1, 0, 20, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('default_template_settings', 'whos_online.php', 1, 1, 200, 200, 1);

INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'banner_box_all.php', 1, 1, 5, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'banner_box.php', 1, 0, 300, 1, 127);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'banner_box2.php', 1, 1, 15, 1, 15);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'best_sellers.php', 1, 1, 30, 70, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'categories.php', 1, 0, 10, 10, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'currencies.php', 1, 1, 80, 60, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'ezpages.php', 1, 1, -1, 2, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'featured.php', 1, 0, 45, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'information.php', 1, 0, 50, 40, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'languages.php', 1, 1, 70, 50, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'manufacturers.php', 1, 0, 30, 20, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'manufacturer_info.php', 1, 1, 35, 95, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'more_information.php', 1, 0, 200, 200, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'my_broken_box.php', 1, 0, 0, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'order_history.php', 1, 1, 0, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'product_notifications.php', 1, 1, 55, 85, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'reviews.php', 1, 0, 40, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'search.php', 1, 1, 10, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'search_header.php', 0, 0, 0, 0, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'shopping_cart.php', 1, 1, 20, 30, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'specials.php', 1, 1, 45, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'tell_a_friend.php', 1, 1, 65, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'whats_new.php', 1, 0, 20, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('template_default', 'whos_online.php', 1, 1, 200, 200, 1);

INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'banner_box.php', 1, 0, 300, 1, 127);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'banner_box2.php', 1, 1, 15, 1, 15);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'banner_box_all.php', 1, 1, 5, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'best_sellers.php', 1, 1, 30, 70, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'categories.php', 1, 0, 10, 10, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'currencies.php', 1, 1, 80, 60, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'document_categories.php', 1, 0, 0, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'ezpages.php', 1, 1, -1, 2, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'featured.php', 1, 0, 45, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'information.php', 1, 0, 50, 40, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'languages.php', 1, 1, 70, 50, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'manufacturers.php', 1, 0, 30, 20, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'manufacturer_info.php', 1, 1, 35, 95, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'more_information.php', 1, 0, 200, 200, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'music_genres.php', 1, 1, 0, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'order_history.php', 1, 1, 0, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'product_notifications.php', 1, 1, 55, 85, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'record_companies.php', 1, 1, 0, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'reviews.php', 1, 0, 40, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'search.php', 1, 1, 10, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'search_header.php', 0, 0, 0, 0, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'shopping_cart.php', 1, 1, 20, 30, 1);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'specials.php', 1, 1, 45, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'tell_a_friend.php', 1, 1, 65, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'whats_new.php', 1, 0, 20, 0, 0);
INSERT INTO layout_boxes (layout_template, layout_box_name, layout_box_status, layout_box_location, layout_box_sort_order, layout_box_sort_order_single, layout_box_status_single) VALUES ('classic', 'whos_online.php', 1, 1, 200, 200, 1);

INSERT INTO orders_status VALUES ( '1', '1', 'En attente');
INSERT INTO orders_status VALUES ( '2', '1', 'Traitement en cours');
INSERT INTO orders_status VALUES ( '3', '1', 'Livre');
INSERT INTO orders_status VALUES ( '4', '1', 'Mise  jour');
INSERT INTO orders_status VALUES ( '1', '2', 'Pending');
INSERT INTO orders_status VALUES ( '2', '2', 'Processing');
INSERT INTO orders_status VALUES ( '3', '2', 'Delivered');
INSERT INTO orders_status VALUES ( '4', '2', 'Update');

INSERT INTO product_types VALUES (1, 'Product - General', 'product', '1', 'Y', '', now(), now());
INSERT INTO product_types VALUES (2, 'Product - Music', 'product_music', '1', 'Y', '', now(), now());
INSERT INTO product_types VALUES (3, 'Document - General', 'document_general', '3', 'N', '', now(), now());
INSERT INTO product_types VALUES (4, 'Document - Product', 'document_product', '3', 'Y', '', now(), now());
INSERT INTO product_types VALUES (5, 'Product - Free Shipping', 'product_free_shipping', '1', 'Y', '', now(), now());

INSERT INTO products_options_types (products_options_types_id, products_options_types_name) VALUES (0, 'Dropdown');
INSERT INTO products_options_types (products_options_types_id, products_options_types_name) VALUES (1, 'Text');
INSERT INTO products_options_types (products_options_types_id, products_options_types_name) VALUES (2, 'Radio');
INSERT INTO products_options_types (products_options_types_id, products_options_types_name) VALUES (3, 'Checkbox');
INSERT INTO products_options_types (products_options_types_id, products_options_types_name) VALUES (4, 'File');
INSERT INTO products_options_types (products_options_types_id, products_options_types_name) VALUES (5, 'Read Only');

INSERT INTO products_options_values (products_options_values_id, language_id, products_options_values_name) VALUES (0, 1, 'TEXT');

# USA/Florida
INSERT INTO tax_rates VALUES (1, 1, 1, 1, 7.0, 'FL TAX 7.0%', now(), now());
INSERT INTO geo_zones (geo_zone_id,geo_zone_name,geo_zone_description,date_added) VALUES (1,'Florida','Florida local sales tax zone',now());
INSERT INTO zones_to_geo_zones (association_id,zone_country_id,zone_id,geo_zone_id,date_added) VALUES (1,223,18,1,now());
INSERT INTO tax_class (tax_class_id, tax_class_title, tax_class_description, date_added) VALUES (1, 'Taxable Goods', 'The following types of products are included: non-food, services, etc', now());

# USA
INSERT INTO zones VALUES (1,223,'AL','Alabama');
INSERT INTO zones VALUES (2,223,'AK','Alaska');
INSERT INTO zones VALUES (3,223,'AS','American Samoa');
INSERT INTO zones VALUES (4,223,'AZ','Arizona');
INSERT INTO zones VALUES (5,223,'AR','Arkansas');
INSERT INTO zones VALUES (6,223,'AF','Armed Forces Africa');
INSERT INTO zones VALUES (7,223,'AA','Armed Forces Americas');
INSERT INTO zones VALUES (8,223,'AC','Armed Forces Canada');
INSERT INTO zones VALUES (9,223,'AE','Armed Forces Europe');
INSERT INTO zones VALUES (10,223,'AM','Armed Forces Middle East');
INSERT INTO zones VALUES (11,223,'AP','Armed Forces Pacific');
INSERT INTO zones VALUES (12,223,'CA','California');
INSERT INTO zones VALUES (13,223,'CO','Colorado');
INSERT INTO zones VALUES (14,223,'CT','Connecticut');
INSERT INTO zones VALUES (15,223,'DE','Delaware');
INSERT INTO zones VALUES (16,223,'DC','District of Columbia');
INSERT INTO zones VALUES (17,223,'FM','Federated States Of Micronesia');
INSERT INTO zones VALUES (18,223,'FL','Florida');
INSERT INTO zones VALUES (19,223,'GA','Georgia');
INSERT INTO zones VALUES (20,223,'GU','Guam');
INSERT INTO zones VALUES (21,223,'HI','Hawaii');
INSERT INTO zones VALUES (22,223,'ID','Idaho');
INSERT INTO zones VALUES (23,223,'IL','Illinois');
INSERT INTO zones VALUES (24,223,'IN','Indiana');
INSERT INTO zones VALUES (25,223,'IA','Iowa');
INSERT INTO zones VALUES (26,223,'KS','Kansas');
INSERT INTO zones VALUES (27,223,'KY','Kentucky');
INSERT INTO zones VALUES (28,223,'LA','Louisiana');
INSERT INTO zones VALUES (29,223,'ME','Maine');
INSERT INTO zones VALUES (30,223,'MH','Marshall Islands');
INSERT INTO zones VALUES (31,223,'MD','Maryland');
INSERT INTO zones VALUES (32,223,'MA','Massachusetts');
INSERT INTO zones VALUES (33,223,'MI','Michigan');
INSERT INTO zones VALUES (34,223,'MN','Minnesota');
INSERT INTO zones VALUES (35,223,'MS','Mississippi');
INSERT INTO zones VALUES (36,223,'MO','Missouri');
INSERT INTO zones VALUES (37,223,'MT','Montana');
INSERT INTO zones VALUES (38,223,'NE','Nebraska');
INSERT INTO zones VALUES (39,223,'NV','Nevada');
INSERT INTO zones VALUES (40,223,'NH','New Hampshire');
INSERT INTO zones VALUES (41,223,'NJ','New Jersey');
INSERT INTO zones VALUES (42,223,'NM','New Mexico');
INSERT INTO zones VALUES (43,223,'NY','New York');
INSERT INTO zones VALUES (44,223,'NC','North Carolina');
INSERT INTO zones VALUES (45,223,'ND','North Dakota');
INSERT INTO zones VALUES (46,223,'MP','Northern Mariana Islands');
INSERT INTO zones VALUES (47,223,'OH','Ohio');
INSERT INTO zones VALUES (48,223,'OK','Oklahoma');
INSERT INTO zones VALUES (49,223,'OR','Oregon');
INSERT INTO zones VALUES (50,163,'PW','Palau');
INSERT INTO zones VALUES (51,223,'PA','Pennsylvania');
INSERT INTO zones VALUES (52,223,'PR','Puerto Rico');
INSERT INTO zones VALUES (53,223,'RI','Rhode Island');
INSERT INTO zones VALUES (54,223,'SC','South Carolina');
INSERT INTO zones VALUES (55,223,'SD','South Dakota');
INSERT INTO zones VALUES (56,223,'TN','Tennessee');
INSERT INTO zones VALUES (57,223,'TX','Texas');
INSERT INTO zones VALUES (58,223,'UT','Utah');
INSERT INTO zones VALUES (59,223,'VT','Vermont');
INSERT INTO zones VALUES (60,223,'VI','Virgin Islands');
INSERT INTO zones VALUES (61,223,'VA','Virginia');
INSERT INTO zones VALUES (62,223,'WA','Washington');
INSERT INTO zones VALUES (63,223,'WV','West Virginia');
INSERT INTO zones VALUES (64,223,'WI','Wisconsin');
INSERT INTO zones VALUES (65,223,'WY','Wyoming');

# Canada
INSERT INTO zones VALUES (66,38,'AB','Alberta');
INSERT INTO zones VALUES (67,38,'BC','British Columbia');
INSERT INTO zones VALUES (68,38,'MB','Manitoba');
INSERT INTO zones VALUES (69,38,'NL','Newfoundland');
INSERT INTO zones VALUES (70,38,'NB','New Brunswick');
INSERT INTO zones VALUES (71,38,'NS','Nova Scotia');
INSERT INTO zones VALUES (72,38,'NT','Northwest Territories');
INSERT INTO zones VALUES (73,38,'NU','Nunavut');
INSERT INTO zones VALUES (74,38,'ON','Ontario');
INSERT INTO zones VALUES (75,38,'PE','Prince Edward Island');
INSERT INTO zones VALUES (76,38,'QC','Quebec');
INSERT INTO zones VALUES (77,38,'SK','Saskatchewan');
INSERT INTO zones VALUES (78,38,'YT','Yukon Territory');

# Germany
INSERT INTO zones VALUES (79,81,'NDS','Niedersachsen');
INSERT INTO zones VALUES (80,81,'BAW','Baden Wrtemberg');
INSERT INTO zones VALUES (81,81,'BAY','Bayern');
INSERT INTO zones VALUES (82,81,'BER','Berlin');
INSERT INTO zones VALUES (83,81,'BRG','Brandenburg');
INSERT INTO zones VALUES (84,81,'BRE','Bremen');
INSERT INTO zones VALUES (85,81,'HAM','Hamburg');
INSERT INTO zones VALUES (86,81,'HES','Hessen');
INSERT INTO zones VALUES (87,81,'MEC','Mecklenburg-Vorpommern');
INSERT INTO zones VALUES (88,81,'NRW','Nordrhein-Westfalen');
INSERT INTO zones VALUES (89,81,'RHE','Rheinland-Pfalz');
INSERT INTO zones VALUES (90,81,'SAR','Saarland');
INSERT INTO zones VALUES (91,81,'SAS','Sachsen');
INSERT INTO zones VALUES (92,81,'SAC','Sachsen-Anhalt');
INSERT INTO zones VALUES (93,81,'SCN','Schleswig-Holstein');
INSERT INTO zones VALUES (94,81,'THE','Thringen');

# Austria
INSERT INTO zones VALUES (95,14,'WI','Wien');
INSERT INTO zones VALUES (96,14,'NO','Niedersterreich');
INSERT INTO zones VALUES (97,14,'OO','Obersterreich');
INSERT INTO zones VALUES (98,14,'SB','Salzburg');
INSERT INTO zones VALUES (99,14,'KN','Krnten');
INSERT INTO zones VALUES (100,14,'ST','Steiermark');
INSERT INTO zones VALUES (101,14,'TI','Tirol');
INSERT INTO zones VALUES (102,14,'BL','Burgenland');
INSERT INTO zones VALUES (103,14,'VB','Voralberg');

# Swizterland
INSERT INTO zones VALUES (104,204,'AG','Aargau');
INSERT INTO zones VALUES (105,204,'AI','Appenzell Innerrhoden');
INSERT INTO zones VALUES (106,204,'AR','Appenzell Ausserrhoden');
INSERT INTO zones VALUES (107,204,'BE','Bern');
INSERT INTO zones VALUES (108,204,'BL','Basel-Landschaft');
INSERT INTO zones VALUES (109,204,'BS','Basel-Stadt');
INSERT INTO zones VALUES (110,204,'FR','Freiburg');
INSERT INTO zones VALUES (111,204,'GE','Genf');
INSERT INTO zones VALUES (112,204,'GL','Glarus');
INSERT INTO zones VALUES (113,204,'JU','Graubnden');
INSERT INTO zones VALUES (114,204,'JU','Jura');
INSERT INTO zones VALUES (115,204,'LU','Luzern');
INSERT INTO zones VALUES (116,204,'NE','Neuenburg');
INSERT INTO zones VALUES (117,204,'NW','Nidwalden');
INSERT INTO zones VALUES (118,204,'OW','Obwalden');
INSERT INTO zones VALUES (119,204,'SG','St. Gallen');
INSERT INTO zones VALUES (120,204,'SH','Schaffhausen');
INSERT INTO zones VALUES (121,204,'SO','Solothurn');
INSERT INTO zones VALUES (122,204,'SZ','Schwyz');
INSERT INTO zones VALUES (123,204,'TG','Thurgau');
INSERT INTO zones VALUES (124,204,'TI','Tessin');
INSERT INTO zones VALUES (125,204,'UR','Uri');
INSERT INTO zones VALUES (126,204,'VD','Waadt');
INSERT INTO zones VALUES (127,204,'VS','Wallis');
INSERT INTO zones VALUES (128,204,'ZG','Zug');
INSERT INTO zones VALUES (129,204,'ZH','Zrich');

# Spain
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'A Corua','A Corua');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Alava','Alava');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Albacete','Albacete');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Alicante','Alicante');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Almeria','Almeria');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Asturias','Asturias');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Avila','Avila');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Badajoz','Badajoz');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Baleares','Baleares');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Barcelona','Barcelona');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Burgos','Burgos');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Caceres','Caceres');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Cadiz','Cadiz');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Cantabria','Cantabria');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Castellon','Castellon');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Ceuta','Ceuta');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Ciudad Real','Ciudad Real');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Cordoba','Cordoba');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Cuenca','Cuenca');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Girona','Girona');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Granada','Granada');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Guadalajara','Guadalajara');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Guipuzcoa','Guipuzcoa');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Huelva','Huelva');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Huesca','Huesca');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Jaen','Jaen');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'La Rioja','La Rioja');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Las Palmas','Las Palmas');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Leon','Leon');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Lleida','Lleida');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Lugo','Lugo');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Madrid','Madrid');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Malaga','Malaga');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Melilla','Melilla');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Murcia','Murcia');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Navarra','Navarra');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Ourense','Ourense');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Palencia','Palencia');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Pontevedra','Pontevedra');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Salamanca','Salamanca');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Santa Cruz de Tenerife','Santa Cruz de Tenerife');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Segovia','Segovia');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Sevilla','Sevilla');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Soria','Soria');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Tarragona','Tarragona');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Teruel','Teruel');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Toledo','Toledo');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Valencia','Valencia');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Valladolid','Valladolid');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Vizcaya','Vizcaya');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Zamora','Zamora');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Zaragoza','Zaragoza');

#australian zones
INSERT INTO zones VALUES (NULL, 13, 'ACT', 'Australian Capital Territory');
INSERT INTO zones VALUES (NULL, 13, 'NSW', 'New South Wales');
INSERT INTO zones VALUES (NULL, 13, 'NT', 'Northern Territory');
INSERT INTO zones VALUES (NULL, 13, 'QLD', 'Queensland');
INSERT INTO zones VALUES (NULL, 13, 'SA', 'South Australia');
INSERT INTO zones VALUES (NULL, 13, 'TAS', 'Tasmania');
INSERT INTO zones VALUES (NULL, 13, 'VIC', 'Victoria');
INSERT INTO zones VALUES (NULL, 13, 'WA', 'Western Australia');


INSERT INTO product_type_layout VALUES (1, 'Affiche la rfrence', 'SHOW_PRODUCT_INFO_MODEL', '1', 'Affiche la rfrence du produit sur la page descriptive du produit', 1, 1, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (2, 'Affiche le poids', 'SHOW_PRODUCT_INFO_WEIGHT', '1', 'Affiche le poids sur la page descriptive du produit', 1, 2, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (3, 'Affiche les attributs de poids', 'SHOW_PRODUCT_INFO_WEIGHT_ATTRIBUTES', '1', 'Affiche les attributs de poids sur la page descriptive du produit', 1, 3, '2008-03-05 11:14:38', '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (4, 'Affiche le fabricant', 'SHOW_PRODUCT_INFO_MANUFACTURER', '1', 'Affiche le nom du fabricant sur la page descriptive du produit', 1, 4, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (5, 'Affiche la quantit dans le panier', 'SHOW_PRODUCT_INFO_IN_CART_QTY', '1', 'Affiche la quantit dans la panier courant sur la page descriptive du produit', 1, 5, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (6, 'Affiche la quantit en stock', 'SHOW_PRODUCT_INFO_QUANTITY', '1', 'Affiche la quantit en stock sur la page descriptive du produit', 1, 6, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (7, 'Affiche le nombre de commentaires', 'SHOW_PRODUCT_INFO_REVIEWS_COUNT', '1', 'Affiche le nombre de commentaires  propos du produit sur la page descriptive du produit', 1, 7, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (8, 'Affiche le bouton pour crire un commentaire', 'SHOW_PRODUCT_INFO_REVIEWS', '1', 'Affiche le bouton pour crire un commentaire sur la page descriptive du produit', 1, 8, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (9, 'Affiche la date de disponibilit', 'SHOW_PRODUCT_INFO_DATE_AVAILABLE', '1', 'Affiche la date  laquelle le produit sera disponible sur la page descriptive du produit', 1, 9, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (10, 'Affiche la date d''ajout', 'SHOW_PRODUCT_INFO_DATE_ADDED', '1', 'Affiche la date d''ajout du produit sur la page descriptive du produit', 1, 10, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (11, 'Affiche l''URL du produit', 'SHOW_PRODUCT_INFO_URL', '1', 'Affiche l''adresse URL du produit sur la page descriptive du produit', 1, 11, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (12, 'Affiche les images supplmentaires', 'SHOW_PRODUCT_INFO_ADDITIONAL_IMAGES', '1', 'Affiche les images supplmentaires sur la page descriptive du produit', 1, 13, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (13, 'Affiche le texte "A partir de" pour le prix', 'SHOW_PRODUCT_INFO_STARTING_AT', '1', 'Affiche le texte "A partir de" avant le prix des produits qui ont des attributs', 1, 12, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (14, 'Affiche le bouton "en parler  un ami"', 'SHOW_PRODUCT_INFO_TELL_A_FRIEND', '1', 'Affiche le bouton "en parler  un ami" sur la page descriptive du produit<br /><br />Note: la dsactivation de ce paramtre n''affecte pas la boite latrale "en parler  un ami", et inversement si vous dsactivez la boite latrale, cela n''affecte pas ce paramtre<br />0= off 1= on', 1, 15, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (15, 'Etat de l''image Produit en livraison gratuite - Catalogue', 'SHOW_PRODUCT_INFO_ALWAYS_FREE_SHIPPING_IMAGE_SWITCH', '0', 'Affiche l''image/texte Livraison gratuite dans le catalogue?', 1, 16, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (16, 'Classe de taxe par dfaut sur les produits -  l''ajout d''un nouveau produit?', 'DEFAULT_PRODUCT_TAX_CLASS_ID', '0', 'Quelle doit tre l''ID de la classe de taxe par dfaut lors de l''ajout de nouveaux produits?', 1, 100, NULL, '2007-11-04 19:40:01', '', '');
INSERT INTO product_type_layout VALUES (17, 'Etat par dfaut de produits virtuels  - Pas de livraison - A l''ajout de nouveaux produits ?', 'DEFAULT_PRODUCT_PRODUCTS_VIRTUAL', '0', 'Etat par dfaut des produits virtuels sur ON lors de l''ajout de nouveaux produits?', 1, 101, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (18, 'Etat par dfaut de Livraison gratuite - Rgles de livraison normales - A l''ajout de nouveaux produits?', 'DEFAULT_PRODUCT_PRODUCTS_IS_ALWAYS_FREE_SHIPPING', '0', 'Quel doit tre l''tat par dfaut de Livraison gratuite lors de l''ajout de nouveaux produits?<br />Oui, toujours en livraison gratuite<br />Non, toujours dsactiver la livraison gratuite<br />Special, Produits/tlchargement qui ncessite une livraison', 1, 102, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes, Always ON''), array(''id''=>''0'', ''text''=>''No, Always OFF''), array(''id''=>''2'', ''text''=>''Special'')), ');
INSERT INTO product_type_layout VALUES (19, 'Affiche la rfrence', 'SHOW_PRODUCT_MUSIC_INFO_MODEL', '1', 'Affiche la rfrence du produit sur la page descriptive des produits', 2, 1, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (20, 'Affiche le poids', 'SHOW_PRODUCT_MUSIC_INFO_WEIGHT', '0', 'Affiche le poids sur la page descriptive des produits', 2, 2, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (21, 'Affiche les attributs de poids', 'SHOW_PRODUCT_MUSIC_INFO_WEIGHT_ATTRIBUTES', '1', 'Affiche les attributs de poids sur la page descriptive des produits', 2, 3, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (22, 'Affiche l''artiste', 'SHOW_PRODUCT_MUSIC_INFO_ARTIST', '1', 'Affiche le nom de l''artiste sur la page descriptive des produits', 2, 4, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (23, 'Affiche le style de musique', 'SHOW_PRODUCT_MUSIC_INFO_GENRE', '1', 'Affiche le style de musique sur la page descriptive des produits', 2, 4, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (24, 'Affiche la maison de disques', 'SHOW_PRODUCT_MUSIC_INFO_RECORD_COMPANY', '1', 'Affiche le nom de la maison de disques sur la page descriptive des produits', 2, 4, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (25, 'Affiche la quantit dans le panier', 'SHOW_PRODUCT_MUSIC_INFO_IN_CART_QTY', '1', 'Affiche la quantit courante dans le panier sur la page descriptive des produits', 2, 5, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (26, 'Affiche la quantit en stock', 'SHOW_PRODUCT_MUSIC_INFO_QUANTITY', '0', 'Affiche la quantit en stock sur la page descriptive des produits', 2, 6, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (27, 'Affiche le nombre de commentaires', 'SHOW_PRODUCT_MUSIC_INFO_REVIEWS_COUNT', '1', 'Affiche le nombre de commentaires sur la page descriptive des produits ', 2, 7, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (28, 'Affiche le bouton pour crire un commentaire', 'SHOW_PRODUCT_MUSIC_INFO_REVIEWS', '1', 'Affiche le bouton pour crire un commentaire sur la page descriptive des produits', 2, 8, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (29, 'Affiche la date de disponibilit', 'SHOW_PRODUCT_MUSIC_INFO_DATE_AVAILABLE', '1', 'Affiche le date de disponibilit sur la page descriptive des produits', 2, 9, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (30, 'Affiche la date d''ajout', 'SHOW_PRODUCT_MUSIC_INFO_DATE_ADDED', '1', 'Affiche la date d''ajout sur la page descriptive des produits', 2, 10, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (31, 'Affiche le texte "A partir de" avec le prix', 'SHOW_PRODUCT_MUSIC_INFO_STARTING_AT', '1', 'Affiche le texte "A partir de" avant le prix, sur les produits avec attributs', 2, 12, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (32, 'Affiche les images additionnelles de produits', 'SHOW_PRODUCT_MUSIC_INFO_ADDITIONAL_IMAGES', '1', 'Affiche les images additionnelles de produits sur la page descriptive des produits', 2, 13, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (33, 'Affiche le bouton "en parler  un ami"', 'SHOW_PRODUCT_MUSIC_INFO_TELL_A_FRIEND', '1', 'Affiche le bouton en parler  un ami sur la page descriptive des produits<br /><br />Note: la dsactivation de ce paramtre n''affecte pas la boite latrale "En parler  un ami", et inversement<br />0= off 1= on', 2, 15, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (34, 'Etat de l''image Produit en livraison gratuite - Catalogue', 'SHOW_PRODUCT_MUSIC_INFO_ALWAYS_FREE_SHIPPING_IMAGE_SWITCH', '0', 'Affiche l''image/texte Livraison gratuite dans le catalogue?', 2, 16, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (35, 'Classe de taxe par dfaut - A l''ajout de nouveaux produits?', 'DEFAULT_PRODUCT_MUSIC_TAX_CLASS_ID', '0', 'Quel doit tre l''ID de la classe de taxe par dfaut lors de l''ajout d''un nouveau produit?', 2, 100, NULL, '2007-11-04 19:40:01', '', '');
INSERT INTO product_type_layout VALUES (36, 'Etat par dfaut Produit virtuel - Pas le livraison requise -  l''ajout de nouveaux produits?', 'DEFAULT_PRODUCT_MUSIC_PRODUCTS_VIRTUAL', '0', 'L''tat par dfaut de la valeur Produit virtuel  l''ajout d''un nouveau produit?', 2, 101, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (37, 'Etat par dfaut Produit en livraison gratuite - Rgles de livraison normales -  l''ajout de produits?', 'DEFAULT_PRODUCT_MUSIC_PRODUCTS_IS_ALWAYS_FREE_SHIPPING', '0', 'Quelle doit tre la valeur par dfaut de l''tat Livraison gratuite  l''ajout de nouveaux produits?<br />Oui, Toujours en livraison gratuite<br />Non, livraison gratuite toujours dsactive<br />Special, Le produit/tlchargement ncessite une livraison', 2, 102, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes, Always ON''), array(''id''=>''0'', ''text''=>''No, Always OFF''), array(''id''=>''2'', ''text''=>''Special'')), ');
INSERT INTO product_type_layout VALUES (38, 'Affiche le nombre de commentaires', 'SHOW_DOCUMENT_GENERAL_INFO_REVIEWS_COUNT', '1', 'Affiche le nombre de commentaires sur la page descriptive des produits', 3, 7, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (39, 'Affiche le bouton commentaires', 'SHOW_DOCUMENT_GENERAL_INFO_REVIEWS', '1', 'Affiche le bouton pour crire un commentaire sur les produits', 3, 8, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (40, 'Affiche la date de disponibilit', 'SHOW_DOCUMENT_GENERAL_INFO_DATE_AVAILABLE', '1', 'Affiche la date  laquelle le produit sera disponible (pour les produits  venir)', 3, 9, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (41, 'Affiche la date d''ajout', 'SHOW_DOCUMENT_GENERAL_INFO_DATE_ADDED', '1', 'Affiche la date d''ajout sur la page descriptive des produits', 3, 10, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (42, 'Affiche le bouton "En parler  un ami"', 'SHOW_DOCUMENT_GENERAL_INFO_TELL_A_FRIEND', '1', 'Affiche le bouton "En parler  un ami" sur la page descriptive des produits<br /><br />Note: La dsactivation de ce paramtre n''affecte par la boite latrale "En parler  un ami", et inversement.<br />0= off 1= on', 3, 15, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (43, 'Affiche l''URL du produit', 'SHOW_DOCUMENT_GENERAL_INFO_URL', '1', 'Affiche l''URL du produit sur la page descriptive des produits', 3, 11, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (44, 'Affiche les images additionnelles de produits', 'SHOW_DOCUMENT_GENERAL_INFO_ADDITIONAL_IMAGES', '1', 'Affiche les images additionnelles de produits sur la page descriptive des produits', 3, 13, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (45, 'Affiche la rfrence', 'SHOW_DOCUMENT_PRODUCT_INFO_MODEL', '1', 'Affiche la rfrence sur la page descriptive des produits', 4, 1, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (46, 'Affiche le poids', 'SHOW_DOCUMENT_PRODUCT_INFO_WEIGHT', '0', 'Affiche le poids sur la page descriptive des produits', 4, 2, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (47, 'Affiche les attributs de poids', 'SHOW_DOCUMENT_PRODUCT_INFO_WEIGHT_ATTRIBUTES', '1', 'Affiche les attributs de poids sur la page descriptive des produits ', 4, 3, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (48, 'Affiche le fabricant', 'SHOW_DOCUMENT_PRODUCT_INFO_MANUFACTURER', '1', 'Affiche le nom du fabricant sur la page descriptive des produits', 4, 4, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (49, 'Affiche la quantit dans le panier', 'SHOW_DOCUMENT_PRODUCT_INFO_IN_CART_QTY', '1', 'Affiche la quantit dans le panier courant sur la page descriptive des produits', 4, 5, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (50, 'Affiche la quantit en stock', 'SHOW_DOCUMENT_PRODUCT_INFO_QUANTITY', '0', 'Affiche la quantit de produits en stock sur la page descriptive des produits', 4, 6, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (51, 'Affiche le nombre de commentaires', 'SHOW_DOCUMENT_PRODUCT_INFO_REVIEWS_COUNT', '1', 'Affiche le nombre de commentaires sur la page descriptive des produits', 4, 7, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (52, 'Affiche le bouton pour crire un commentaire', 'SHOW_DOCUMENT_PRODUCT_INFO_REVIEWS', '1', 'Affiche le bouton pour crire un commentaire sur la page descriptive des produits', 4, 8, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (53, 'Affiche la date de disponibilit', 'SHOW_DOCUMENT_PRODUCT_INFO_DATE_AVAILABLE', '1', 'Affiche la date  laquelle le produit sera disponible, sur la page descriptive des produits', 4, 9, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (54, 'Affiche la date d''ajout', 'SHOW_DOCUMENT_PRODUCT_INFO_DATE_ADDED', '1', 'Affiche la date d''ajout du produit sur la page descriptive des produits', 4, 10, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (55, 'Affiche l''URL du produit', 'SHOW_DOCUMENT_PRODUCT_INFO_URL', '1', 'Affiche l''URL du produit sur la page descriptive des produits', 4, 11, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (56, 'Affiche les images additionnelles de produits', 'SHOW_DOCUMENT_PRODUCT_INFO_ADDITIONAL_IMAGES', '1', 'Affiche les images additionnelles de produits sur la page descriptive des produits', 4, 13, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (57, 'Affiche le texte "A partir de" avant le prix', 'SHOW_DOCUMENT_PRODUCT_INFO_STARTING_AT', '1', 'Affiche le texte "A partir de" avant le prix sur la page descriptive des produits qui possdent des attributs jouants sur le prix', 4, 12, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (58, 'Affiche le bouton "En parler  un ami"', 'SHOW_DOCUMENT_PRODUCT_INFO_TELL_A_FRIEND', '1', 'Affiche le bouton "en parler  un ami" sur la page descriptive des produits<br /><br />Note: La dsactivation de ce paramtre n''affecte pas la boite latrale "En parler  un ami", et inversement.', 4, 15, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (59, 'Etat de l''image Produit en livraison gratuite - Catalogue', 'SHOW_DOCUMENT_PRODUCT_INFO_ALWAYS_FREE_SHIPPING_IMAGE_SWITCH', '0', 'Affiche le texte/image Livraison gratuite dans la catalogue?', 4, 16, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (60, 'La classe de taxe par dfaut -  l''ajout de nouveaux produits?', 'DEFAULT_DOCUMENT_PRODUCT_TAX_CLASS_ID', '0', 'Quelle doit tre l''ID de la classe de taxe par dfaut sur le prix lors de l''ajout d''un nouveau produit?', 4, 100, NULL, '2007-11-04 19:40:01', '', '');
INSERT INTO product_type_layout VALUES (61, 'Etat par dfaut de Produit virtuel - Pas de livraison - A l''ajout de nouveaux produits?', 'DEFAULT_DOCUMENT_PRODUCT_PRODUCTS_VIRTUAL', '0', 'L''etat par dfaut du paramtre Produit Virtuel lors de l''ajout de nouveaux produits?', 4, 101, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (62, 'Etat par dfaut de Produit en livraison gratuite - Livraison normale -  l''ajout de nouveaux produits?', 'DEFAULT_DOCUMENT_PRODUCT_PRODUCTS_IS_ALWAYS_FREE_SHIPPING', '0', 'Quel doit tre l''tat par dfaut de Livraison gratuite lors de l''ajout de nouveaux produits?<br />Oui, toujours en livraison gratuite<br />Non, dsactiver la livraison gratuite<br />Special, Le produit/tlchargement ncessite une livraison ', 4, 102, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes, Always ON''), array(''id''=>''0'', ''text''=>''No, Always OFF''), array(''id''=>''2'', ''text''=>''Special'')), ');
INSERT INTO product_type_layout VALUES (63, 'Affiche la rfrence', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_MODEL', '1', 'Affiche la rfrence du produit sur la page descriptive des produits', 5, 1, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (64, 'Affiche le poids', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_WEIGHT', '0', 'Affiche le poids sur la page descriptive des produits', 5, 2, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (65, 'Affiche les attributs de poids', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_WEIGHT_ATTRIBUTES', '1', 'Affiche les attributs de poids sur la page descriptive des produits', 5, 3, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (66, 'Affiche le fabricant', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_MANUFACTURER', '1', 'Affiche le nom du fabricant sur la page descriptive des produits', 5, 4, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (67, 'Affiche la quantit dans le panier', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_IN_CART_QTY', '1', 'Affiche la quantit dans le panier courant sur la page descriptive des produits', 5, 5, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (68, 'Affiche la quantit en stock', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_QUANTITY', '1', 'Affiche la quantit en stok sur la page descriptive des produits', 5, 6, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (69, 'Affiche le nombre de commentaires sur la page descriptive des produits', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_REVIEWS_COUNT', '1', 'Affiche le nombre de commentaires sur la page descriptive des produits', 5, 7, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (70, 'Affiche le bouton pour crire un commentaire', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_REVIEWS', '1', 'Affiche le bouton pour crire un commentaire sur la page descriptive des produits', 5, 8, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (71, 'Affiche la date de disponibilit', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_DATE_AVAILABLE', '0', 'Affiche la date  laquelle le produit sera disponible sur la page descriptive des produits', 5, 9, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (72, 'Affiche la date d''ajout', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_DATE_ADDED', '1', 'Affiche la date d''ajout sur la page descriptive des produits', 5, 10, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (73, 'Affiche l''URL des produits', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_URL', '1', 'Affiche l''URL des produits sur la page descriptive des produits', 5, 11, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (74, 'Affiche les images additionnelles des produits', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_ADDITIONAL_IMAGES', '1', 'Affiche les images additionnelles des produits sur la page descriptive des produits', 5, 13, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (75, 'Affiche le texte "A partir de" avant le prix', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_STARTING_AT', '1', 'Affiche le texte " partir de" avant le prix sur la page descriptive des produits qui ont des attributs qui jouent sur le prix.', 5, 12, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (76, 'Affiche le bouton "En parler  un ami"', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_TELL_A_FRIEND', '1', 'Affiche le bouton "En parler  un ami" sur la page descriptive des produits<br /><br />Note: La dsactivation de ce paramtre n''affecte pas la boite latrale "En parler  un ami", et inversement<br />0= off 1= on', 5, 15, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (77, 'Etat de l''image Livraison gratuite - Catalogue', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_ALWAYS_FREE_SHIPPING_IMAGE_SWITCH', '1', 'Affiche l''image/texte Livraison gratuite dans la catalogue?', 5, 16, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (78, 'Classe de taxe par dfaut sur le prix -  l''ajout de nouveaux produits', 'DEFAULT_PRODUCT_FREE_SHIPPING_TAX_CLASS_ID', '0', 'Quel doit tre lID de la classe de taxe par dfaut lors de l''ajout de nouveaux produits', 5, 100, NULL, '2007-11-04 19:40:01', '', '');
INSERT INTO product_type_layout VALUES (79, 'Etat par dfaut de Produit virtuel - Pas de livraison - A l''ajout de nouveaux produits?', 'DEFAULT_PRODUCT_FREE_SHIPPING_PRODUCTS_VIRTUAL', '0', 'Etat par dfaut de Produit virtuel lors de l''ajout de nouveaux produits?', 5, 101, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (80, 'Etat par dfaut de Produit en livraison gratuite - Livraison normale - A l''ajout de nouveaux produits?', 'DEFAULT_PRODUCT_FREE_SHIPPING_PRODUCTS_IS_ALWAYS_FREE_SHIPPING', '1', 'Quelle doit tre la valeur par dfaut de "Livraison gratuite" lors de l''ajout de nouveaux produits?<br />Oui, Toujours en livraison gratuite<br />Non, dsactiver la livraison gratuite<br />Special, Le produit/tlchargement ncessite une livraison', 5, 102, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes, Always ON''), array(''id''=>''0'', ''text''=>''No, Always OFF''), array(''id''=>''2'', ''text''=>''Special'')), ');
INSERT INTO product_type_layout VALUES (81, 'Affichage des Metatags Title par dfaut - Titre du produit', 'SHOW_PRODUCT_INFO_METATAGS_TITLE_STATUS', '1', 'Affiche le titre du produit dans le champ Meta Tags Title 0= off 1= on', 1, 50, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (82, 'Affiche des Metatags Title par dfaut - Nom du produit', 'SHOW_PRODUCT_INFO_METATAGS_PRODUCTS_NAME_STATUS', '1', 'Affiche le nom du produit dans le champ Meta Tags Title 0= off 1= on', 1, 51, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (83, 'Affiche des Metatags Title par dfaut - Rfrence du produit', 'SHOW_PRODUCT_INFO_METATAGS_MODEL_STATUS', '1', 'Affiche la rfrence du produit dans le champ Meta Tags Title 0= off 1= on', 1, 52, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (84, 'Affiche des Metatags Title par dfaut - Prix du produit', 'SHOW_PRODUCT_INFO_METATAGS_PRICE_STATUS', '1', 'Affiche le prix du produit dans le champ Meta Tags Title 0= off 1= on', 1, 53, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (85, 'Affiche des Metatags Title par dfaut - Tagline du produit', 'SHOW_PRODUCT_INFO_METATAGS_TITLE_TAGLINE_STATUS', '1', 'Affiche la tagline du produit dans le champ Meta Tags Title 0= off 1= on', 1, 54, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (86, 'Affiche des Metatags Title par dfaut - Titre du produit', 'SHOW_PRODUCT_MUSIC_INFO_METATAGS_TITLE_STATUS', '1', 'Affiche le titre du produit dans le champ Meta Tags Title 0= off 1= on', 2, 50, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (87, 'Affiche des Metatags Title par dfaut - Nom du produit', 'SHOW_PRODUCT_MUSIC_INFO_METATAGS_PRODUCTS_NAME_STATUS', '1', 'Affiche le nom du produit dans le champ Meta Tags Title 0= off 1= on', 2, 51, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (88, 'Affiche des Metatags Title par dfaut - Rfrence du produit', 'SHOW_PRODUCT_MUSIC_INFO_METATAGS_MODEL_STATUS', '1', 'Affiche la rfrence du produit dans le champ Meta Tags Title 0= off 1= on', 2, 52, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (89, 'Affiche des Metatags Title par dfaut - Prix du produit', 'SHOW_PRODUCT_MUSIC_INFO_METATAGS_PRICE_STATUS', '1', 'Affiche le prix du produit dans le champ Meta Tags Title 0= off 1= on', 2, 53, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (90, 'Affiche des Metatags Title par dfaut - Tagline du produit', 'SHOW_PRODUCT_MUSIC_INFO_METATAGS_TITLE_TAGLINE_STATUS', '1', 'Affiche la tagline du produit dans le champ Meta Tags Title 0= off 1= on', 2, 54, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (91, 'Affichage des Metatags Title par dfaut - Titre du document', 'SHOW_DOCUMENT_GENERAL_INFO_METATAGS_TITLE_STATUS', '1', 'Affiche le titre du document dans le champ Meta Tags Title 0= off 1= on', 3, 50, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (92, 'Affichage des Metatags Title par dfaut - Nom du document', 'SHOW_DOCUMENT_GENERAL_INFO_METATAGS_PRODUCTS_NAME_STATUS', '1', 'Affiche le nom du document dans le champ Meta Tags Title 0= off 1= on', 3, 51, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (93, 'Affichage des Metatags Title par dfaut - Tagline du document', 'SHOW_DOCUMENT_GENERAL_INFO_METATAGS_TITLE_TAGLINE_STATUS', '1', 'Affiche la tagline du document dans le champ Meta Tags Title 0= off 1= on', 3, 54, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (94, 'Affichage des Metatags Title par dfaut - Titre du document', 'SHOW_DOCUMENT_PRODUCT_INFO_METATAGS_TITLE_STATUS', '1', 'Affiche le titre du document dans le champ Meta Tags Title 0= off 1= on', 4, 50, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (95, 'Affichage des Metatags Title par dfaut - Nom du document', 'SHOW_DOCUMENT_PRODUCT_INFO_METATAGS_PRODUCTS_NAME_STATUS', '1', 'Affiche le nom du document dans le champ Meta Tags Title 0= off 1= on', 4, 51, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (96, 'Affichage des Metatags Title par dfaut - Rfrence du document', 'SHOW_DOCUMENT_PRODUCT_INFO_METATAGS_MODEL_STATUS', '1', 'Affiche la rfrence du document dans le champ Meta Tags Title 0= off 1= on', 4, 52, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (97, 'Affichage des Metatags Title par dfaut - Prix du document', 'SHOW_DOCUMENT_PRODUCT_INFO_METATAGS_PRICE_STATUS', '1', 'Affiche le prix du document dans le champ Meta Tags Title 0= off 1= on', 4, 53, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (98, 'Affichage des Metatags Title par dfaut - Tagline du document', 'SHOW_DOCUMENT_PRODUCT_INFO_METATAGS_TITLE_TAGLINE_STATUS', '1', 'Affiche la tagline du document dans le champ Meta Tags Title 0= off 1= on', 4, 54, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (99, 'Affichage des Metatags Title par dfaut - Titre du produit', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_METATAGS_TITLE_STATUS', '1', 'Affiche le titre du produit dans le champ Meta Tags Title 0= off 1= on', 5, 50, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (100, 'Affichage des Metatags Title par dfaut - Nom du produit', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_METATAGS_PRODUCTS_NAME_STATUS', '1', 'Affiche le nom du produit dans le champ Meta Tags Title 0= off 1= on', 5, 51, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (101, 'Affichage des Metatags Title par dfaut - Rfrence du produit', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_METATAGS_MODEL_STATUS', '1', 'Affiche la rfrence du produit dans le champ Meta Tags Title 0= off 1= on', 5, 52, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (102, 'Affichage des Metatags Title par dfaut - Prix du produit', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_METATAGS_PRICE_STATUS', '1', 'Affiche le prix du produit dans le champ Meta Tags Title 0= off 1= on', 5, 53, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (103, 'Affichage des Metatags Title par dfaut - Tagline du produit', 'SHOW_PRODUCT_FREE_SHIPPING_INFO_METATAGS_TITLE_TAGLINE_STATUS', '1', 'Affiche la tagline du produit dans le champ Meta Tags Title 0= off 1= on', 5, 54, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''True''), array(''id''=>''0'', ''text''=>''False'')), ');
INSERT INTO product_type_layout VALUES (104, 'Attributs de PRODUITS pour affichage seulement - Par dfaut', 'DEFAULT_PRODUCT_ATTRIBUTES_DISPLAY_ONLY', '0', 'Les attributs de PRODUITS sont utiliss pour l''affichage seulement<br />(aucun choix requis)<br />0= Non 1= Oui', 1, 200, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (105, 'Attribut de PRODUIT gratuit - Par dfaut', 'DEFAULT_PRODUCT_ATTRIBUTE_IS_FREE', '1', 'Attribut de PRODUIT gratuit<br />Les attributs sont gratuits lorsque le produit est lui-mme gratuit<br />0= Non 1= Oui', 1, 201, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (106, 'Attribut de PRODUIT par dfaut', 'DEFAULT_PRODUCT_ATTRIBUTES_DEFAULT', '0', 'Attribut de Produit par dfaut<br />L''attribut "par dfaut" est  slectionner par dfaut?<br />0= Non 1= Oui', 1, 202, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (107, 'Attribut de PRODUIT remis - Dfaut', 'DEFAULT_PRODUCT_ATTRIBUTES_DISCOUNTED', '1', 'L''attribut de PRODUIT est remis<br />L''application de remises est utilis par les produits en promotion<br />0= Non 1= Oui', 1, 203, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (108, 'Attribut de PRODUIT inclus dans le prix de base - Dfaut', 'DEFAULT_PRODUCT_ATTRIBUTES_PRICE_BASE_INCLUDED', '1', 'L''attribut de PRODUIT est inclus dans le prix de base<br />Inclure dans le prix de base quand le prix dpend des attributs<br />0= Non 1= Oui', 1, 204, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (109, 'Attribut de PRODUIT requis - Dfaut', 'DEFAULT_PRODUCT_ATTRIBUTES_REQUIRED', '0', 'Attribut de PRODUIT requis<br />L''attribut de texte est requis/obligatoire<br />0= Non 1= Oui', 1, 205, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (110, 'Attribut PRODUIT prfixe de prix - Dfaut', 'DEFAULT_PRODUCT_PRICE_PREFIX', '1', 'Attribut PRODUIT prfixe de prix<br />Prfixe de prix par dfaut pour un Attribut qui additionne<br />Blank = aucun, + ou -', 1, 206, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Blank''), array(''id''=>''1'', ''text''=>''+''), array(''id''=>''2'', ''text''=>''-'')), ');
INSERT INTO product_type_layout VALUES (111, 'Attribut PRODUIT prfixe de poids - Dfaut', 'DEFAULT_PRODUCT_PRODUCTS_ATTRIBUTES_WEIGHT_PREFIX', '1', 'Attribut PRODUIT prfixe de poids<br />Prfixe par dfaut d''un Attribut avec prfixe de poids<br />Blank = rien, + ou -', 1, 207, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Blank''), array(''id''=>''1'', ''text''=>''+''), array(''id''=>''2'', ''text''=>''-'')), ');
INSERT INTO product_type_layout VALUES (112, 'MUSIC : Attribut en affichage seulement - Dfaut', 'DEFAULT_PRODUCT_MUSIC_ATTRIBUTES_DISPLAY_ONLY', '0', 'Attribut MUSIC en affichage seulement<br />Utilis  des fins d''affichage seulement<br />0= Non 1= Oui', 2, 200, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (113, 'MUSIC : Attribut gratuit - Dfaut', 'DEFAULT_PRODUCT_MUSIC_ATTRIBUTE_IS_FREE', '1', 'Attribut MUSIC gratuite<br />L''attribut est gratuit lorsque le produit est gratuit<br />0= Non 1= Oui', 2, 201, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (114, 'MUSIC : Attribut par dfaut - Dfaut', 'DEFAULT_PRODUCT_MUSIC_ATTRIBUTES_DEFAULT', '0', 'Attribut MUSIC par dfaut<br />L''attribut par dfaut  slectionner<br />0= Non 1= Oui', 2, 202, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (115, 'MUSIC : Attribut de remises - Dfaut', 'DEFAULT_PRODUCT_MUSIC_ATTRIBUTES_DISCOUNTED', '1', 'Attribut de remises MUSIC<br />Applique les rductions utilises par les produits en promotion<br />0= Non 1= Oui', 2, 203, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (116, 'MUSIC : attribut inclus dans le prix de base - Dfaut', 'DEFAULT_PRODUCT_MUSIC_ATTRIBUTES_PRICE_BASE_INCLUDED', '1', 'MUSIC Attribute is Included in Base Price<br />Include in Base Price When Priced by Attributes<br />0= No 1= Yes', 2, 204, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (117, 'MUSIC : attribut requis - Dfaut', 'DEFAULT_PRODUCT_MUSIC_ATTRIBUTES_REQUIRED', '0', 'MUSIC : Attribut est requis<br />Attribut de texte obligatoire<br />0= Non 1= Oui', 2, 205, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (118, 'MUSIC : Attribut prfixe de prix - Dfaut', 'DEFAULT_PRODUCT_MUSIC_PRICE_PREFIX', '1', 'MUSIC : Attribut prfixe de prix<br />Valeur de prfixe par dfaut pour un attribut prfixe de prix qui additionne<br />Blank = rien, + or -', 2, 206, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Blank''), array(''id''=>''1'', ''text''=>''+''), array(''id''=>''2'', ''text''=>''-'')), ');
INSERT INTO product_type_layout VALUES (119, 'MUSIC : attribut prfixe de poids - Par dfaut', 'DEFAULT_PRODUCT_MUSIC_PRODUCTS_ATTRIBUTES_WEIGHT_PREFIX', '1', 'MUSIC  : attribut prfixe de poids<br />Prfixe par dfaut pour les attributs de poids<br />Blank = rien, + ou -', 2, 207, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Blank''), array(''id''=>''1'', ''text''=>''+''), array(''id''=>''2'', ''text''=>''-'')), ');
INSERT INTO product_type_layout VALUES (120, 'DOCUMENT GENERAL : attribut en affichage seul - Dfaut', 'DEFAULT_DOCUMENT_GENERAL_ATTRIBUTES_DISPLAY_ONLY', '0', 'DOCUMENT GENERAL : attribut en affichage seul<br />Utilis  des fins d''affichage seulement<br />0= Non 1= Oui', 3, 200, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (121, 'DOCUMENT GENERAL : attribut gratuit - Dfaut', 'DEFAULT_DOCUMENT_GENERAL_ATTRIBUTE_IS_FREE', '1', 'DOCUMENT GENERAL : attribut gratuit<br />L''attribut est gratuit lorsque le produit est lui-mme gratuit<br />0= Non 1= Oui', 3, 201, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (122, 'DOCUMENT GENERAL : attribut par dfaut - Dfaut', 'DEFAULT_DOCUMENT_GENERAL_ATTRIBUTES_DEFAULT', '0', 'DOCUMENT GENERAL : attribut par dfaut<br />L''attribut par dfaut doit tre slectionn<br />0= Non 1= Oui', 3, 202, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (123, 'DOCUMENT GENERAL : Attribut de remises - Dfaut', 'DEFAULT_DOCUMENT_GENERAL_ATTRIBUTES_DISCOUNTED', '1', 'DOCUMENT GENERAL : Attribut de remises<br />Appliquent les remises utilises par les produits en promotion<br />0= Non 1= Oui', 3, 203, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (124, 'DOCUMENT GENERAL : attribut inclus dans le prix de base - Dfaut', 'DEFAULT_DOCUMENT_GENERAL_ATTRIBUTES_PRICE_BASE_INCLUDED', '1', 'DOCUMENT GENERAL attribut inclus dans le prix de base<br />Inclure dans le prix de base quand le prix est en rapport avec des attributs<br />0= Non 1= Oui', 3, 204, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (125, 'DOCUMENT GENERAL : attribut requis - Dfaut', 'DEFAULT_DOCUMENT_GENERAL_ATTRIBUTES_REQUIRED', '0', 'DOCUMENT GENERAL : attribut requis<br />L''attribut ncessite du texte obligatoire<br />0= Non 1= Oui', 3, 205, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (126, 'DOCUMENT GENERAL : attribut prfixe de prix - Dfaut', 'DEFAULT_DOCUMENT_GENERAL_PRICE_PREFIX', '1', 'DOCUMENT GENERAL : attribut prfixe de prix<br />Valeur par dfaut pour du prfixe de prix pour une addition<br />Blank = rien, + ou -', 3, 206, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Blank''), array(''id''=>''1'', ''text''=>''+''), array(''id''=>''2'', ''text''=>''-'')), ');
INSERT INTO product_type_layout VALUES (127, 'DOCUMENT GENERAL : attribut prfixe de poids - Dfaut', 'DEFAULT_DOCUMENT_GENERAL_PRODUCTS_ATTRIBUTES_WEIGHT_PREFIX', '1', 'DOCUMENT GENERAL : attribut prfixe de poids<br />Le prfixe par dfaut de l''attribut de poids<br />Blank = rien, + or -', 3, 207, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Blank''), array(''id''=>''1'', ''text''=>''+''), array(''id''=>''2'', ''text''=>''-'')), ');
INSERT INTO product_type_layout VALUES (128, 'DOCUMENT PRODUCT : attribut en affichage seulement - Dfaut', 'DEFAULT_DOCUMENT_PRODUCT_ATTRIBUTES_DISPLAY_ONLY', '0', 'DOCUMENT PRODUCT : attribut en affichage seulement<br />Utilis  des fins d''affichage seulement<br />0= Non 1= Oui', 4, 200, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (129, 'DOCUMENT PRODUCT : attribut gratuit - Dfaut', 'DEFAULT_DOCUMENT_PRODUCT_ATTRIBUTE_IS_FREE', '1', 'DOCUMENT PRODUCT : attribut gratuit<br />Attribut gratuit lorsque le produit est lui-mme gratuit<br />0= Non 1= Oui', 4, 201, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (130, 'DOCUMENT PRODUCT : attribut par dfaut - Dfaut', 'DEFAULT_DOCUMENT_PRODUCT_ATTRIBUTES_DEFAULT', '0', 'DOCUMENT PRODUCT : attribut par dfaut<br />L''attribut  slectionner par dfaut<br />0= Non 1= Oui', 4, 202, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (131, 'DOCUMENT PRODUCT : attribut de remises - Dfaut', 'DEFAULT_DOCUMENT_PRODUCT_ATTRIBUTES_DISCOUNTED', '1', 'DOCUMENT PRODUCT : attribut de remises<br />Applique les remises utilises par les produits en promotion<br />0= Non 1= Oui', 4, 203, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (132, 'DOCUMENT PRODUCT : attribut inclus dans le prix de base - Dfaut', 'DEFAULT_DOCUMENT_PRODUCT_ATTRIBUTES_PRICE_BASE_INCLUDED', '1', 'DOCUMENT PRODUCT : l''attribut est inclus dans le prix de base<br />Inclure dans le prix de base lorsque l''attribut joue sur le prix<br />0= Non 1= Oui', 4, 204, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (133, 'DOCUMENT PRODUCT : attribut requis - Dfaut', 'DEFAULT_DOCUMENT_PRODUCT_ATTRIBUTES_REQUIRED', '0', 'DOCUMENT PRODUCT : attribut requis<br />Attribut de texte obligatoire<br />0= Non 1= Oui', 4, 205, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (134, 'DOCUMENT PRODUCT : attribut prfixe de prix - Dfaut', 'DEFAULT_DOCUMENT_PRODUCT_PRICE_PREFIX', '1', 'DOCUMENT PRODUCT : attribut prfixe de prix<br />Prfixe par dfaut pour les prix des attributs<br />Blank = rien, + ou -', 4, 206, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Blank''), array(''id''=>''1'', ''text''=>''+''), array(''id''=>''2'', ''text''=>''-'')), ');
INSERT INTO product_type_layout VALUES (135, 'DOCUMENT PRODUCT : prfixe d''attribut de poids - Dfaut', 'DEFAULT_DOCUMENT_PRODUCT_PRODUCTS_ATTRIBUTES_WEIGHT_PREFIX', '1', 'DOCUMENT PRODUCT : prfixe d''attribut de poids<br />Prfixe par dfaut pour un attribut de poids<br />Blank = rien, + or -', 4, 207, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Blank''), array(''id''=>''1'', ''text''=>''+''), array(''id''=>''2'', ''text''=>''-'')), ');
INSERT INTO product_type_layout VALUES (136, 'PRODUIT EN LIVRAISON GRATUITE : attribut seulement pour affichage - Dfaut', 'DEFAULT_PRODUCT_FREE_SHIPPING_ATTRIBUTES_DISPLAY_ONLY', '0', 'PRODUIT EN LIVRAISON GRATUITE : attribut seulement pour affichage<br />Utilis  des fins d''affichage seulement<br />0= Non 1= Oui', 5, 201, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (137, 'PRODUIT EN LIVRAISON GRATUITE : Attribut gratuit - Dfaut', 'DEFAULT_PRODUCT_FREE_SHIPPING_ATTRIBUTE_IS_FREE', '1', 'PRODUIT EN LIVRAISON GRATUITE : Attribut gratuit<br />L''attribut est gratuit lorsque le produit est lui-mme gratuit<br />0= Non 1= Oui', 5, 201, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (138, 'PRODUIT EN LIVRAISON GRATUITE : Attribut par dfaut - Dfaut', 'DEFAULT_PRODUCT_FREE_SHIPPING_ATTRIBUTES_DEFAULT', '0', 'PRODUIT EN LIVRAISON GRATUITE : Attribut par dfaut<br />Attribut qui doit tre slectionn par dfaut<br />0= Non 1= Oui', 5, 202, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (139, 'PRODUIT EN LIVRAISON GRATUITE : Attribut de remises - Dfaut', 'DEFAULT_PRODUCT_FREE_SHIPPING_ATTRIBUTES_DISCOUNTED', '1', 'PRODUIT EN LIVRAISON GRATUITE : Attribut de remises<br />Appliquer des remises utilises par les produits en promotion<br />0= Non 1= Oui', 5, 203, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (140, 'PRODUIT EN LIVRAISON GRATUITE : Attribut inclus dans le prix de base - Dfaut', 'DEFAULT_PRODUCT_FREE_SHIPPING_ATTRIBUTES_PRICE_BASE_INCLUDED', '1', 'PRODUIT EN LIVRAISON GRATUITE : Attribut inclus dans le prix de base<br />Inclure dans le prix de base lorsque l''attribut a un prix<br />0= Non 1= Oui', 5, 204, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (141, 'PRODUIT EN LIVRAISON GRATUITE : Attribut requis - Dfaut', 'DEFAULT_PRODUCT_FREE_SHIPPING_ATTRIBUTES_REQUIRED', '0', 'PRODUIT EN LIVRAISON GRATUITE : Attribut requis<br />Attribut ncessite du texte<br />0= Non 1= Oui', 5, 205, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''1'', ''text''=>''Yes''), array(''id''=>''0'', ''text''=>''No'')), ');
INSERT INTO product_type_layout VALUES (142, 'PRODUIT EN LIVRAISON GRATUITE : Prfixe de prix de l''attribut - Dfaut', 'DEFAULT_PRODUCT_FREE_SHIPPING_PRICE_PREFIX', '1', 'PRODUIT EN LIVRAISON GRATUITE : Prfixe de prix de l''attribut<br />Le prfixe de prix par dfaut de l''attribut pour addition<br />Blank = rien, + ou -', 5, 206, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Blank''), array(''id''=>''1'', ''text''=>''+''), array(''id''=>''2'', ''text''=>''-'')), ');
INSERT INTO product_type_layout VALUES (143, 'PRODUIT EN LIVRAISON GRATUITE : prfixe de poids de l''attribut - Dfaut', 'DEFAULT_PRODUCT_FREE_SHIPPING_PRODUCTS_ATTRIBUTES_WEIGHT_PREFIX', '1', 'PRODUIT EN LIVRAISON GRATUITE : prfixe de poids de l''attribut<br />Prfixe de l''attribut de poids par dfaut<br />Blank = rien, + ou -', 5, 207, NULL, '2007-11-04 19:40:01', NULL, 'zen_cfg_select_drop_down(array(array(''id''=>''0'', ''text''=>''Blank''), array(''id''=>''1'', ''text''=>''+''), array(''id''=>''2'', ''text''=>''-'')), ');

### eof: attribute default database updates and changes


## Insert the default queries for "all customers" and "all newsletter subscribers"
INSERT INTO query_builder ( query_id , query_category , query_name , query_description , query_string , query_keys_list ) VALUES ( '1', 'email', 'All Customers', 'Returns all customers name and email address for sending mass emails (ie: for newsletters, coupons, GVs, messages, etc).', 'select customers_email_address, customers_firstname, customers_lastname from TABLE_CUSTOMERS order by customers_lastname, customers_firstname, customers_email_address', '');
INSERT INTO query_builder ( query_id , query_category , query_name , query_description , query_string , query_keys_list ) VALUES ( '2', 'email,newsletters', 'All Newsletter Subscribers', 'Returns name and email address of newsletter subscribers', 'select customers_firstname, customers_lastname, customers_email_address from TABLE_CUSTOMERS where customers_newsletter = \'1\'', '');
INSERT INTO query_builder ( query_id , query_category , query_name , query_description , query_string , query_keys_list ) VALUES ( '3', 'email,newsletters', 'Dormant Customers (>3months) (Subscribers)', 'Subscribers who HAVE purchased something, but have NOT purchased for at least three months.', 'select o.date_purchased, c.customers_email_address, c.customers_lastname, c.customers_firstname from TABLE_CUSTOMERS c, TABLE_ORDERS o WHERE c.customers_id = o.customers_id AND c.customers_newsletter = 1 GROUP BY c.customers_email_address HAVING max(o.date_purchased) <= subdate(now(),INTERVAL 3 MONTH) ORDER BY c.customers_lastname, c.customers_firstname ASC', '');
INSERT INTO query_builder ( query_id , query_category , query_name , query_description , query_string , query_keys_list ) VALUES ( '4', 'email,newsletters', 'Active customers in past 3 months (Subscribers)', 'Newsletter subscribers who are also active customers (purchased something) in last 3 months.', 'select c.customers_email_address, c.customers_lastname, c.customers_firstname from TABLE_CUSTOMERS c, TABLE_ORDERS o where c.customers_newsletter = \'1\' AND c.customers_id = o.customers_id and o.date_purchased > subdate(now(),INTERVAL 3 MONTH) GROUP BY c.customers_email_address order by c.customers_lastname, c.customers_firstname ASC', '');
INSERT INTO query_builder ( query_id , query_category , query_name , query_description , query_string , query_keys_list ) VALUES ( '5', 'email,newsletters', 'Active customers in past 3 months (Regardless of subscription status)', 'All active customers (purchased something) in last 3 months, ignoring newsletter-subscription status.', 'select c.customers_email_address, c.customers_lastname, c.customers_firstname from TABLE_CUSTOMERS c, TABLE_ORDERS o WHERE c.customers_id = o.customers_id and o.date_purchased > subdate(now(),INTERVAL 3 MONTH) GROUP BY c.customers_email_address order by c.customers_lastname, c.customers_firstname ASC', '');
INSERT INTO query_builder ( query_id , query_category , query_name , query_description , query_string , query_keys_list ) VALUES ( '6', 'email,newsletters', 'Administrator', 'Just the email account of the current administrator', 'select \'ADMIN\' as customers_firstname, admin_name as customers_lastname, admin_email as customers_email_address from TABLE_ADMIN where admin_id = $SESSION:admin_id', '');
INSERT INTO query_builder ( query_id , query_category , query_name , query_description , query_string , query_keys_list ) VALUES ( '7', 'email,newsletters', 'Customers who have never completed a purchase', 'For sending newsletter to all customers who registered but have never completed a purchase', 'SELECT DISTINCT c.customers_email_address as customers_email_address, c.customers_lastname as customers_lastname, c.customers_firstname as customers_firstname FROM TABLE_CUSTOMERS c LEFT JOIN  TABLE_ORDERS o ON c.customers_id=o.customers_id WHERE o.date_purchased IS NULL', '');

#
# end of Query-Builder Setup
#

#
# Dumping data for table get_terms_to_filter
#

INSERT INTO get_terms_to_filter VALUES ('manufacturers_id', 'TABLE_MANUFACTURERS', 'manufacturers_name');
INSERT INTO get_terms_to_filter VALUES ('music_genre_id', 'TABLE_MUSIC_GENRE', 'music_genre_name');
INSERT INTO get_terms_to_filter VALUES ('record_company_id', 'TABLE_RECORD_COMPANY', 'record_company_name');

#
# Dumping data for table project_version
#

INSERT INTO project_version (project_version_id, project_version_key, project_version_major, project_version_minor, project_version_patch1, project_version_patch1_source, project_version_patch2, project_version_patch2_source, project_version_comment, project_version_date_applied) VALUES (1, 'Zen-Cart Main', '1', '3.8', '', '', '', '', 'Fresh Installation', now());
INSERT INTO project_version (project_version_id, project_version_key, project_version_major, project_version_minor, project_version_patch1, project_version_patch1_source, project_version_patch2, project_version_patch2_source, project_version_comment, project_version_date_applied) VALUES (2, 'Zen-Cart Database', '1', '3.8', '', '', '', '', 'Fresh Installation', now());
INSERT INTO project_version_history (project_version_id, project_version_key, project_version_major, project_version_minor, project_version_patch, project_version_comment, project_version_date_applied) VALUES (1, 'Zen-Cart Main', '1', '3.8', '', 'Fresh Installation', now());
INSERT INTO project_version_history (project_version_id, project_version_key, project_version_major, project_version_minor, project_version_patch, project_version_comment, project_version_date_applied) VALUES (2, 'Zen-Cart Database', '1', '3.8', '', 'Fresh Installation', now());

##### End of SQL setup for Zen Cart.
